/* GomDocument.c generated by valac 0.34.6, the Vala compiler
 * generated from GomDocument.vala, do not modify */

/* -*- Mode: vala; indent-tabs-mode: nil; c-basic-offset: 2; tab-width: 2 -*- */
/*
 *
 * Copyright (C) 2016  Daniel Espinosa <esodan@gmail.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, see <http://www.gnu.org/licenses/>.
 *
 * Authors:
 *      Daniel Espinosa <esodan@gmail.com>
 */

#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <gee.h>
#include <gio/gio.h>
#include <glib/gi18n-lib.h>


#define GXML_TYPE_DOM_EVENT_TARGET (gxml_dom_event_target_get_type ())
#define GXML_DOM_EVENT_TARGET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_EVENT_TARGET, GXmlDomEventTarget))
#define GXML_IS_DOM_EVENT_TARGET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_EVENT_TARGET))
#define GXML_DOM_EVENT_TARGET_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_EVENT_TARGET, GXmlDomEventTargetIface))

typedef struct _GXmlDomEventTarget GXmlDomEventTarget;
typedef struct _GXmlDomEventTargetIface GXmlDomEventTargetIface;

#define GXML_TYPE_DOM_EVENT_LISTENER (gxml_dom_event_listener_get_type ())
#define GXML_DOM_EVENT_LISTENER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_EVENT_LISTENER, GXmlDomEventListener))
#define GXML_IS_DOM_EVENT_LISTENER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_EVENT_LISTENER))
#define GXML_DOM_EVENT_LISTENER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_EVENT_LISTENER, GXmlDomEventListenerIface))

typedef struct _GXmlDomEventListener GXmlDomEventListener;
typedef struct _GXmlDomEventListenerIface GXmlDomEventListenerIface;

#define GXML_TYPE_DOM_EVENT (gxml_dom_event_get_type ())
#define GXML_DOM_EVENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_EVENT, GXmlDomEvent))
#define GXML_IS_DOM_EVENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_EVENT))
#define GXML_DOM_EVENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_EVENT, GXmlDomEventIface))

typedef struct _GXmlDomEvent GXmlDomEvent;
typedef struct _GXmlDomEventIface GXmlDomEventIface;

#define GXML_TYPE_DOM_TIME_STAMP (gxml_dom_time_stamp_get_type ())
#define GXML_DOM_TIME_STAMP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_TIME_STAMP, GXmlDomTimeStamp))
#define GXML_DOM_TIME_STAMP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_DOM_TIME_STAMP, GXmlDomTimeStampClass))
#define GXML_IS_DOM_TIME_STAMP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_TIME_STAMP))
#define GXML_IS_DOM_TIME_STAMP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_DOM_TIME_STAMP))
#define GXML_DOM_TIME_STAMP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_DOM_TIME_STAMP, GXmlDomTimeStampClass))

typedef struct _GXmlDomTimeStamp GXmlDomTimeStamp;
typedef struct _GXmlDomTimeStampClass GXmlDomTimeStampClass;

#define GXML_DOM_EVENT_TYPE_PHASE (gxml_dom_event_phase_get_type ())

#define GXML_TYPE_DOM_NODE (gxml_dom_node_get_type ())
#define GXML_DOM_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NODE, GXmlDomNode))
#define GXML_IS_DOM_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NODE))
#define GXML_DOM_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NODE, GXmlDomNodeIface))

typedef struct _GXmlDomNode GXmlDomNode;
typedef struct _GXmlDomNodeIface GXmlDomNodeIface;

#define GXML_DOM_NODE_TYPE_DOCUMENT_POSITION (gxml_dom_node_document_position_get_type ())

#define GXML_DOM_NODE_TYPE_NODE_TYPE (gxml_dom_node_node_type_get_type ())

#define GXML_TYPE_DOM_PARENT_NODE (gxml_dom_parent_node_get_type ())
#define GXML_DOM_PARENT_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_PARENT_NODE, GXmlDomParentNode))
#define GXML_IS_DOM_PARENT_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_PARENT_NODE))
#define GXML_DOM_PARENT_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_PARENT_NODE, GXmlDomParentNodeIface))

typedef struct _GXmlDomParentNode GXmlDomParentNode;
typedef struct _GXmlDomParentNodeIface GXmlDomParentNodeIface;

#define GXML_TYPE_DOM_CHILD_NODE (gxml_dom_child_node_get_type ())
#define GXML_DOM_CHILD_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_CHILD_NODE, GXmlDomChildNode))
#define GXML_IS_DOM_CHILD_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_CHILD_NODE))
#define GXML_DOM_CHILD_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_CHILD_NODE, GXmlDomChildNodeIface))

typedef struct _GXmlDomChildNode GXmlDomChildNode;
typedef struct _GXmlDomChildNodeIface GXmlDomChildNodeIface;

#define GXML_TYPE_DOM_NON_DOCUMENT_TYPE_CHILD_NODE (gxml_dom_non_document_type_child_node_get_type ())
#define GXML_DOM_NON_DOCUMENT_TYPE_CHILD_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NON_DOCUMENT_TYPE_CHILD_NODE, GXmlDomNonDocumentTypeChildNode))
#define GXML_IS_DOM_NON_DOCUMENT_TYPE_CHILD_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NON_DOCUMENT_TYPE_CHILD_NODE))
#define GXML_DOM_NON_DOCUMENT_TYPE_CHILD_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NON_DOCUMENT_TYPE_CHILD_NODE, GXmlDomNonDocumentTypeChildNodeIface))

typedef struct _GXmlDomNonDocumentTypeChildNode GXmlDomNonDocumentTypeChildNode;
typedef struct _GXmlDomNonDocumentTypeChildNodeIface GXmlDomNonDocumentTypeChildNodeIface;

#define GXML_TYPE_DOM_ELEMENT (gxml_dom_element_get_type ())
#define GXML_DOM_ELEMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_ELEMENT, GXmlDomElement))
#define GXML_IS_DOM_ELEMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_ELEMENT))
#define GXML_DOM_ELEMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_ELEMENT, GXmlDomElementIface))

typedef struct _GXmlDomElement GXmlDomElement;
typedef struct _GXmlDomElementIface GXmlDomElementIface;

#define GXML_TYPE_DOM_HTML_COLLECTION (gxml_dom_html_collection_get_type ())
#define GXML_DOM_HTML_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_HTML_COLLECTION, GXmlDomHTMLCollection))
#define GXML_IS_DOM_HTML_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_HTML_COLLECTION))
#define GXML_DOM_HTML_COLLECTION_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_HTML_COLLECTION, GXmlDomHTMLCollectionIface))

typedef struct _GXmlDomHTMLCollection GXmlDomHTMLCollection;
typedef struct _GXmlDomHTMLCollectionIface GXmlDomHTMLCollectionIface;

#define GXML_TYPE_DOM_TOKEN_LIST (gxml_dom_token_list_get_type ())
#define GXML_DOM_TOKEN_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_TOKEN_LIST, GXmlDomTokenList))
#define GXML_IS_DOM_TOKEN_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_TOKEN_LIST))
#define GXML_DOM_TOKEN_LIST_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_TOKEN_LIST, GXmlDomTokenListIface))

typedef struct _GXmlDomTokenList GXmlDomTokenList;
typedef struct _GXmlDomTokenListIface GXmlDomTokenListIface;

#define GXML_TYPE_DOM_NAMED_NODE_MAP (gxml_dom_named_node_map_get_type ())
#define GXML_DOM_NAMED_NODE_MAP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NAMED_NODE_MAP, GXmlDomNamedNodeMap))
#define GXML_IS_DOM_NAMED_NODE_MAP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NAMED_NODE_MAP))
#define GXML_DOM_NAMED_NODE_MAP_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NAMED_NODE_MAP, GXmlDomNamedNodeMapIface))

typedef struct _GXmlDomNamedNodeMap GXmlDomNamedNodeMap;
typedef struct _GXmlDomNamedNodeMapIface GXmlDomNamedNodeMapIface;

#define GXML_TYPE_DOM_NODE_LIST (gxml_dom_node_list_get_type ())
#define GXML_DOM_NODE_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NODE_LIST, GXmlDomNodeList))
#define GXML_IS_DOM_NODE_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NODE_LIST))
#define GXML_DOM_NODE_LIST_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NODE_LIST, GXmlDomNodeListIface))

typedef struct _GXmlDomNodeList GXmlDomNodeList;
typedef struct _GXmlDomNodeListIface GXmlDomNodeListIface;

#define GXML_TYPE_DOM_ELEMENT_LIST (gxml_dom_element_list_get_type ())
#define GXML_DOM_ELEMENT_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_ELEMENT_LIST, GXmlDomElementList))
#define GXML_DOM_ELEMENT_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_DOM_ELEMENT_LIST, GXmlDomElementListClass))
#define GXML_IS_DOM_ELEMENT_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_ELEMENT_LIST))
#define GXML_IS_DOM_ELEMENT_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_DOM_ELEMENT_LIST))
#define GXML_DOM_ELEMENT_LIST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_DOM_ELEMENT_LIST, GXmlDomElementListClass))

typedef struct _GXmlDomElementList GXmlDomElementList;
typedef struct _GXmlDomElementListClass GXmlDomElementListClass;

#define GXML_TYPE_DOM_NON_ELEMENT_PARENT_NODE (gxml_dom_non_element_parent_node_get_type ())
#define GXML_DOM_NON_ELEMENT_PARENT_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NON_ELEMENT_PARENT_NODE, GXmlDomNonElementParentNode))
#define GXML_IS_DOM_NON_ELEMENT_PARENT_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NON_ELEMENT_PARENT_NODE))
#define GXML_DOM_NON_ELEMENT_PARENT_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NON_ELEMENT_PARENT_NODE, GXmlDomNonElementParentNodeIface))

typedef struct _GXmlDomNonElementParentNode GXmlDomNonElementParentNode;
typedef struct _GXmlDomNonElementParentNodeIface GXmlDomNonElementParentNodeIface;

#define GXML_TYPE_DOM_DOCUMENT (gxml_dom_document_get_type ())
#define GXML_DOM_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_DOCUMENT, GXmlDomDocument))
#define GXML_IS_DOM_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_DOCUMENT))
#define GXML_DOM_DOCUMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_DOCUMENT, GXmlDomDocumentIface))

typedef struct _GXmlDomDocument GXmlDomDocument;
typedef struct _GXmlDomDocumentIface GXmlDomDocumentIface;

#define GXML_TYPE_DOM_DOCUMENT_FRAGMENT (gxml_dom_document_fragment_get_type ())
#define GXML_DOM_DOCUMENT_FRAGMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_DOCUMENT_FRAGMENT, GXmlDomDocumentFragment))
#define GXML_IS_DOM_DOCUMENT_FRAGMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_DOCUMENT_FRAGMENT))
#define GXML_DOM_DOCUMENT_FRAGMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_DOCUMENT_FRAGMENT, GXmlDomDocumentFragmentIface))

typedef struct _GXmlDomDocumentFragment GXmlDomDocumentFragment;
typedef struct _GXmlDomDocumentFragmentIface GXmlDomDocumentFragmentIface;

#define GXML_TYPE_DOM_CHARACTER_DATA (gxml_dom_character_data_get_type ())
#define GXML_DOM_CHARACTER_DATA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_CHARACTER_DATA, GXmlDomCharacterData))
#define GXML_IS_DOM_CHARACTER_DATA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_CHARACTER_DATA))
#define GXML_DOM_CHARACTER_DATA_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_CHARACTER_DATA, GXmlDomCharacterDataIface))

typedef struct _GXmlDomCharacterData GXmlDomCharacterData;
typedef struct _GXmlDomCharacterDataIface GXmlDomCharacterDataIface;

#define GXML_TYPE_DOM_TEXT (gxml_dom_text_get_type ())
#define GXML_DOM_TEXT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_TEXT, GXmlDomText))
#define GXML_IS_DOM_TEXT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_TEXT))
#define GXML_DOM_TEXT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_TEXT, GXmlDomTextIface))

typedef struct _GXmlDomText GXmlDomText;
typedef struct _GXmlDomTextIface GXmlDomTextIface;

#define GXML_TYPE_DOM_COMMENT (gxml_dom_comment_get_type ())
#define GXML_DOM_COMMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_COMMENT, GXmlDomComment))
#define GXML_IS_DOM_COMMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_COMMENT))
#define GXML_DOM_COMMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_COMMENT, GXmlDomCommentIface))

typedef struct _GXmlDomComment GXmlDomComment;
typedef struct _GXmlDomCommentIface GXmlDomCommentIface;

#define GXML_TYPE_DOM_PROCESSING_INSTRUCTION (gxml_dom_processing_instruction_get_type ())
#define GXML_DOM_PROCESSING_INSTRUCTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_PROCESSING_INSTRUCTION, GXmlDomProcessingInstruction))
#define GXML_IS_DOM_PROCESSING_INSTRUCTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_PROCESSING_INSTRUCTION))
#define GXML_DOM_PROCESSING_INSTRUCTION_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_PROCESSING_INSTRUCTION, GXmlDomProcessingInstructionIface))

typedef struct _GXmlDomProcessingInstruction GXmlDomProcessingInstruction;
typedef struct _GXmlDomProcessingInstructionIface GXmlDomProcessingInstructionIface;

#define GXML_TYPE_DOM_RANGE (gxml_dom_range_get_type ())
#define GXML_DOM_RANGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_RANGE, GXmlDomRange))
#define GXML_IS_DOM_RANGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_RANGE))
#define GXML_DOM_RANGE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_RANGE, GXmlDomRangeIface))

typedef struct _GXmlDomRange GXmlDomRange;
typedef struct _GXmlDomRangeIface GXmlDomRangeIface;

#define GXML_DOM_RANGE_TYPE_BOUNDARY_POINTS (gxml_dom_range_boundary_points_get_type ())

#define GXML_TYPE_DOM_NODE_FILTER (gxml_dom_node_filter_get_type ())
#define GXML_DOM_NODE_FILTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NODE_FILTER, GXmlDomNodeFilter))
#define GXML_DOM_NODE_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_DOM_NODE_FILTER, GXmlDomNodeFilterClass))
#define GXML_IS_DOM_NODE_FILTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NODE_FILTER))
#define GXML_IS_DOM_NODE_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_DOM_NODE_FILTER))
#define GXML_DOM_NODE_FILTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_DOM_NODE_FILTER, GXmlDomNodeFilterClass))

typedef struct _GXmlDomNodeFilter GXmlDomNodeFilter;
typedef struct _GXmlDomNodeFilterClass GXmlDomNodeFilterClass;

#define GXML_TYPE_DOM_NODE_ITERATOR (gxml_dom_node_iterator_get_type ())
#define GXML_DOM_NODE_ITERATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NODE_ITERATOR, GXmlDomNodeIterator))
#define GXML_IS_DOM_NODE_ITERATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NODE_ITERATOR))
#define GXML_DOM_NODE_ITERATOR_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NODE_ITERATOR, GXmlDomNodeIteratorIface))

typedef struct _GXmlDomNodeIterator GXmlDomNodeIterator;
typedef struct _GXmlDomNodeIteratorIface GXmlDomNodeIteratorIface;

#define GXML_TYPE_DOM_TREE_WALKER (gxml_dom_tree_walker_get_type ())
#define GXML_DOM_TREE_WALKER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_TREE_WALKER, GXmlDomTreeWalker))
#define GXML_IS_DOM_TREE_WALKER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_TREE_WALKER))
#define GXML_DOM_TREE_WALKER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_TREE_WALKER, GXmlDomTreeWalkerIface))

typedef struct _GXmlDomTreeWalker GXmlDomTreeWalker;
typedef struct _GXmlDomTreeWalkerIface GXmlDomTreeWalkerIface;

#define GXML_TYPE_DOM_IMPLEMENTATION (gxml_dom_implementation_get_type ())
#define GXML_DOM_IMPLEMENTATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_IMPLEMENTATION, GXmlDomImplementation))
#define GXML_IS_DOM_IMPLEMENTATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_IMPLEMENTATION))
#define GXML_DOM_IMPLEMENTATION_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_IMPLEMENTATION, GXmlDomImplementationIface))

typedef struct _GXmlDomImplementation GXmlDomImplementation;
typedef struct _GXmlDomImplementationIface GXmlDomImplementationIface;

#define GXML_TYPE_DOM_DOCUMENT_TYPE (gxml_dom_document_type_get_type ())
#define GXML_DOM_DOCUMENT_TYPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_DOCUMENT_TYPE, GXmlDomDocumentType))
#define GXML_IS_DOM_DOCUMENT_TYPE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_DOCUMENT_TYPE))
#define GXML_DOM_DOCUMENT_TYPE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_DOCUMENT_TYPE, GXmlDomDocumentTypeIface))

typedef struct _GXmlDomDocumentType GXmlDomDocumentType;
typedef struct _GXmlDomDocumentTypeIface GXmlDomDocumentTypeIface;

#define GXML_TYPE_DOM_XML_DOCUMENT (gxml_dom_xml_document_get_type ())
#define GXML_DOM_XML_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_XML_DOCUMENT, GXmlDomXMLDocument))
#define GXML_IS_DOM_XML_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_XML_DOCUMENT))
#define GXML_DOM_XML_DOCUMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_XML_DOCUMENT, GXmlDomXMLDocumentIface))

typedef struct _GXmlDomXMLDocument GXmlDomXMLDocument;
typedef struct _GXmlDomXMLDocumentIface GXmlDomXMLDocumentIface;

#define GXML_TYPE_NODE (gxml_node_get_type ())
#define GXML_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_NODE, GXmlNode))
#define GXML_IS_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_NODE))
#define GXML_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_NODE, GXmlNodeIface))

typedef struct _GXmlNode GXmlNode;
typedef struct _GXmlNodeIface GXmlNodeIface;

#define GXML_TYPE_ELEMENT_LIST (gxml_element_list_get_type ())
#define GXML_ELEMENT_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_ELEMENT_LIST, GXmlElementList))
#define GXML_ELEMENT_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_ELEMENT_LIST, GXmlElementListClass))
#define GXML_IS_ELEMENT_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_ELEMENT_LIST))
#define GXML_IS_ELEMENT_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_ELEMENT_LIST))
#define GXML_ELEMENT_LIST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_ELEMENT_LIST, GXmlElementListClass))

typedef struct _GXmlElementList GXmlElementList;
typedef struct _GXmlElementListClass GXmlElementListClass;

#define GXML_TYPE_NAMESPACE (gxml_namespace_get_type ())
#define GXML_NAMESPACE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_NAMESPACE, GXmlNamespace))
#define GXML_IS_NAMESPACE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_NAMESPACE))
#define GXML_NAMESPACE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_NAMESPACE, GXmlNamespaceIface))

typedef struct _GXmlNamespace GXmlNamespace;
typedef struct _GXmlNamespaceIface GXmlNamespaceIface;

#define GXML_TYPE_NODE_TYPE (gxml_node_type_get_type ())

#define GXML_TYPE_DOCUMENT (gxml_document_get_type ())
#define GXML_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOCUMENT, GXmlDocument))
#define GXML_IS_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOCUMENT))
#define GXML_DOCUMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOCUMENT, GXmlDocumentIface))

typedef struct _GXmlDocument GXmlDocument;
typedef struct _GXmlDocumentIface GXmlDocumentIface;

#define GXML_TYPE_GOM_NODE (gxml_gom_node_get_type ())
#define GXML_GOM_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GOM_NODE, GXmlGomNode))
#define GXML_GOM_NODE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GOM_NODE, GXmlGomNodeClass))
#define GXML_IS_GOM_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GOM_NODE))
#define GXML_IS_GOM_NODE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GOM_NODE))
#define GXML_GOM_NODE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GOM_NODE, GXmlGomNodeClass))

typedef struct _GXmlGomNode GXmlGomNode;
typedef struct _GXmlGomNodeClass GXmlGomNodeClass;
typedef struct _GXmlGomNodePrivate GXmlGomNodePrivate;

#define GXML_TYPE_GOM_NODE_LIST (gxml_gom_node_list_get_type ())
#define GXML_GOM_NODE_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GOM_NODE_LIST, GXmlGomNodeList))
#define GXML_GOM_NODE_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GOM_NODE_LIST, GXmlGomNodeListClass))
#define GXML_IS_GOM_NODE_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GOM_NODE_LIST))
#define GXML_IS_GOM_NODE_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GOM_NODE_LIST))
#define GXML_GOM_NODE_LIST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GOM_NODE_LIST, GXmlGomNodeListClass))

typedef struct _GXmlGomNodeList GXmlGomNodeList;
typedef struct _GXmlGomNodeListClass GXmlGomNodeListClass;

#define GXML_TYPE_GOM_DOCUMENT (gxml_gom_document_get_type ())
#define GXML_GOM_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GOM_DOCUMENT, GXmlGomDocument))
#define GXML_GOM_DOCUMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GOM_DOCUMENT, GXmlGomDocumentClass))
#define GXML_IS_GOM_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GOM_DOCUMENT))
#define GXML_IS_GOM_DOCUMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GOM_DOCUMENT))
#define GXML_GOM_DOCUMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GOM_DOCUMENT, GXmlGomDocumentClass))

typedef struct _GXmlGomDocument GXmlGomDocument;
typedef struct _GXmlGomDocumentClass GXmlGomDocumentClass;
typedef struct _GXmlGomDocumentPrivate GXmlGomDocumentPrivate;

#define GXML_TYPE_GOM_IMPLEMENTATION (gxml_gom_implementation_get_type ())
#define GXML_GOM_IMPLEMENTATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GOM_IMPLEMENTATION, GXmlGomImplementation))
#define GXML_GOM_IMPLEMENTATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GOM_IMPLEMENTATION, GXmlGomImplementationClass))
#define GXML_IS_GOM_IMPLEMENTATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GOM_IMPLEMENTATION))
#define GXML_IS_GOM_IMPLEMENTATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GOM_IMPLEMENTATION))
#define GXML_GOM_IMPLEMENTATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GOM_IMPLEMENTATION, GXmlGomImplementationClass))

typedef struct _GXmlGomImplementation GXmlGomImplementation;
typedef struct _GXmlGomImplementationClass GXmlGomImplementationClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))

#define GXML_TYPE_XPARSER (gxml_xparser_get_type ())
#define GXML_XPARSER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_XPARSER, GXmlXParser))
#define GXML_XPARSER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_XPARSER, GXmlXParserClass))
#define GXML_IS_XPARSER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_XPARSER))
#define GXML_IS_XPARSER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_XPARSER))
#define GXML_XPARSER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_XPARSER, GXmlXParserClass))

typedef struct _GXmlXParser GXmlXParser;
typedef struct _GXmlXParserClass GXmlXParserClass;

#define GXML_TYPE_PARSER (gxml_parser_get_type ())
#define GXML_PARSER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_PARSER, GXmlParser))
#define GXML_IS_PARSER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_PARSER))
#define GXML_PARSER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_PARSER, GXmlParserIface))

typedef struct _GXmlParser GXmlParser;
typedef struct _GXmlParserIface GXmlParserIface;

#define GXML_TYPE_GOM_ELEMENT (gxml_gom_element_get_type ())
#define GXML_GOM_ELEMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GOM_ELEMENT, GXmlGomElement))
#define GXML_GOM_ELEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GOM_ELEMENT, GXmlGomElementClass))
#define GXML_IS_GOM_ELEMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GOM_ELEMENT))
#define GXML_IS_GOM_ELEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GOM_ELEMENT))
#define GXML_GOM_ELEMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GOM_ELEMENT, GXmlGomElementClass))

typedef struct _GXmlGomElement GXmlGomElement;
typedef struct _GXmlGomElementClass GXmlGomElementClass;

#define GXML_TYPE_GDOM_HTML_COLLECTION (gxml_gdom_html_collection_get_type ())
#define GXML_GDOM_HTML_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GDOM_HTML_COLLECTION, GXmlGDomHTMLCollection))
#define GXML_GDOM_HTML_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GDOM_HTML_COLLECTION, GXmlGDomHTMLCollectionClass))
#define GXML_IS_GDOM_HTML_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GDOM_HTML_COLLECTION))
#define GXML_IS_GDOM_HTML_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GDOM_HTML_COLLECTION))
#define GXML_GDOM_HTML_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GDOM_HTML_COLLECTION, GXmlGDomHTMLCollectionClass))

typedef struct _GXmlGDomHTMLCollection GXmlGDomHTMLCollection;
typedef struct _GXmlGDomHTMLCollectionClass GXmlGDomHTMLCollectionClass;

#define GXML_TYPE_GOM_DOCUMENT_FRAGMENT (gxml_gom_document_fragment_get_type ())
#define GXML_GOM_DOCUMENT_FRAGMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GOM_DOCUMENT_FRAGMENT, GXmlGomDocumentFragment))
#define GXML_GOM_DOCUMENT_FRAGMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GOM_DOCUMENT_FRAGMENT, GXmlGomDocumentFragmentClass))
#define GXML_IS_GOM_DOCUMENT_FRAGMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GOM_DOCUMENT_FRAGMENT))
#define GXML_IS_GOM_DOCUMENT_FRAGMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GOM_DOCUMENT_FRAGMENT))
#define GXML_GOM_DOCUMENT_FRAGMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GOM_DOCUMENT_FRAGMENT, GXmlGomDocumentFragmentClass))

typedef struct _GXmlGomDocumentFragment GXmlGomDocumentFragment;
typedef struct _GXmlGomDocumentFragmentClass GXmlGomDocumentFragmentClass;

#define GXML_TYPE_GOM_CHARACTER_DATA (gxml_gom_character_data_get_type ())
#define GXML_GOM_CHARACTER_DATA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GOM_CHARACTER_DATA, GXmlGomCharacterData))
#define GXML_GOM_CHARACTER_DATA_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GOM_CHARACTER_DATA, GXmlGomCharacterDataClass))
#define GXML_IS_GOM_CHARACTER_DATA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GOM_CHARACTER_DATA))
#define GXML_IS_GOM_CHARACTER_DATA_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GOM_CHARACTER_DATA))
#define GXML_GOM_CHARACTER_DATA_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GOM_CHARACTER_DATA, GXmlGomCharacterDataClass))

typedef struct _GXmlGomCharacterData GXmlGomCharacterData;
typedef struct _GXmlGomCharacterDataClass GXmlGomCharacterDataClass;

#define GXML_TYPE_GOM_TEXT (gxml_gom_text_get_type ())
#define GXML_GOM_TEXT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GOM_TEXT, GXmlGomText))
#define GXML_GOM_TEXT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GOM_TEXT, GXmlGomTextClass))
#define GXML_IS_GOM_TEXT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GOM_TEXT))
#define GXML_IS_GOM_TEXT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GOM_TEXT))
#define GXML_GOM_TEXT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GOM_TEXT, GXmlGomTextClass))

typedef struct _GXmlGomText GXmlGomText;
typedef struct _GXmlGomTextClass GXmlGomTextClass;

#define GXML_TYPE_GOM_COMMENT (gxml_gom_comment_get_type ())
#define GXML_GOM_COMMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GOM_COMMENT, GXmlGomComment))
#define GXML_GOM_COMMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GOM_COMMENT, GXmlGomCommentClass))
#define GXML_IS_GOM_COMMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GOM_COMMENT))
#define GXML_IS_GOM_COMMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GOM_COMMENT))
#define GXML_GOM_COMMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GOM_COMMENT, GXmlGomCommentClass))

typedef struct _GXmlGomComment GXmlGomComment;
typedef struct _GXmlGomCommentClass GXmlGomCommentClass;

#define GXML_TYPE_GOM_PROCESSING_INSTRUCTION (gxml_gom_processing_instruction_get_type ())
#define GXML_GOM_PROCESSING_INSTRUCTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GOM_PROCESSING_INSTRUCTION, GXmlGomProcessingInstruction))
#define GXML_GOM_PROCESSING_INSTRUCTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GOM_PROCESSING_INSTRUCTION, GXmlGomProcessingInstructionClass))
#define GXML_IS_GOM_PROCESSING_INSTRUCTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GOM_PROCESSING_INSTRUCTION))
#define GXML_IS_GOM_PROCESSING_INSTRUCTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GOM_PROCESSING_INSTRUCTION))
#define GXML_GOM_PROCESSING_INSTRUCTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GOM_PROCESSING_INSTRUCTION, GXmlGomProcessingInstructionClass))

typedef struct _GXmlGomProcessingInstruction GXmlGomProcessingInstruction;
typedef struct _GXmlGomProcessingInstructionClass GXmlGomProcessingInstructionClass;

#define GXML_TYPE_GDOM_EVENT (gxml_gdom_event_get_type ())
#define GXML_GDOM_EVENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GDOM_EVENT, GXmlGDomEvent))
#define GXML_GDOM_EVENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GDOM_EVENT, GXmlGDomEventClass))
#define GXML_IS_GDOM_EVENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GDOM_EVENT))
#define GXML_IS_GDOM_EVENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GDOM_EVENT))
#define GXML_GDOM_EVENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GDOM_EVENT, GXmlGDomEventClass))

typedef struct _GXmlGDomEvent GXmlGDomEvent;
typedef struct _GXmlGDomEventClass GXmlGDomEventClass;

#define GXML_TYPE_GDOM_CUSTOM_EVENT (gxml_gdom_custom_event_get_type ())
#define GXML_GDOM_CUSTOM_EVENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GDOM_CUSTOM_EVENT, GXmlGDomCustomEvent))
#define GXML_GDOM_CUSTOM_EVENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GDOM_CUSTOM_EVENT, GXmlGDomCustomEventClass))
#define GXML_IS_GDOM_CUSTOM_EVENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GDOM_CUSTOM_EVENT))
#define GXML_IS_GDOM_CUSTOM_EVENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GDOM_CUSTOM_EVENT))
#define GXML_GDOM_CUSTOM_EVENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GDOM_CUSTOM_EVENT, GXmlGDomCustomEventClass))

typedef struct _GXmlGDomCustomEvent GXmlGDomCustomEvent;
typedef struct _GXmlGDomCustomEventClass GXmlGDomCustomEventClass;

#define GXML_TYPE_GDOM_RANGE (gxml_gdom_range_get_type ())
#define GXML_GDOM_RANGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GDOM_RANGE, GXmlGDomRange))
#define GXML_GDOM_RANGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GDOM_RANGE, GXmlGDomRangeClass))
#define GXML_IS_GDOM_RANGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GDOM_RANGE))
#define GXML_IS_GDOM_RANGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GDOM_RANGE))
#define GXML_GDOM_RANGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GDOM_RANGE, GXmlGDomRangeClass))

typedef struct _GXmlGDomRange GXmlGDomRange;
typedef struct _GXmlGDomRangeClass GXmlGDomRangeClass;

#define GXML_TYPE_GDOM_NODE_ITERATOR (gxml_gdom_node_iterator_get_type ())
#define GXML_GDOM_NODE_ITERATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GDOM_NODE_ITERATOR, GXmlGDomNodeIterator))
#define GXML_GDOM_NODE_ITERATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GDOM_NODE_ITERATOR, GXmlGDomNodeIteratorClass))
#define GXML_IS_GDOM_NODE_ITERATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GDOM_NODE_ITERATOR))
#define GXML_IS_GDOM_NODE_ITERATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GDOM_NODE_ITERATOR))
#define GXML_GDOM_NODE_ITERATOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GDOM_NODE_ITERATOR, GXmlGDomNodeIteratorClass))

typedef struct _GXmlGDomNodeIterator GXmlGDomNodeIterator;
typedef struct _GXmlGDomNodeIteratorClass GXmlGDomNodeIteratorClass;

#define GXML_TYPE_GDOM_TREE_WALKER (gxml_gdom_tree_walker_get_type ())
#define GXML_GDOM_TREE_WALKER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GDOM_TREE_WALKER, GXmlGDomTreeWalker))
#define GXML_GDOM_TREE_WALKER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GDOM_TREE_WALKER, GXmlGDomTreeWalkerClass))
#define GXML_IS_GDOM_TREE_WALKER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GDOM_TREE_WALKER))
#define GXML_IS_GDOM_TREE_WALKER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GDOM_TREE_WALKER))
#define GXML_GDOM_TREE_WALKER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GDOM_TREE_WALKER, GXmlGDomTreeWalkerClass))

typedef struct _GXmlGDomTreeWalker GXmlGDomTreeWalker;
typedef struct _GXmlGDomTreeWalkerClass GXmlGDomTreeWalkerClass;
typedef struct _GXmlGomImplementationPrivate GXmlGomImplementationPrivate;

#define GXML_TYPE_GOM_DOCUMENT_TYPE (gxml_gom_document_type_get_type ())
#define GXML_GOM_DOCUMENT_TYPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GOM_DOCUMENT_TYPE, GXmlGomDocumentType))
#define GXML_GOM_DOCUMENT_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GOM_DOCUMENT_TYPE, GXmlGomDocumentTypeClass))
#define GXML_IS_GOM_DOCUMENT_TYPE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GOM_DOCUMENT_TYPE))
#define GXML_IS_GOM_DOCUMENT_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GOM_DOCUMENT_TYPE))
#define GXML_GOM_DOCUMENT_TYPE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GOM_DOCUMENT_TYPE, GXmlGomDocumentTypeClass))

typedef struct _GXmlGomDocumentType GXmlGomDocumentType;
typedef struct _GXmlGomDocumentTypeClass GXmlGomDocumentTypeClass;

#define GXML_TYPE_GNODE (gxml_gnode_get_type ())
#define GXML_GNODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GNODE, GXmlGNode))
#define GXML_GNODE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GNODE, GXmlGNodeClass))
#define GXML_IS_GNODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GNODE))
#define GXML_IS_GNODE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GNODE))
#define GXML_GNODE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GNODE, GXmlGNodeClass))

typedef struct _GXmlGNode GXmlGNode;
typedef struct _GXmlGNodeClass GXmlGNodeClass;

#define GXML_TYPE_GDOCUMENT (gxml_gdocument_get_type ())
#define GXML_GDOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GDOCUMENT, GXmlGDocument))
#define GXML_GDOCUMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GDOCUMENT, GXmlGDocumentClass))
#define GXML_IS_GDOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GDOCUMENT))
#define GXML_IS_GDOCUMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GDOCUMENT))
#define GXML_GDOCUMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GDOCUMENT, GXmlGDocumentClass))

typedef struct _GXmlGDocument GXmlGDocument;
typedef struct _GXmlGDocumentClass GXmlGDocumentClass;

#define GXML_TYPE_HTML_DOCUMENT (gxml_html_document_get_type ())
#define GXML_HTML_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_HTML_DOCUMENT, GXmlHtmlDocument))
#define GXML_HTML_DOCUMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_HTML_DOCUMENT, GXmlHtmlDocumentClass))
#define GXML_IS_HTML_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_HTML_DOCUMENT))
#define GXML_IS_HTML_DOCUMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_HTML_DOCUMENT))
#define GXML_HTML_DOCUMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_HTML_DOCUMENT, GXmlHtmlDocumentClass))

typedef struct _GXmlHtmlDocument GXmlHtmlDocument;
typedef struct _GXmlHtmlDocumentClass GXmlHtmlDocumentClass;
typedef struct _GXmlGomDocumentTypePrivate GXmlGomDocumentTypePrivate;
typedef struct _GXmlGomDocumentFragmentPrivate GXmlGomDocumentFragmentPrivate;

typedef enum  {
	GXML_DOM_EVENT_PHASE_NONE = 0,
	GXML_DOM_EVENT_PHASE_CAPTURING_PHASE,
	GXML_DOM_EVENT_PHASE_AT_TARGET,
	GXML_DOM_EVENT_PHASE_BUBBLING_PHASE
} GXmlDomEventPhase;

struct _GXmlDomEventIface {
	GTypeInterface parent_iface;
	void (*stop_propagation) (GXmlDomEvent* self);
	void (*stop_immediate_propagation) (GXmlDomEvent* self);
	void (*prevent_default) (GXmlDomEvent* self);
	void (*init_event) (GXmlDomEvent* self, const gchar* type, gboolean bubbles, gboolean cancelable);
	const gchar* (*get_etype) (GXmlDomEvent* self);
	GXmlDomEventTarget* (*get_event_target) (GXmlDomEvent* self);
	GXmlDomEventTarget* (*get_current_target) (GXmlDomEvent* self);
	gboolean (*get_bubbles) (GXmlDomEvent* self);
	gboolean (*get_cancelable) (GXmlDomEvent* self);
	gboolean (*get_is_trusted) (GXmlDomEvent* self);
	GXmlDomTimeStamp* (*get_time_stamp) (GXmlDomEvent* self);
	gboolean (*get_default_prevented) (GXmlDomEvent* self);
	GXmlDomEventPhase (*get_event_phase) (GXmlDomEvent* self);
};

struct _GXmlDomEventListenerIface {
	GTypeInterface parent_iface;
	void (*handle_event) (GXmlDomEventListener* self, GXmlDomEvent* event);
};

struct _GXmlDomEventTargetIface {
	GTypeInterface parent_iface;
	void (*add_event_listener) (GXmlDomEventTarget* self, const gchar* type, GXmlDomEventListener* callback, gboolean capture);
	void (*remove_event_listener) (GXmlDomEventTarget* self, const gchar* type, GXmlDomEventListener* callback, gboolean capture);
	gboolean (*dispatch_event) (GXmlDomEventTarget* self, GXmlDomEvent* event, GError** error);
};

typedef enum  {
	GXML_DOM_NODE_DOCUMENT_POSITION_NONE = 1 << 0,
	GXML_DOM_NODE_DOCUMENT_POSITION_DISCONNECTED = 1 << 1,
	GXML_DOM_NODE_DOCUMENT_POSITION_PRECEDING = 1 << 2,
	GXML_DOM_NODE_DOCUMENT_POSITION_FOLLOWING = 1 << 3,
	GXML_DOM_NODE_DOCUMENT_POSITION_CONTAINS = 1 << 4,
	GXML_DOM_NODE_DOCUMENT_POSITION_CONTAINED_BY = 1 << 5,
	GXML_DOM_NODE_DOCUMENT_POSITION_IMPLEMENTATION_SPECIFIC = 1 << 6
} GXmlDomNodeDocumentPosition;

typedef enum  {
	GXML_DOM_NODE_NODE_TYPE_INVALID = 0,
	GXML_DOM_NODE_NODE_TYPE_ELEMENT_NODE = 1,
	GXML_DOM_NODE_NODE_TYPE_ATTRIBUTE_NODE,
	GXML_DOM_NODE_NODE_TYPE_TEXT_NODE,
	GXML_DOM_NODE_NODE_TYPE_CDATA_SECTION_NODE,
	GXML_DOM_NODE_NODE_TYPE_ENTITY_REFERENCE_NODE,
	GXML_DOM_NODE_NODE_TYPE_ENTITY_NODE,
	GXML_DOM_NODE_NODE_TYPE_PROCESSING_INSTRUCTION_NODE,
	GXML_DOM_NODE_NODE_TYPE_COMMENT_NODE,
	GXML_DOM_NODE_NODE_TYPE_DOCUMENT_NODE,
	GXML_DOM_NODE_NODE_TYPE_DOCUMENT_TYPE_NODE,
	GXML_DOM_NODE_NODE_TYPE_DOCUMENT_FRAGMENT_NODE,
	GXML_DOM_NODE_NODE_TYPE_NOTATION_NODE
} GXmlDomNodeNodeType;

struct _GXmlDomChildNodeIface {
	GTypeInterface parent_iface;
	void (*remove) (GXmlDomChildNode* self);
};

struct _GXmlDomNonDocumentTypeChildNodeIface {
	GTypeInterface parent_iface;
	GXmlDomElement* (*get_previous_element_sibling) (GXmlDomNonDocumentTypeChildNode* self);
	GXmlDomElement* (*get_next_element_sibling) (GXmlDomNonDocumentTypeChildNode* self);
};

struct _GXmlDomHTMLCollectionIface {
	GTypeInterface parent_iface;
	GXmlDomElement* (*get_element) (GXmlDomHTMLCollection* self, gint index);
	GXmlDomElement** (*to_array) (GXmlDomHTMLCollection* self, int* result_length1);
	GXmlDomElement* (*item) (GXmlDomHTMLCollection* self, gint index);
	GXmlDomElement* (*named_item) (GXmlDomHTMLCollection* self, const gchar* name);
	gint (*get_length) (GXmlDomHTMLCollection* self);
};

struct _GXmlDomTokenListIface {
	GTypeInterface parent_iface;
	gchar* (*item) (GXmlDomTokenList* self, gint index);
	gboolean (*contains) (GXmlDomTokenList* self, const gchar* token, GError** error);
	void (*add) (GXmlDomTokenList* self, gchar** tokens, int tokens_length1, GError** error);
	void (*remove) (GXmlDomTokenList* self, gchar** tokens, int tokens_length1);
	gboolean (*toggle) (GXmlDomTokenList* self, const gchar* token, gboolean force, gboolean _auto_, GError** error);
	gchar* (*to_string) (GXmlDomTokenList* self);
	gint (*get_length) (GXmlDomTokenList* self);
};

struct _GXmlDomNamedNodeMapIface {
	GTypeInterface parent_iface;
	GXmlDomNode* (*item) (GXmlDomNamedNodeMap* self, gint index);
	GXmlDomNode* (*get_named_item) (GXmlDomNamedNodeMap* self, const gchar* name);
	GXmlDomNode* (*set_named_item) (GXmlDomNamedNodeMap* self, GXmlDomNode* node, GError** error);
	GXmlDomNode* (*remove_named_item) (GXmlDomNamedNodeMap* self, const gchar* name, GError** error);
	GXmlDomNode* (*remove_named_item_ns) (GXmlDomNamedNodeMap* self, const gchar* namespace_uri, const gchar* localName, GError** error);
	GXmlDomNode* (*get_named_item_ns) (GXmlDomNamedNodeMap* self, const gchar* namespace_uri, const gchar* local_name, GError** error);
	GXmlDomNode* (*set_named_item_ns) (GXmlDomNamedNodeMap* self, GXmlDomNode* node, GError** error);
	gint (*get_length) (GXmlDomNamedNodeMap* self);
};

struct _GXmlDomElementIface {
	GTypeInterface parent_iface;
	gchar* (*get_attribute) (GXmlDomElement* self, const gchar* name);
	gchar* (*get_attribute_ns) (GXmlDomElement* self, const gchar* namespace, const gchar* local_name);
	void (*set_attribute) (GXmlDomElement* self, const gchar* name, const gchar* value, GError** error);
	void (*set_attribute_ns) (GXmlDomElement* self, const gchar* namespace, const gchar* name, const gchar* value, GError** error);
	void (*remove_attribute) (GXmlDomElement* self, const gchar* name);
	void (*remove_attribute_ns) (GXmlDomElement* self, const gchar* namespace, const gchar* local_name);
	gboolean (*has_attribute) (GXmlDomElement* self, const gchar* name);
	gboolean (*has_attribute_ns) (GXmlDomElement* self, const gchar* namespace, const gchar* local_name);
	GXmlDomHTMLCollection* (*get_elements_by_tag_name) (GXmlDomElement* self, const gchar* local_name);
	GXmlDomHTMLCollection* (*get_elements_by_tag_name_ns) (GXmlDomElement* self, const gchar* namespace, const gchar* local_name);
	GXmlDomHTMLCollection* (*get_elements_by_class_name) (GXmlDomElement* self, const gchar* class_names);
	gchar* (*get_namespace_uri) (GXmlDomElement* self);
	gchar* (*get_prefix) (GXmlDomElement* self);
	gchar* (*get_local_name) (GXmlDomElement* self);
	gchar* (*get_tag_name) (GXmlDomElement* self);
	gchar* (*get_id) (GXmlDomElement* self);
	void (*set_id) (GXmlDomElement* self, const gchar* value);
	gchar* (*get_class_name) (GXmlDomElement* self);
	void (*set_class_name) (GXmlDomElement* self, const gchar* value);
	GXmlDomTokenList* (*get_class_list) (GXmlDomElement* self);
	GXmlDomNamedNodeMap* (*get_attributes) (GXmlDomElement* self);
};

struct _GXmlDomNodeListIface {
	GTypeInterface parent_iface;
	GXmlDomNode* (*item) (GXmlDomNodeList* self, gint index);
	gint (*get_length) (GXmlDomNodeList* self);
};

struct _GXmlDomParentNodeIface {
	GTypeInterface parent_iface;
	GXmlDomElement* (*query_selector) (GXmlDomParentNode* self, const gchar* selectors, GError** error);
	GXmlDomNodeList* (*query_selector_all) (GXmlDomParentNode* self, const gchar* selectors, GError** error);
	GXmlDomElementList* (*get_elements_by_property_value) (GXmlDomParentNode* self, const gchar* property, const gchar* value);
	GXmlDomHTMLCollection* (*get_children) (GXmlDomParentNode* self);
	GXmlDomElement* (*get_first_element_child) (GXmlDomParentNode* self);
	GXmlDomElement* (*get_last_element_child) (GXmlDomParentNode* self);
	gint (*get_child_element_count) (GXmlDomParentNode* self);
};

struct _GXmlDomNonElementParentNodeIface {
	GTypeInterface parent_iface;
	GXmlDomElement* (*get_element_by_id) (GXmlDomNonElementParentNode* self, const gchar* element_id, GError** error);
};

struct _GXmlDomDocumentFragmentIface {
	GTypeInterface parent_iface;
};

struct _GXmlDomCharacterDataIface {
	GTypeInterface parent_iface;
	gchar* (*substring_data) (GXmlDomCharacterData* self, gint offset, gint count, GError** error);
	void (*append_data) (GXmlDomCharacterData* self, const gchar* data);
	void (*insert_data) (GXmlDomCharacterData* self, gint offset, const gchar* data, GError** error);
	void (*delete_data) (GXmlDomCharacterData* self, gint offset, gint count, GError** error);
	void (*replace_data) (GXmlDomCharacterData* self, gint offset, gint count, const gchar* data, GError** error);
	gchar* (*get_data) (GXmlDomCharacterData* self);
	void (*set_data) (GXmlDomCharacterData* self, const gchar* value);
	gint (*get_length) (GXmlDomCharacterData* self);
};

struct _GXmlDomTextIface {
	GTypeInterface parent_iface;
	GXmlDomText* (*split_text) (GXmlDomText* self, gint offset, GError** error);
	gchar* (*get_whole_text) (GXmlDomText* self);
};

struct _GXmlDomCommentIface {
	GTypeInterface parent_iface;
};

struct _GXmlDomProcessingInstructionIface {
	GTypeInterface parent_iface;
	gchar* (*get_target) (GXmlDomProcessingInstruction* self);
};

typedef enum  {
	GXML_DOM_RANGE_BOUNDARY_POINTS_START_TO_START = 0,
	GXML_DOM_RANGE_BOUNDARY_POINTS_START_TO_END,
	GXML_DOM_RANGE_BOUNDARY_POINTS_END_TO_END,
	GXML_DOM_RANGE_BOUNDARY_POINTS_END_TO_START
} GXmlDomRangeBoundaryPoints;

struct _GXmlDomRangeIface {
	GTypeInterface parent_iface;
	void (*set_start) (GXmlDomRange* self, GXmlDomNode* node, gint offset, GError** error);
	void (*set_end) (GXmlDomRange* self, GXmlDomNode* node, gint offset, GError** error);
	void (*set_start_before) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	void (*set_start_after) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	void (*set_end_before) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	void (*set_end_after) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	void (*collapse) (GXmlDomRange* self, gboolean to_start, GError** error);
	void (*select_node) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	void (*select_node_contents) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	gint (*compare_boundary_points) (GXmlDomRange* self, GXmlDomRangeBoundaryPoints how, GXmlDomRange* sourceRange, GError** error);
	void (*delete_contents) (GXmlDomRange* self, GError** error);
	GXmlDomDocumentFragment* (*extract_contents) (GXmlDomRange* self, GError** error);
	GXmlDomDocumentFragment* (*clone_contents) (GXmlDomRange* self, GError** error);
	void (*insert_node) (GXmlDomRange* self, GXmlDomNode* node);
	void (*surround_contents) (GXmlDomRange* self, GXmlDomNode* newParent);
	GXmlDomRange* (*clone_range) (GXmlDomRange* self);
	void (*detach) (GXmlDomRange* self);
	gboolean (*is_point_in_range) (GXmlDomRange* self, GXmlDomNode* node, gint offset);
	gshort (*compare_point) (GXmlDomRange* self, GXmlDomNode* node, gint offset);
	gboolean (*intersects_node) (GXmlDomRange* self, GXmlDomNode* node);
	gchar* (*to_string) (GXmlDomRange* self);
	GXmlDomNode* (*get_start_container) (GXmlDomRange* self);
	gint (*get_start_offset) (GXmlDomRange* self);
	GXmlDomNode* (*get_end_container) (GXmlDomRange* self);
	gint (*get_end_offset) (GXmlDomRange* self);
	gboolean (*get_collapsed) (GXmlDomRange* self);
	GXmlDomNode* (*get_common_ancestor_container) (GXmlDomRange* self);
};

struct _GXmlDomNodeIteratorIface {
	GTypeInterface parent_iface;
	GXmlDomNode* (*next_node) (GXmlDomNodeIterator* self);
	GXmlDomNode* (*previous_node) (GXmlDomNodeIterator* self);
	void (*detach) (GXmlDomNodeIterator* self);
	GXmlDomNode* (*get_root) (GXmlDomNodeIterator* self);
	GXmlDomNode* (*get_reference_node) (GXmlDomNodeIterator* self);
	gboolean (*get_pointer_before_reference_node) (GXmlDomNodeIterator* self);
	gint (*get_what_to_show) (GXmlDomNodeIterator* self);
	GXmlDomNodeFilter* (*get_filter) (GXmlDomNodeIterator* self);
};

struct _GXmlDomTreeWalkerIface {
	GTypeInterface parent_iface;
	GXmlDomNode* (*parentNode) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*firstChild) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*lastChild) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*previousSibling) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*nextSibling) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*previousNode) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*nextNode) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*get_root) (GXmlDomTreeWalker* self);
	gint (*get_what_to_show) (GXmlDomTreeWalker* self);
	GXmlDomNodeFilter* (*get_filter) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*get_current_node) (GXmlDomTreeWalker* self);
};

struct _GXmlDomDocumentTypeIface {
	GTypeInterface parent_iface;
	const gchar* (*get_name) (GXmlDomDocumentType* self);
	const gchar* (*get_public_id) (GXmlDomDocumentType* self);
	const gchar* (*get_system_id) (GXmlDomDocumentType* self);
};

struct _GXmlDomXMLDocumentIface {
	GTypeInterface parent_iface;
};

struct _GXmlNamespaceIface {
	GTypeInterface parent_iface;
	gchar* (*get_uri) (GXmlNamespace* self);
	gchar* (*get_prefix) (GXmlNamespace* self);
};

typedef enum  {
	GXML_NODE_TYPE_INVALID = 0,
	GXML_NODE_TYPE_ELEMENT = 1,
	GXML_NODE_TYPE_ATTRIBUTE,
	GXML_NODE_TYPE_TEXT,
	GXML_NODE_TYPE_CDATA_SECTION,
	GXML_NODE_TYPE_ENTITY_REFERENCE,
	GXML_NODE_TYPE_ENTITY,
	GXML_NODE_TYPE_PROCESSING_INSTRUCTION,
	GXML_NODE_TYPE_COMMENT,
	GXML_NODE_TYPE_DOCUMENT,
	GXML_NODE_TYPE_DOCUMENT_TYPE,
	GXML_NODE_TYPE_DOCUMENT_FRAGMENT,
	GXML_NODE_TYPE_NOTATION
} GXmlNodeType;

struct _GXmlNodeIface {
	GTypeInterface parent_iface;
	GXmlNode* (*get) (GXmlNode* self, const gchar* key);
	GXmlElementList* (*get_elements_by_property_value) (GXmlNode* self, const gchar* property, const gchar* value);
	GXmlElementList* (*get_elements_by_name) (GXmlNode* self, const gchar* name);
	GXmlElementList* (*get_elements_by_name_ns) (GXmlNode* self, const gchar* name, const gchar* ns);
	gchar* (*to_string) (GXmlNode* self);
	gboolean (*set_namespace) (GXmlNode* self, const gchar* uri, const gchar* prefix);
	gchar* (*ns_prefix) (GXmlNode* self);
	gchar* (*ns_uri) (GXmlNode* self);
	GeeList* (*get_namespaces) (GXmlNode* self);
	GeeBidirList* (*get_children_nodes) (GXmlNode* self);
	GeeMap* (*get_attrs) (GXmlNode* self);
	gchar* (*get_name) (GXmlNode* self);
	gchar* (*get_value) (GXmlNode* self);
	void (*set_value) (GXmlNode* self, const gchar* value);
	GXmlNodeType (*get_type_node) (GXmlNode* self);
	GXmlDocument* (*get_document) (GXmlNode* self);
	GXmlNode* (*get_parent) (GXmlNode* self);
};

struct _GXmlDocumentIface {
	GTypeInterface parent_iface;
	GXmlNode* (*create_element) (GXmlDocument* self, const gchar* name, GError** error);
	GXmlNode* (*create_text) (GXmlDocument* self, const gchar* text);
	GXmlNode* (*create_comment) (GXmlDocument* self, const gchar* text);
	GXmlNode* (*create_cdata) (GXmlDocument* self, const gchar* text);
	GXmlNode* (*create_pi) (GXmlDocument* self, const gchar* target, const gchar* data);
	gboolean (*save) (GXmlDocument* self, GCancellable* cancellable, GError** error);
	gboolean (*save_as) (GXmlDocument* self, GFile* f, GCancellable* cancellable, GError** error);
	gboolean (*get_indent) (GXmlDocument* self);
	void (*set_indent) (GXmlDocument* self, gboolean value);
	gboolean (*get_ns_top) (GXmlDocument* self);
	void (*set_ns_top) (GXmlDocument* self, gboolean value);
	gboolean (*get_prefix_default_ns) (GXmlDocument* self);
	void (*set_prefix_default_ns) (GXmlDocument* self, gboolean value);
	gboolean (*get_backup) (GXmlDocument* self);
	void (*set_backup) (GXmlDocument* self, gboolean value);
	GXmlNode* (*get_root) (GXmlDocument* self);
	GFile* (*get_file) (GXmlDocument* self);
	void (*set_file) (GXmlDocument* self, GFile* value);
};

struct _GXmlDomImplementationIface {
	GTypeInterface parent_iface;
	GXmlDomDocumentType* (*create_document_type) (GXmlDomImplementation* self, const gchar* qualified_name, const gchar* public_id, const gchar* system_id, GError** error);
	GXmlDomXMLDocument* (*create_document) (GXmlDomImplementation* self, const gchar* nspace, const gchar* qualified_name, GXmlDomDocumentType* doctype, GError** error);
	GXmlDocument* (*create_html_document) (GXmlDomImplementation* self, const gchar* title);
	gboolean (*has_feature) (GXmlDomImplementation* self);
};

struct _GXmlDomDocumentIface {
	GTypeInterface parent_iface;
	GXmlDomHTMLCollection* (*get_elements_by_tag_name) (GXmlDomDocument* self, const gchar* local_name);
	GXmlDomHTMLCollection* (*get_elements_by_tag_name_ns) (GXmlDomDocument* self, const gchar* namespace, const gchar* local_name);
	GXmlDomHTMLCollection* (*get_elements_by_class_name) (GXmlDomDocument* self, const gchar* classNames);
	GXmlDomElement* (*create_element) (GXmlDomDocument* self, const gchar* local_name, GError** error);
	GXmlDomElement* (*create_element_ns) (GXmlDomDocument* self, const gchar* namespace, const gchar* qualified_name, GError** error);
	GXmlDomDocumentFragment* (*create_document_fragment) (GXmlDomDocument* self);
	GXmlDomText* (*create_text_node) (GXmlDomDocument* self, const gchar* data, GError** error);
	GXmlDomComment* (*create_comment) (GXmlDomDocument* self, const gchar* data, GError** error);
	GXmlDomProcessingInstruction* (*create_processing_instruction) (GXmlDomDocument* self, const gchar* target, const gchar* data, GError** error);
	GXmlDomNode* (*import_node) (GXmlDomDocument* self, GXmlDomNode* node, gboolean deep, GError** error);
	GXmlDomNode* (*adopt_node) (GXmlDomDocument* self, GXmlDomNode* node, GError** error);
	GXmlDomEvent* (*create_event) (GXmlDomDocument* self, const gchar* interface, GError** error);
	GXmlDomRange* (*create_range) (GXmlDomDocument* self);
	GXmlDomNodeIterator* (*create_node_iterator) (GXmlDomDocument* self, GXmlDomNode* root, gint whatToShow, GXmlDomNodeFilter* filter);
	GXmlDomTreeWalker* (*create_tree_walker) (GXmlDomDocument* self, GXmlDomNode* root, gint what_to_show, GXmlDomNodeFilter* filter);
	GXmlDomImplementation* (*get_implementation) (GXmlDomDocument* self);
	const gchar* (*get_url) (GXmlDomDocument* self);
	const gchar* (*get_document_uri) (GXmlDomDocument* self);
	const gchar* (*get_origin) (GXmlDomDocument* self);
	const gchar* (*get_compat_mode) (GXmlDomDocument* self);
	const gchar* (*get_character_set) (GXmlDomDocument* self);
	const gchar* (*get_content_type) (GXmlDomDocument* self);
	GXmlDomDocumentType* (*get_doctype) (GXmlDomDocument* self);
	GXmlDomElement* (*get_document_element) (GXmlDomDocument* self);
};

struct _GXmlDomNodeIface {
	GTypeInterface parent_iface;
	gboolean (*has_child_nodes) (GXmlDomNode* self);
	void (*normalize) (GXmlDomNode* self);
	gboolean (*is_equal_node) (GXmlDomNode* self, GXmlDomNode* node);
	GXmlDomNodeDocumentPosition (*compare_document_position) (GXmlDomNode* self, GXmlDomNode* other);
	gboolean (*contains) (GXmlDomNode* self, GXmlDomNode* other);
	gchar* (*lookup_prefix) (GXmlDomNode* self, const gchar* nspace);
	gchar* (*lookup_namespace_uri) (GXmlDomNode* self, const gchar* prefix);
	gboolean (*is_default_namespace) (GXmlDomNode* self, const gchar* nspace);
	GXmlDomNode* (*insert_before) (GXmlDomNode* self, GXmlDomNode* node, GXmlDomNode* child, GError** error);
	GXmlDomNode* (*append_child) (GXmlDomNode* self, GXmlDomNode* node, GError** error);
	GXmlDomNode* (*replace_child) (GXmlDomNode* self, GXmlDomNode* node, GXmlDomNode* child, GError** error);
	GXmlDomNode* (*remove_child) (GXmlDomNode* self, GXmlDomNode* child, GError** error);
	GXmlDomNode* (*clone_node) (GXmlDomNode* self, gboolean deep, GError** error);
	GXmlDomNodeNodeType (*get_node_type) (GXmlDomNode* self);
	gchar* (*get_node_name) (GXmlDomNode* self);
	const gchar* (*get_base_uri) (GXmlDomNode* self);
	GXmlDomDocument* (*get_owner_document) (GXmlDomNode* self);
	void (*set_owner_document) (GXmlDomNode* self, GXmlDomDocument* value);
	GXmlDomNode* (*get_parent_node) (GXmlDomNode* self);
	GXmlDomElement* (*get_parent_element) (GXmlDomNode* self);
	GXmlDomNodeList* (*get_child_nodes) (GXmlDomNode* self);
	GXmlDomNode* (*get_first_child) (GXmlDomNode* self);
	GXmlDomNode* (*get_last_child) (GXmlDomNode* self);
	GXmlDomNode* (*get_previous_sibling) (GXmlDomNode* self);
	GXmlDomNode* (*get_next_sibling) (GXmlDomNode* self);
	gchar* (*get_node_value) (GXmlDomNode* self);
	void (*set_node_value) (GXmlDomNode* self, const gchar* value);
	gchar* (*get_text_content) (GXmlDomNode* self);
	void (*set_text_content) (GXmlDomNode* self, const gchar* value);
};

struct _GXmlGomNode {
	GObject parent_instance;
	GXmlGomNodePrivate * priv;
	gchar* _local_name;
	gchar* _prefix;
	gchar* _base_uri;
	gchar* _node_value;
	GXmlDomNode* _parent;
	GXmlDomNodeNodeType _node_type;
	GXmlGomNodeList* _child_nodes;
	GXmlDomDocument* _document;
};

struct _GXmlGomNodeClass {
	GObjectClass parent_class;
};

struct _GXmlGomDocument {
	GXmlGomNode parent_instance;
	GXmlGomDocumentPrivate * priv;
	GXmlDomImplementation* _implementation;
	gchar* _url;
	gchar* _origin;
	gchar* _compat_mode;
	gchar* _character_set;
	gchar* _content_type;
	GXmlDomEvent* _constructor;
};

struct _GXmlGomDocumentClass {
	GXmlGomNodeClass parent_class;
};

struct _GXmlParserIface {
	GTypeInterface parent_iface;
	void (*write_file) (GXmlParser* self, GFile* file, GCancellable* cancellable, GError** error);
	gchar* (*write_string) (GXmlParser* self, GError** error);
	void (*write_stream) (GXmlParser* self, GOutputStream* stream, GCancellable* cancellable, GError** error);
	void (*read_file) (GXmlParser* self, GFile* file, GCancellable* cancellable, GError** error);
	void (*read_stream) (GXmlParser* self, GInputStream* stream, GCancellable* cancellable, GError** error);
	void (*read_string) (GXmlParser* self, const gchar* str, GCancellable* cancellable, GError** error);
	gboolean (*get_backup) (GXmlParser* self);
	void (*set_backup) (GXmlParser* self, gboolean value);
	gboolean (*get_indent) (GXmlParser* self);
	void (*set_indent) (GXmlParser* self, gboolean value);
	GXmlDomNode* (*get_node) (GXmlParser* self);
};

typedef enum  {
	GXML_DOM_ERROR_INDEX_SIZE_ERROR = 1,
	GXML_DOM_ERROR_DOMSTRING_SIZE_ERROR,
	GXML_DOM_ERROR_HIERARCHY_REQUEST_ERROR,
	GXML_DOM_ERROR_WRONG_DOCUMENT_ERROR,
	GXML_DOM_ERROR_INVALID_CHARACTER_ERROR,
	GXML_DOM_ERROR_NO_DATA_ALLOWED_ERROR,
	GXML_DOM_ERROR_NO_MODIFICATION_ALLOWED_ERROR,
	GXML_DOM_ERROR_NOT_FOUND_ERROR,
	GXML_DOM_ERROR_NOT_SUPPORTED_ERROR,
	GXML_DOM_ERROR_INUSE_ATTRIBUTE_ERROR,
	GXML_DOM_ERROR_INVALID_STATE_ERROR,
	GXML_DOM_ERROR_SYNTAX_ERROR,
	GXML_DOM_ERROR_INVALID_MODIFICATION_ERROR,
	GXML_DOM_ERROR_NAMESPACE_ERROR,
	GXML_DOM_ERROR_INVALID_ACCESS_ERROR,
	GXML_DOM_ERROR_VALIDATION_ERROR,
	GXML_DOM_ERROR_TYPE_MISMATCH_ERROR,
	GXML_DOM_ERROR_SECURITY_ERROR,
	GXML_DOM_ERROR_NETWORK_ERROR,
	GXML_DOM_ERROR_ABORT_ERROR,
	GXML_DOM_ERROR_URL_MISMATCH_ERROR,
	GXML_DOM_ERROR_QUOTA_EXCEEDED_ERROR,
	GXML_DOM_ERROR_TIME_OUT_ERROR,
	GXML_DOM_ERROR_INVALID_NODE_TYPE_ERROR,
	GXML_DOM_ERROR_DATA_CLONE_ERROR
} GXmlDomError;
#define GXML_DOM_ERROR gxml_dom_error_quark ()
struct _GXmlGomImplementation {
	GObject parent_instance;
	GXmlGomImplementationPrivate * priv;
};

struct _GXmlGomImplementationClass {
	GObjectClass parent_class;
};

struct _GXmlGomDocumentType {
	GXmlGomNode parent_instance;
	GXmlGomDocumentTypePrivate * priv;
	gchar* _name;
	gchar* _public_id;
	gchar* _system_id;
};

struct _GXmlGomDocumentTypeClass {
	GXmlGomNodeClass parent_class;
};

struct _GXmlGomDocumentFragment {
	GXmlGomNode parent_instance;
	GXmlGomDocumentFragmentPrivate * priv;
};

struct _GXmlGomDocumentFragmentClass {
	GXmlGomNodeClass parent_class;
};


static gpointer gxml_gom_document_parent_class = NULL;
static GXmlDomParentNodeIface* gxml_gom_document_gxml_dom_parent_node_parent_iface = NULL;
static GXmlDomNonElementParentNodeIface* gxml_gom_document_gxml_dom_non_element_parent_node_parent_iface = NULL;
static GXmlDomDocumentIface* gxml_gom_document_gxml_dom_document_parent_iface = NULL;
static GXmlDomXMLDocumentIface* gxml_gom_document_gxml_dom_xml_document_parent_iface = NULL;
static gpointer gxml_gom_implementation_parent_class = NULL;
static GXmlDomImplementationIface* gxml_gom_implementation_gxml_dom_implementation_parent_iface = NULL;
static gpointer gxml_gom_document_type_parent_class = NULL;
static GXmlDomNodeIface* gxml_gom_document_type_gxml_dom_node_parent_iface = NULL;
static GXmlDomChildNodeIface* gxml_gom_document_type_gxml_dom_child_node_parent_iface = NULL;
static GXmlDomDocumentTypeIface* gxml_gom_document_type_gxml_dom_document_type_parent_iface = NULL;
static gpointer gxml_gom_document_fragment_parent_class = NULL;
static GXmlDomParentNodeIface* gxml_gom_document_fragment_gxml_dom_parent_node_parent_iface = NULL;
static GXmlDomNonElementParentNodeIface* gxml_gom_document_fragment_gxml_dom_non_element_parent_node_parent_iface = NULL;
static GXmlDomDocumentFragmentIface* gxml_gom_document_fragment_gxml_dom_document_fragment_parent_iface = NULL;

GType gxml_dom_time_stamp_get_type (void) G_GNUC_CONST;
GType gxml_dom_event_phase_get_type (void) G_GNUC_CONST;
GType gxml_dom_event_get_type (void) G_GNUC_CONST;
GType gxml_dom_event_listener_get_type (void) G_GNUC_CONST;
GType gxml_dom_event_target_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_document_position_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_node_type_get_type (void) G_GNUC_CONST;
GType gxml_dom_child_node_get_type (void) G_GNUC_CONST;
GType gxml_dom_non_document_type_child_node_get_type (void) G_GNUC_CONST;
GType gxml_dom_html_collection_get_type (void) G_GNUC_CONST;
GType gxml_dom_token_list_get_type (void) G_GNUC_CONST;
GType gxml_dom_named_node_map_get_type (void) G_GNUC_CONST;
GType gxml_dom_element_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_list_get_type (void) G_GNUC_CONST;
GType gxml_dom_element_list_get_type (void) G_GNUC_CONST;
GType gxml_dom_parent_node_get_type (void) G_GNUC_CONST;
GType gxml_dom_non_element_parent_node_get_type (void) G_GNUC_CONST;
GType gxml_dom_document_fragment_get_type (void) G_GNUC_CONST;
GType gxml_dom_character_data_get_type (void) G_GNUC_CONST;
GType gxml_dom_text_get_type (void) G_GNUC_CONST;
GType gxml_dom_comment_get_type (void) G_GNUC_CONST;
GType gxml_dom_processing_instruction_get_type (void) G_GNUC_CONST;
GType gxml_dom_range_boundary_points_get_type (void) G_GNUC_CONST;
GType gxml_dom_range_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_filter_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_iterator_get_type (void) G_GNUC_CONST;
GType gxml_dom_tree_walker_get_type (void) G_GNUC_CONST;
GType gxml_dom_document_type_get_type (void) G_GNUC_CONST;
GType gxml_dom_xml_document_get_type (void) G_GNUC_CONST;
GType gxml_element_list_get_type (void) G_GNUC_CONST;
GType gxml_namespace_get_type (void) G_GNUC_CONST;
GType gxml_node_type_get_type (void) G_GNUC_CONST;
GType gxml_node_get_type (void) G_GNUC_CONST;
GType gxml_document_get_type (void) G_GNUC_CONST;
GType gxml_dom_implementation_get_type (void) G_GNUC_CONST;
GType gxml_dom_document_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_get_type (void) G_GNUC_CONST;
GType gxml_gom_node_get_type (void) G_GNUC_CONST;
GType gxml_gom_node_list_get_type (void) G_GNUC_CONST;
GType gxml_gom_document_get_type (void) G_GNUC_CONST;
enum  {
	GXML_GOM_DOCUMENT_DUMMY_PROPERTY,
	GXML_GOM_DOCUMENT_IMPLEMENTATION,
	GXML_GOM_DOCUMENT_URL,
	GXML_GOM_DOCUMENT_DOCUMENT_URI,
	GXML_GOM_DOCUMENT_ORIGIN,
	GXML_GOM_DOCUMENT_COMPAT_MODE,
	GXML_GOM_DOCUMENT_CHARACTER_SET,
	GXML_GOM_DOCUMENT_CONTENT_TYPE,
	GXML_GOM_DOCUMENT_DOCTYPE,
	GXML_GOM_DOCUMENT_DOCUMENT_ELEMENT,
	GXML_GOM_DOCUMENT_CHILDREN,
	GXML_GOM_DOCUMENT_FIRST_ELEMENT_CHILD,
	GXML_GOM_DOCUMENT_LAST_ELEMENT_CHILD,
	GXML_GOM_DOCUMENT_CHILD_ELEMENT_COUNT
};
GXmlGomImplementation* gxml_gom_implementation_new (void);
GXmlGomImplementation* gxml_gom_implementation_construct (GType object_type);
GType gxml_gom_implementation_get_type (void) G_GNUC_CONST;
GXmlGomDocument* gxml_gom_document_new (void);
GXmlGomDocument* gxml_gom_document_construct (GType object_type);
GXmlGomNode* gxml_gom_node_new (void);
GXmlGomNode* gxml_gom_node_construct (GType object_type);
GXmlGomDocument* gxml_gom_document_new_from_path (const gchar* path, GError** error);
GXmlGomDocument* gxml_gom_document_construct_from_path (GType object_type, const gchar* path, GError** error);
GXmlGomDocument* gxml_gom_document_new_from_file (GFile* file, GError** error);
GXmlGomDocument* gxml_gom_document_construct_from_file (GType object_type, GFile* file, GError** error);
GXmlGomDocument* gxml_gom_document_new_from_uri (const gchar* uri, GError** error);
GXmlGomDocument* gxml_gom_document_construct_from_uri (GType object_type, const gchar* uri, GError** error);
GType gxml_xparser_get_type (void) G_GNUC_CONST;
GXmlXParser* gxml_xparser_new (GXmlDomNode* node);
GXmlXParser* gxml_xparser_construct (GType object_type, GXmlDomNode* node);
GType gxml_parser_get_type (void) G_GNUC_CONST;
void gxml_parser_read_file (GXmlParser* self, GFile* file, GCancellable* cancellable, GError** error);
GXmlGomDocument* gxml_gom_document_new_from_stream (GInputStream* stream, GError** error);
GXmlGomDocument* gxml_gom_document_construct_from_stream (GType object_type, GInputStream* stream, GError** error);
void gxml_parser_read_stream (GXmlParser* self, GInputStream* stream, GCancellable* cancellable, GError** error);
GXmlGomDocument* gxml_gom_document_new_from_string (const gchar* str, GError** error);
GXmlGomDocument* gxml_gom_document_construct_from_string (GType object_type, const gchar* str, GError** error);
void gxml_parser_read_string (GXmlParser* self, const gchar* str, GCancellable* cancellable, GError** error);
void gxml_gom_document_write_file (GXmlGomDocument* self, GFile* file, GError** error);
void gxml_parser_write_file (GXmlParser* self, GFile* file, GCancellable* cancellable, GError** error);
void gxml_gom_document_write_stream (GXmlGomDocument* self, GOutputStream* stream, GError** error);
void gxml_parser_write_stream (GXmlParser* self, GOutputStream* stream, GCancellable* cancellable, GError** error);
void gxml_gom_document_read_from_file (GXmlGomDocument* self, GFile* file, GError** error);
void gxml_gom_document_read_from_string (GXmlGomDocument* self, const gchar* str, GError** error);
static GXmlDomElement* gxml_gom_document_real_create_element (GXmlDomDocument* base, const gchar* local_name, GError** error);
GType gxml_gom_element_get_type (void) G_GNUC_CONST;
GXmlGomElement* gxml_gom_element_new (void);
GXmlGomElement* gxml_gom_element_construct (GType object_type);
void gxml_gom_element_initialize_document (GXmlGomElement* self, GXmlDomDocument* doc, const gchar* local_name);
static GXmlDomElement* gxml_gom_document_real_create_element_ns (GXmlDomDocument* base, const gchar* namespace_uri, const gchar* qualified_name, GError** error);
GQuark gxml_dom_error_quark (void);
void gxml_gom_element_initialize_document_with_namespace (GXmlGomElement* self, GXmlDomDocument* doc, const gchar* namespace_uri, const gchar* prefix, const gchar* local_name);
static GXmlDomHTMLCollection* gxml_gom_document_real_get_elements_by_tag_name (GXmlDomDocument* base, const gchar* local_name);
GType gxml_gdom_html_collection_get_type (void) G_GNUC_CONST;
GXmlGDomHTMLCollection* gxml_gdom_html_collection_new (void);
GXmlGDomHTMLCollection* gxml_gdom_html_collection_construct (GType object_type);
GXmlDomElement* gxml_dom_document_get_document_element (GXmlDomDocument* self);
GXmlDomHTMLCollection* gxml_dom_element_get_elements_by_tag_name (GXmlDomElement* self, const gchar* local_name);
static GXmlDomHTMLCollection* gxml_gom_document_real_get_elements_by_tag_name_ns (GXmlDomDocument* base, const gchar* ns, const gchar* local_name);
GXmlDomHTMLCollection* gxml_dom_element_get_elements_by_tag_name_ns (GXmlDomElement* self, const gchar* namespace, const gchar* local_name);
static GXmlDomHTMLCollection* gxml_gom_document_real_get_elements_by_class_name (GXmlDomDocument* base, const gchar* class_names);
GXmlDomHTMLCollection* gxml_dom_element_get_elements_by_class_name (GXmlDomElement* self, const gchar* class_names);
static GXmlDomDocumentFragment* gxml_gom_document_real_create_document_fragment (GXmlDomDocument* base);
GXmlGomDocumentFragment* gxml_gom_document_fragment_new (GXmlDomDocument* doc);
GXmlGomDocumentFragment* gxml_gom_document_fragment_construct (GType object_type, GXmlDomDocument* doc);
GType gxml_gom_document_fragment_get_type (void) G_GNUC_CONST;
static GXmlDomText* gxml_gom_document_real_create_text_node (GXmlDomDocument* base, const gchar* data, GError** error);
GXmlGomText* gxml_gom_text_new (GXmlDomDocument* doc, const gchar* data);
GXmlGomText* gxml_gom_text_construct (GType object_type, GXmlDomDocument* doc, const gchar* data);
GType gxml_gom_character_data_get_type (void) G_GNUC_CONST;
GType gxml_gom_text_get_type (void) G_GNUC_CONST;
static GXmlDomComment* gxml_gom_document_real_gxml_dom_document_create_comment (GXmlDomDocument* base, const gchar* data, GError** error);
GXmlGomComment* gxml_gom_comment_new (GXmlDomDocument* doc, const gchar* data);
GXmlGomComment* gxml_gom_comment_construct (GType object_type, GXmlDomDocument* doc, const gchar* data);
GType gxml_gom_comment_get_type (void) G_GNUC_CONST;
static GXmlDomProcessingInstruction* gxml_gom_document_real_create_processing_instruction (GXmlDomDocument* base, const gchar* target, const gchar* data, GError** error);
GXmlGomProcessingInstruction* gxml_gom_processing_instruction_new (GXmlDomDocument* doc, const gchar* target, const gchar* data);
GXmlGomProcessingInstruction* gxml_gom_processing_instruction_construct (GType object_type, GXmlDomDocument* doc, const gchar* target, const gchar* data);
GType gxml_gom_processing_instruction_get_type (void) G_GNUC_CONST;
static GXmlDomNode* gxml_gom_document_real_import_node (GXmlDomDocument* base, GXmlDomNode* node, gboolean deep, GError** error);
GXmlDomElement* gxml_dom_document_create_element (GXmlDomDocument* self, const gchar* local_name, GError** error);
gchar* gxml_dom_node_get_node_name (GXmlDomNode* self);
gboolean gxml_dom_node_copy (GXmlDomDocument* doc, GXmlDomNode* node, GXmlDomNode* source, gboolean deep, GError** error);
GXmlDomNode* gxml_dom_node_append_child (GXmlDomNode* self, GXmlDomNode* node, GError** error);
GXmlDomText* gxml_dom_document_create_text_node (GXmlDomDocument* self, const gchar* data, GError** error);
gchar* gxml_dom_character_data_get_data (GXmlDomCharacterData* self);
GXmlDomComment* gxml_dom_document_create_comment (GXmlDomDocument* self, const gchar* data, GError** error);
GXmlDomProcessingInstruction* gxml_dom_document_create_processing_instruction (GXmlDomDocument* self, const gchar* target, const gchar* data, GError** error);
gchar* gxml_dom_processing_instruction_get_target (GXmlDomProcessingInstruction* self);
static GXmlDomNode* gxml_gom_document_real_adopt_node (GXmlDomDocument* base, GXmlDomNode* node, GError** error);
GXmlDomDocument* gxml_dom_node_get_owner_document (GXmlDomNode* self);
GXmlDomNode* gxml_dom_node_get_parent_node (GXmlDomNode* self);
GXmlDomNodeList* gxml_dom_node_get_child_nodes (GXmlDomNode* self);
static GXmlDomEvent* gxml_gom_document_real_create_event (GXmlDomDocument* base, const gchar* iface, GError** error);
GXmlGDomCustomEvent* gxml_gdom_custom_event_new (void);
GXmlGDomCustomEvent* gxml_gdom_custom_event_construct (GType object_type);
GType gxml_gdom_event_get_type (void) G_GNUC_CONST;
GType gxml_gdom_custom_event_get_type (void) G_GNUC_CONST;
static GXmlDomRange* gxml_gom_document_real_create_range (GXmlDomDocument* base);
GXmlGDomRange* gxml_gdom_range_new (GXmlDomDocument* doc);
GXmlGDomRange* gxml_gdom_range_construct (GType object_type, GXmlDomDocument* doc);
GType gxml_gdom_range_get_type (void) G_GNUC_CONST;
static GXmlDomNodeIterator* gxml_gom_document_real_create_node_iterator (GXmlDomDocument* base, GXmlDomNode* root, gint what_to_show, GXmlDomNodeFilter* filter);
GXmlGDomNodeIterator* gxml_gdom_node_iterator_new (GXmlDomNode* n, gint what_to_show, GXmlDomNodeFilter* filter);
GXmlGDomNodeIterator* gxml_gdom_node_iterator_construct (GType object_type, GXmlDomNode* n, gint what_to_show, GXmlDomNodeFilter* filter);
GType gxml_gdom_node_iterator_get_type (void) G_GNUC_CONST;
static GXmlDomTreeWalker* gxml_gom_document_real_create_tree_walker (GXmlDomDocument* base, GXmlDomNode* root, gint what_to_show, GXmlDomNodeFilter* filter);
GXmlGDomTreeWalker* gxml_gdom_tree_walker_new (GXmlDomNode* r, gint w, GXmlDomNodeFilter* f);
GXmlGDomTreeWalker* gxml_gdom_tree_walker_construct (GType object_type, GXmlDomNode* r, gint w, GXmlDomNodeFilter* f);
GType gxml_gdom_tree_walker_get_type (void) G_GNUC_CONST;
static GXmlDomElement* gxml_gom_document_real_query_selector (GXmlDomParentNode* base, const gchar* selectors, GError** error);
static GXmlDomNodeList* gxml_gom_document_real_query_selector_all (GXmlDomParentNode* base, const gchar* selectors, GError** error);
static GXmlDomElement* gxml_gom_document_real_get_element_by_id (GXmlDomNonElementParentNode* base, const gchar* element_id, GError** error);
GXmlDomElementList* gxml_dom_parent_node_get_elements_by_property_value (GXmlDomParentNode* self, const gchar* property, const gchar* value);
static GObject * gxml_gom_document_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
static void gxml_gom_document_finalize (GObject* obj);
GXmlDomImplementation* gxml_dom_document_get_implementation (GXmlDomDocument* self);
const gchar* gxml_dom_document_get_url (GXmlDomDocument* self);
const gchar* gxml_dom_document_get_document_uri (GXmlDomDocument* self);
const gchar* gxml_dom_document_get_origin (GXmlDomDocument* self);
const gchar* gxml_dom_document_get_compat_mode (GXmlDomDocument* self);
const gchar* gxml_dom_document_get_character_set (GXmlDomDocument* self);
const gchar* gxml_dom_document_get_content_type (GXmlDomDocument* self);
GXmlDomDocumentType* gxml_dom_document_get_doctype (GXmlDomDocument* self);
GXmlDomHTMLCollection* gxml_dom_parent_node_get_children (GXmlDomParentNode* self);
GXmlDomElement* gxml_dom_parent_node_get_first_element_child (GXmlDomParentNode* self);
GXmlDomElement* gxml_dom_parent_node_get_last_element_child (GXmlDomParentNode* self);
gint gxml_dom_parent_node_get_child_element_count (GXmlDomParentNode* self);
static void _vala_gxml_gom_document_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
enum  {
	GXML_GOM_IMPLEMENTATION_DUMMY_PROPERTY
};
static GXmlDomDocumentType* gxml_gom_implementation_real_create_document_type (GXmlDomImplementation* base, const gchar* qualified_name, const gchar* public_id, const gchar* system_id, GError** error);
GXmlGomDocumentType* gxml_gom_document_type_new_with_ids (GXmlDomDocument* doc, const gchar* name, const gchar* public_id, const gchar* system_id);
GXmlGomDocumentType* gxml_gom_document_type_construct_with_ids (GType object_type, GXmlDomDocument* doc, const gchar* name, const gchar* public_id, const gchar* system_id);
GType gxml_gom_document_type_get_type (void) G_GNUC_CONST;
static GXmlDomXMLDocument* gxml_gom_implementation_real_create_document (GXmlDomImplementation* base, const gchar* namespace, const gchar* qualified_name, GXmlDomDocumentType* doctype, GError** error);
const gchar* gxml_dom_document_type_get_name (GXmlDomDocumentType* self);
const gchar* gxml_dom_document_type_get_public_id (GXmlDomDocumentType* self);
const gchar* gxml_dom_document_type_get_system_id (GXmlDomDocumentType* self);
GXmlDomElement* gxml_dom_document_create_element_ns (GXmlDomDocument* self, const gchar* namespace, const gchar* qualified_name, GError** error);
static GXmlDocument* gxml_gom_implementation_real_create_html_document (GXmlDomImplementation* base, const gchar* title);
GXmlHtmlDocument* gxml_html_document_new (void);
GXmlHtmlDocument* gxml_html_document_construct (GType object_type);
GType gxml_gnode_get_type (void) G_GNUC_CONST;
GType gxml_gdocument_get_type (void) G_GNUC_CONST;
GType gxml_html_document_get_type (void) G_GNUC_CONST;
enum  {
	GXML_GOM_DOCUMENT_TYPE_DUMMY_PROPERTY,
	GXML_GOM_DOCUMENT_TYPE_NAME,
	GXML_GOM_DOCUMENT_TYPE_PUBLIC_ID,
	GXML_GOM_DOCUMENT_TYPE_SYSTEM_ID
};
GXmlGomDocumentType* gxml_gom_document_type_new_with_name (GXmlDomDocument* doc, const gchar* name);
GXmlGomDocumentType* gxml_gom_document_type_construct_with_name (GType object_type, GXmlDomDocument* doc, const gchar* name);
static void gxml_gom_document_type_real_remove (GXmlDomChildNode* base);
GXmlGomDocumentType* gxml_gom_document_type_new (void);
GXmlGomDocumentType* gxml_gom_document_type_construct (GType object_type);
gboolean gxml_dom_node_has_child_nodes (GXmlDomNode* self);
void gxml_dom_node_normalize (GXmlDomNode* self);
gboolean gxml_dom_node_is_equal_node (GXmlDomNode* self, GXmlDomNode* node);
GXmlDomNodeDocumentPosition gxml_dom_node_compare_document_position (GXmlDomNode* self, GXmlDomNode* other);
gboolean gxml_dom_node_contains (GXmlDomNode* self, GXmlDomNode* other);
gchar* gxml_dom_node_lookup_prefix (GXmlDomNode* self, const gchar* nspace);
gchar* gxml_dom_node_lookup_namespace_uri (GXmlDomNode* self, const gchar* prefix);
gboolean gxml_dom_node_is_default_namespace (GXmlDomNode* self, const gchar* nspace);
GXmlDomNode* gxml_dom_node_insert_before (GXmlDomNode* self, GXmlDomNode* node, GXmlDomNode* child, GError** error);
GXmlDomNode* gxml_dom_node_replace_child (GXmlDomNode* self, GXmlDomNode* node, GXmlDomNode* child, GError** error);
GXmlDomNode* gxml_dom_node_remove_child (GXmlDomNode* self, GXmlDomNode* child, GError** error);
GXmlDomNodeNodeType gxml_dom_node_get_node_type (GXmlDomNode* self);
const gchar* gxml_dom_node_get_base_uri (GXmlDomNode* self);
void gxml_dom_node_set_owner_document (GXmlDomNode* self, GXmlDomDocument* value);
GXmlDomElement* gxml_dom_node_get_parent_element (GXmlDomNode* self);
GXmlDomNode* gxml_dom_node_get_first_child (GXmlDomNode* self);
GXmlDomNode* gxml_dom_node_get_last_child (GXmlDomNode* self);
GXmlDomNode* gxml_dom_node_get_previous_sibling (GXmlDomNode* self);
GXmlDomNode* gxml_dom_node_get_next_sibling (GXmlDomNode* self);
gchar* gxml_dom_node_get_node_value (GXmlDomNode* self);
void gxml_dom_node_set_node_value (GXmlDomNode* self, const gchar* value);
gchar* gxml_dom_node_get_text_content (GXmlDomNode* self);
void gxml_dom_node_set_text_content (GXmlDomNode* self, const gchar* value);
static void gxml_gom_document_type_finalize (GObject* obj);
static void _vala_gxml_gom_document_type_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
enum  {
	GXML_GOM_DOCUMENT_FRAGMENT_DUMMY_PROPERTY,
	GXML_GOM_DOCUMENT_FRAGMENT_CHILDREN,
	GXML_GOM_DOCUMENT_FRAGMENT_FIRST_ELEMENT_CHILD,
	GXML_GOM_DOCUMENT_FRAGMENT_LAST_ELEMENT_CHILD,
	GXML_GOM_DOCUMENT_FRAGMENT_CHILD_ELEMENT_COUNT
};
static GXmlDomElement* gxml_gom_document_fragment_real_query_selector (GXmlDomParentNode* base, const gchar* selectors, GError** error);
static GXmlDomNodeList* gxml_gom_document_fragment_real_query_selector_all (GXmlDomParentNode* base, const gchar* selectors, GError** error);
static GXmlDomElement* gxml_gom_document_fragment_real_get_element_by_id (GXmlDomNonElementParentNode* base, const gchar* element_id, GError** error);
GXmlDomElementList* gxml_dom_element_list_new (void);
GXmlDomElementList* gxml_dom_element_list_construct (GType object_type);
static void _vala_gxml_gom_document_fragment_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
static gint _vala_array_length (gpointer array);


GXmlGomDocument* gxml_gom_document_construct (GType object_type) {
	GXmlGomDocument * self = NULL;
	self = (GXmlGomDocument*) gxml_gom_node_construct (object_type);
	return self;
}


GXmlGomDocument* gxml_gom_document_new (void) {
	return gxml_gom_document_construct (GXML_TYPE_GOM_DOCUMENT);
}


GXmlGomDocument* gxml_gom_document_construct_from_path (GType object_type, const gchar* path, GError** error) {
	GXmlGomDocument * self = NULL;
	GFile* file = NULL;
	const gchar* _tmp0_ = NULL;
	GFile* _tmp1_ = NULL;
	GError * _inner_error_ = NULL;
	g_return_val_if_fail (path != NULL, NULL);
	_tmp0_ = path;
	_tmp1_ = g_file_new_for_path (_tmp0_);
	file = _tmp1_;
	self = (GXmlGomDocument*) gxml_gom_document_construct_from_file (object_type, file, &_inner_error_);
	if (G_UNLIKELY (_inner_error_ != NULL)) {
		g_propagate_error (error, _inner_error_);
		_g_object_unref0 (file);
		_g_object_unref0 (self);
		return NULL;
	}
	_g_object_unref0 (file);
	return self;
}


GXmlGomDocument* gxml_gom_document_new_from_path (const gchar* path, GError** error) {
	return gxml_gom_document_construct_from_path (GXML_TYPE_GOM_DOCUMENT, path, error);
}


/**
   * Creates a document parsing a URI file.
   */
GXmlGomDocument* gxml_gom_document_construct_from_uri (GType object_type, const gchar* uri, GError** error) {
	GXmlGomDocument * self = NULL;
	const gchar* _tmp0_ = NULL;
	GFile* _tmp1_ = NULL;
	GFile* _tmp2_ = NULL;
	GError * _inner_error_ = NULL;
	g_return_val_if_fail (uri != NULL, NULL);
	_tmp0_ = uri;
	_tmp1_ = g_file_new_for_uri (_tmp0_);
	_tmp2_ = _tmp1_;
	self = (GXmlGomDocument*) gxml_gom_document_construct_from_file (object_type, _tmp2_, &_inner_error_);
	_g_object_unref0 (_tmp2_);
	if (G_UNLIKELY (_inner_error_ != NULL)) {
		g_propagate_error (error, _inner_error_);
		_g_object_unref0 (self);
		return NULL;
	}
	return self;
}


GXmlGomDocument* gxml_gom_document_new_from_uri (const gchar* uri, GError** error) {
	return gxml_gom_document_construct_from_uri (GXML_TYPE_GOM_DOCUMENT, uri, error);
}


/**
   * Creates a document parsing a file.
   */
GXmlGomDocument* gxml_gom_document_construct_from_file (GType object_type, GFile* file, GError** error) {
	GXmlGomDocument * self = NULL;
	GXmlXParser* parser = NULL;
	GXmlXParser* _tmp0_ = NULL;
	GFile* _tmp1_ = NULL;
	GError * _inner_error_ = NULL;
	g_return_val_if_fail (file != NULL, NULL);
	self = (GXmlGomDocument*) gxml_gom_node_construct (object_type);
	_tmp0_ = gxml_xparser_new ((GXmlDomNode*) self);
	parser = _tmp0_;
	_tmp1_ = file;
	gxml_parser_read_file ((GXmlParser*) parser, _tmp1_, NULL, &_inner_error_);
	if (G_UNLIKELY (_inner_error_ != NULL)) {
		g_propagate_error (error, _inner_error_);
		_g_object_unref0 (parser);
		_g_object_unref0 (self);
		return NULL;
	}
	_g_object_unref0 (parser);
	return self;
}


GXmlGomDocument* gxml_gom_document_new_from_file (GFile* file, GError** error) {
	return gxml_gom_document_construct_from_file (GXML_TYPE_GOM_DOCUMENT, file, error);
}


/**
   * Creates a document parsing a stream.
   */
GXmlGomDocument* gxml_gom_document_construct_from_stream (GType object_type, GInputStream* stream, GError** error) {
	GXmlGomDocument * self = NULL;
	GXmlXParser* parser = NULL;
	GXmlXParser* _tmp0_ = NULL;
	GInputStream* _tmp1_ = NULL;
	GError * _inner_error_ = NULL;
	g_return_val_if_fail (stream != NULL, NULL);
	self = (GXmlGomDocument*) gxml_gom_node_construct (object_type);
	_tmp0_ = gxml_xparser_new ((GXmlDomNode*) self);
	parser = _tmp0_;
	_tmp1_ = stream;
	gxml_parser_read_stream ((GXmlParser*) parser, _tmp1_, NULL, &_inner_error_);
	if (G_UNLIKELY (_inner_error_ != NULL)) {
		g_propagate_error (error, _inner_error_);
		_g_object_unref0 (parser);
		_g_object_unref0 (self);
		return NULL;
	}
	_g_object_unref0 (parser);
	return self;
}


GXmlGomDocument* gxml_gom_document_new_from_stream (GInputStream* stream, GError** error) {
	return gxml_gom_document_construct_from_stream (GXML_TYPE_GOM_DOCUMENT, stream, error);
}


/**
   * Creates a document parsing a string.
   */
GXmlGomDocument* gxml_gom_document_construct_from_string (GType object_type, const gchar* str, GError** error) {
	GXmlGomDocument * self = NULL;
	GXmlXParser* parser = NULL;
	GXmlXParser* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	GError * _inner_error_ = NULL;
	g_return_val_if_fail (str != NULL, NULL);
	self = (GXmlGomDocument*) gxml_gom_node_construct (object_type);
	_tmp0_ = gxml_xparser_new ((GXmlDomNode*) self);
	parser = _tmp0_;
	_tmp1_ = str;
	gxml_parser_read_string ((GXmlParser*) parser, _tmp1_, NULL, &_inner_error_);
	if (G_UNLIKELY (_inner_error_ != NULL)) {
		g_propagate_error (error, _inner_error_);
		_g_object_unref0 (parser);
		_g_object_unref0 (self);
		return NULL;
	}
	_g_object_unref0 (parser);
	return self;
}


GXmlGomDocument* gxml_gom_document_new_from_string (const gchar* str, GError** error) {
	return gxml_gom_document_construct_from_string (GXML_TYPE_GOM_DOCUMENT, str, error);
}


/**
   * Writes a dump XML representation of document to a file.
   */
void gxml_gom_document_write_file (GXmlGomDocument* self, GFile* file, GError** error) {
	GXmlXParser* parser = NULL;
	GXmlXParser* _tmp0_ = NULL;
	GFile* _tmp1_ = NULL;
	GError * _inner_error_ = NULL;
	g_return_if_fail (self != NULL);
	g_return_if_fail (file != NULL);
	_tmp0_ = gxml_xparser_new ((GXmlDomNode*) self);
	parser = _tmp0_;
	_tmp1_ = file;
	gxml_parser_write_file ((GXmlParser*) parser, _tmp1_, NULL, &_inner_error_);
	if (G_UNLIKELY (_inner_error_ != NULL)) {
		g_propagate_error (error, _inner_error_);
		_g_object_unref0 (parser);
		return;
	}
	_g_object_unref0 (parser);
}


/**
   * Writes a dump XML representation of document to a stream.
   */
void gxml_gom_document_write_stream (GXmlGomDocument* self, GOutputStream* stream, GError** error) {
	GXmlXParser* parser = NULL;
	GXmlXParser* _tmp0_ = NULL;
	GOutputStream* _tmp1_ = NULL;
	GError * _inner_error_ = NULL;
	g_return_if_fail (self != NULL);
	g_return_if_fail (stream != NULL);
	_tmp0_ = gxml_xparser_new ((GXmlDomNode*) self);
	parser = _tmp0_;
	_tmp1_ = stream;
	gxml_parser_write_stream ((GXmlParser*) parser, _tmp1_, NULL, &_inner_error_);
	if (G_UNLIKELY (_inner_error_ != NULL)) {
		g_propagate_error (error, _inner_error_);
		_g_object_unref0 (parser);
		return;
	}
	_g_object_unref0 (parser);
}


/**
   * Reads a file contents and parse it to document.
   */
void gxml_gom_document_read_from_file (GXmlGomDocument* self, GFile* file, GError** error) {
	GXmlXParser* parser = NULL;
	GXmlXParser* _tmp0_ = NULL;
	GFile* _tmp1_ = NULL;
	GError * _inner_error_ = NULL;
	g_return_if_fail (self != NULL);
	g_return_if_fail (file != NULL);
	_tmp0_ = gxml_xparser_new ((GXmlDomNode*) self);
	parser = _tmp0_;
	_tmp1_ = file;
	gxml_parser_read_file ((GXmlParser*) parser, _tmp1_, NULL, &_inner_error_);
	if (G_UNLIKELY (_inner_error_ != NULL)) {
		g_propagate_error (error, _inner_error_);
		_g_object_unref0 (parser);
		return;
	}
	_g_object_unref0 (parser);
}


/**
   * Reads a string and parse it to document.
   */
void gxml_gom_document_read_from_string (GXmlGomDocument* self, const gchar* str, GError** error) {
	GXmlXParser* parser = NULL;
	GXmlXParser* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	GError * _inner_error_ = NULL;
	g_return_if_fail (self != NULL);
	g_return_if_fail (str != NULL);
	_tmp0_ = gxml_xparser_new ((GXmlDomNode*) self);
	parser = _tmp0_;
	_tmp1_ = str;
	gxml_parser_read_string ((GXmlParser*) parser, _tmp1_, NULL, &_inner_error_);
	if (G_UNLIKELY (_inner_error_ != NULL)) {
		g_propagate_error (error, _inner_error_);
		_g_object_unref0 (parser);
		return;
	}
	_g_object_unref0 (parser);
}


static GXmlDomElement* gxml_gom_document_real_create_element (GXmlDomDocument* base, const gchar* local_name, GError** error) {
	GXmlGomDocument * self;
	GXmlDomElement* result = NULL;
	GXmlGomElement* e = NULL;
	GXmlGomElement* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	self = (GXmlGomDocument*) base;
	g_return_val_if_fail (local_name != NULL, NULL);
	_tmp0_ = gxml_gom_element_new ();
	e = _tmp0_;
	_tmp1_ = local_name;
	gxml_gom_element_initialize_document (e, (GXmlDomDocument*) self, _tmp1_);
	result = (GXmlDomElement*) e;
	return result;
}


static gboolean string_contains (const gchar* self, const gchar* needle) {
	gboolean result = FALSE;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	g_return_val_if_fail (self != NULL, FALSE);
	g_return_val_if_fail (needle != NULL, FALSE);
	_tmp0_ = needle;
	_tmp1_ = strstr ((gchar*) self, (gchar*) _tmp0_);
	result = _tmp1_ != NULL;
	return result;
}


static GXmlDomElement* gxml_gom_document_real_create_element_ns (GXmlDomDocument* base, const gchar* namespace_uri, const gchar* qualified_name, GError** error) {
	GXmlGomDocument * self;
	GXmlDomElement* result = NULL;
	gchar* n = NULL;
	gchar* _tmp0_ = NULL;
	gchar* nsp = NULL;
	const gchar* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	gboolean _tmp17_ = FALSE;
	const gchar* _tmp18_ = NULL;
	gboolean _tmp22_ = FALSE;
	gboolean _tmp23_ = FALSE;
	const gchar* _tmp24_ = NULL;
	gboolean _tmp29_ = FALSE;
	gboolean _tmp30_ = FALSE;
	const gchar* _tmp31_ = NULL;
	GXmlGomElement* e = NULL;
	GXmlGomElement* _tmp36_ = NULL;
	GXmlGomElement* _tmp37_ = NULL;
	const gchar* _tmp38_ = NULL;
	const gchar* _tmp39_ = NULL;
	const gchar* _tmp40_ = NULL;
	GError * _inner_error_ = NULL;
	self = (GXmlGomDocument*) base;
	g_return_val_if_fail (qualified_name != NULL, NULL);
	_tmp0_ = g_strdup ("");
	n = _tmp0_;
	nsp = NULL;
	_tmp1_ = qualified_name;
	_tmp2_ = string_contains (_tmp1_, ":");
	if (_tmp2_) {
		gchar** s = NULL;
		const gchar* _tmp3_ = NULL;
		gchar** _tmp4_ = NULL;
		gchar** _tmp5_ = NULL;
		gint s_length1 = 0;
		gint _s_size_ = 0;
		gchar** _tmp6_ = NULL;
		gint _tmp6__length1 = 0;
		gchar** _tmp9_ = NULL;
		gint _tmp9__length1 = 0;
		const gchar* _tmp10_ = NULL;
		gchar* _tmp11_ = NULL;
		gchar** _tmp12_ = NULL;
		gint _tmp12__length1 = 0;
		const gchar* _tmp13_ = NULL;
		gchar* _tmp14_ = NULL;
		_tmp3_ = qualified_name;
		_tmp5_ = _tmp4_ = g_strsplit (_tmp3_, ":", 0);
		s = _tmp5_;
		s_length1 = _vala_array_length (_tmp4_);
		_s_size_ = s_length1;
		_tmp6_ = s;
		_tmp6__length1 = s_length1;
		if (_tmp6__length1 != 2) {
			const gchar* _tmp7_ = NULL;
			GError* _tmp8_ = NULL;
			_tmp7_ = _ ("Creating a namespaced element with invalid node name");
			_tmp8_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_NAMESPACE_ERROR, _tmp7_);
			_inner_error_ = _tmp8_;
			g_propagate_error (error, _inner_error_);
			s = (_vala_array_free (s, s_length1, (GDestroyNotify) g_free), NULL);
			_g_free0 (nsp);
			_g_free0 (n);
			return NULL;
		}
		_tmp9_ = s;
		_tmp9__length1 = s_length1;
		_tmp10_ = _tmp9_[0];
		_tmp11_ = g_strdup (_tmp10_);
		_g_free0 (nsp);
		nsp = _tmp11_;
		_tmp12_ = s;
		_tmp12__length1 = s_length1;
		_tmp13_ = _tmp12_[1];
		_tmp14_ = g_strdup (_tmp13_);
		_g_free0 (n);
		n = _tmp14_;
		s = (_vala_array_free (s, s_length1, (GDestroyNotify) g_free), NULL);
	} else {
		const gchar* _tmp15_ = NULL;
		gchar* _tmp16_ = NULL;
		_tmp15_ = qualified_name;
		_tmp16_ = g_strdup (_tmp15_);
		_g_free0 (n);
		n = _tmp16_;
	}
	_tmp18_ = nsp;
	if (g_strcmp0 (_tmp18_, "") == 0) {
		const gchar* _tmp19_ = NULL;
		_tmp19_ = namespace_uri;
		_tmp17_ = _tmp19_ == NULL;
	} else {
		_tmp17_ = FALSE;
	}
	if (_tmp17_) {
		const gchar* _tmp20_ = NULL;
		GError* _tmp21_ = NULL;
		_tmp20_ = _ ("Creating a namespaced element with invalid namespace");
		_tmp21_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_NAMESPACE_ERROR, _tmp20_);
		_inner_error_ = _tmp21_;
		g_propagate_error (error, _inner_error_);
		_g_free0 (nsp);
		_g_free0 (n);
		return NULL;
	}
	_tmp24_ = n;
	if (g_strcmp0 (_tmp24_, "xmlns") == 0) {
		_tmp23_ = TRUE;
	} else {
		const gchar* _tmp25_ = NULL;
		_tmp25_ = nsp;
		_tmp23_ = g_strcmp0 (_tmp25_, "xmlns") == 0;
	}
	if (_tmp23_) {
		const gchar* _tmp26_ = NULL;
		_tmp26_ = namespace_uri;
		_tmp22_ = g_strcmp0 (_tmp26_, "http://www.w3.org/2000/xmlns/") != 0;
	} else {
		_tmp22_ = FALSE;
	}
	if (_tmp22_) {
		const gchar* _tmp27_ = NULL;
		GError* _tmp28_ = NULL;
		_tmp27_ = _ ("Invalid namespace URI for xmlns prefix. Use http://www.w3.org/2000/xml" \
"ns/");
		_tmp28_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_NAMESPACE_ERROR, _tmp27_);
		_inner_error_ = _tmp28_;
		g_propagate_error (error, _inner_error_);
		_g_free0 (nsp);
		_g_free0 (n);
		return NULL;
	}
	_tmp31_ = n;
	if (g_strcmp0 (_tmp31_, "xmlns") != 0) {
		_tmp30_ = TRUE;
	} else {
		const gchar* _tmp32_ = NULL;
		_tmp32_ = nsp;
		_tmp30_ = g_strcmp0 (_tmp32_, "xmlns") != 0;
	}
	if (_tmp30_) {
		const gchar* _tmp33_ = NULL;
		_tmp33_ = namespace_uri;
		_tmp29_ = g_strcmp0 (_tmp33_, "http://www.w3.org/2000/xmlns/") == 0;
	} else {
		_tmp29_ = FALSE;
	}
	if (_tmp29_) {
		const gchar* _tmp34_ = NULL;
		GError* _tmp35_ = NULL;
		_tmp34_ = _ ("Only xmlns prefixs can be used with http://www.w3.org/2000/xmlns/");
		_tmp35_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_NAMESPACE_ERROR, _tmp34_);
		_inner_error_ = _tmp35_;
		g_propagate_error (error, _inner_error_);
		_g_free0 (nsp);
		_g_free0 (n);
		return NULL;
	}
	_tmp36_ = gxml_gom_element_new ();
	e = _tmp36_;
	_tmp37_ = e;
	_tmp38_ = namespace_uri;
	_tmp39_ = nsp;
	_tmp40_ = n;
	gxml_gom_element_initialize_document_with_namespace (_tmp37_, (GXmlDomDocument*) self, _tmp38_, _tmp39_, _tmp40_);
	result = (GXmlDomElement*) e;
	_g_free0 (nsp);
	_g_free0 (n);
	return result;
}


static GXmlDomHTMLCollection* gxml_gom_document_real_get_elements_by_tag_name (GXmlDomDocument* base, const gchar* local_name) {
	GXmlGomDocument * self;
	GXmlDomHTMLCollection* result = NULL;
	GXmlGDomHTMLCollection* l = NULL;
	GXmlGDomHTMLCollection* _tmp0_ = NULL;
	GXmlDomElement* _tmp1_ = NULL;
	GXmlDomElement* _tmp2_ = NULL;
	GXmlDomElement* _tmp3_ = NULL;
	gboolean _tmp4_ = FALSE;
	GXmlGDomHTMLCollection* _tmp5_ = NULL;
	GXmlDomElement* _tmp6_ = NULL;
	GXmlDomElement* _tmp7_ = NULL;
	GXmlDomElement* _tmp8_ = NULL;
	const gchar* _tmp9_ = NULL;
	GXmlDomHTMLCollection* _tmp10_ = NULL;
	GXmlDomHTMLCollection* _tmp11_ = NULL;
	self = (GXmlGomDocument*) base;
	g_return_val_if_fail (local_name != NULL, NULL);
	_tmp0_ = gxml_gdom_html_collection_new ();
	l = _tmp0_;
	_tmp1_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) self);
	_tmp2_ = _tmp1_;
	_tmp3_ = _tmp2_;
	_tmp4_ = _tmp3_ == NULL;
	_g_object_unref0 (_tmp3_);
	if (_tmp4_) {
		result = (GXmlDomHTMLCollection*) l;
		return result;
	}
	_tmp5_ = l;
	_tmp6_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) self);
	_tmp7_ = _tmp6_;
	_tmp8_ = _tmp7_;
	_tmp9_ = local_name;
	_tmp10_ = gxml_dom_element_get_elements_by_tag_name (_tmp8_, _tmp9_);
	_tmp11_ = _tmp10_;
	gee_array_list_add_all ((GeeArrayList*) _tmp5_, (GeeCollection*) _tmp11_);
	_g_object_unref0 (_tmp11_);
	_g_object_unref0 (_tmp8_);
	result = (GXmlDomHTMLCollection*) l;
	return result;
}


static GXmlDomHTMLCollection* gxml_gom_document_real_get_elements_by_tag_name_ns (GXmlDomDocument* base, const gchar* ns, const gchar* local_name) {
	GXmlGomDocument * self;
	GXmlDomHTMLCollection* result = NULL;
	GXmlGDomHTMLCollection* l = NULL;
	GXmlGDomHTMLCollection* _tmp0_ = NULL;
	GXmlDomElement* _tmp1_ = NULL;
	GXmlDomElement* _tmp2_ = NULL;
	GXmlDomElement* _tmp3_ = NULL;
	gboolean _tmp4_ = FALSE;
	GXmlGDomHTMLCollection* _tmp5_ = NULL;
	GXmlDomElement* _tmp6_ = NULL;
	GXmlDomElement* _tmp7_ = NULL;
	GXmlDomElement* _tmp8_ = NULL;
	const gchar* _tmp9_ = NULL;
	const gchar* _tmp10_ = NULL;
	GXmlDomHTMLCollection* _tmp11_ = NULL;
	GXmlDomHTMLCollection* _tmp12_ = NULL;
	self = (GXmlGomDocument*) base;
	g_return_val_if_fail (local_name != NULL, NULL);
	_tmp0_ = gxml_gdom_html_collection_new ();
	l = _tmp0_;
	_tmp1_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) self);
	_tmp2_ = _tmp1_;
	_tmp3_ = _tmp2_;
	_tmp4_ = _tmp3_ == NULL;
	_g_object_unref0 (_tmp3_);
	if (_tmp4_) {
		result = (GXmlDomHTMLCollection*) l;
		return result;
	}
	_tmp5_ = l;
	_tmp6_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) self);
	_tmp7_ = _tmp6_;
	_tmp8_ = _tmp7_;
	_tmp9_ = ns;
	_tmp10_ = local_name;
	_tmp11_ = gxml_dom_element_get_elements_by_tag_name_ns (_tmp8_, _tmp9_, _tmp10_);
	_tmp12_ = _tmp11_;
	gee_array_list_add_all ((GeeArrayList*) _tmp5_, (GeeCollection*) _tmp12_);
	_g_object_unref0 (_tmp12_);
	_g_object_unref0 (_tmp8_);
	result = (GXmlDomHTMLCollection*) l;
	return result;
}


static GXmlDomHTMLCollection* gxml_gom_document_real_get_elements_by_class_name (GXmlDomDocument* base, const gchar* class_names) {
	GXmlGomDocument * self;
	GXmlDomHTMLCollection* result = NULL;
	GXmlGDomHTMLCollection* l = NULL;
	GXmlGDomHTMLCollection* _tmp0_ = NULL;
	GXmlDomElement* _tmp1_ = NULL;
	GXmlDomElement* _tmp2_ = NULL;
	GXmlDomElement* _tmp3_ = NULL;
	gboolean _tmp4_ = FALSE;
	GXmlGDomHTMLCollection* _tmp5_ = NULL;
	GXmlDomElement* _tmp6_ = NULL;
	GXmlDomElement* _tmp7_ = NULL;
	GXmlDomElement* _tmp8_ = NULL;
	const gchar* _tmp9_ = NULL;
	GXmlDomHTMLCollection* _tmp10_ = NULL;
	GXmlDomHTMLCollection* _tmp11_ = NULL;
	self = (GXmlGomDocument*) base;
	g_return_val_if_fail (class_names != NULL, NULL);
	_tmp0_ = gxml_gdom_html_collection_new ();
	l = _tmp0_;
	_tmp1_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) self);
	_tmp2_ = _tmp1_;
	_tmp3_ = _tmp2_;
	_tmp4_ = _tmp3_ == NULL;
	_g_object_unref0 (_tmp3_);
	if (_tmp4_) {
		result = (GXmlDomHTMLCollection*) l;
		return result;
	}
	_tmp5_ = l;
	_tmp6_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) self);
	_tmp7_ = _tmp6_;
	_tmp8_ = _tmp7_;
	_tmp9_ = class_names;
	_tmp10_ = gxml_dom_element_get_elements_by_class_name (_tmp8_, _tmp9_);
	_tmp11_ = _tmp10_;
	gee_array_list_add_all ((GeeArrayList*) _tmp5_, (GeeCollection*) _tmp11_);
	_g_object_unref0 (_tmp11_);
	_g_object_unref0 (_tmp8_);
	result = (GXmlDomHTMLCollection*) l;
	return result;
}


static GXmlDomDocumentFragment* gxml_gom_document_real_create_document_fragment (GXmlDomDocument* base) {
	GXmlGomDocument * self;
	GXmlDomDocumentFragment* result = NULL;
	GXmlGomDocumentFragment* _tmp0_ = NULL;
	self = (GXmlGomDocument*) base;
	_tmp0_ = gxml_gom_document_fragment_new ((GXmlDomDocument*) self);
	result = (GXmlDomDocumentFragment*) _tmp0_;
	return result;
}


static GXmlDomText* gxml_gom_document_real_create_text_node (GXmlDomDocument* base, const gchar* data, GError** error) {
	GXmlGomDocument * self;
	GXmlDomText* result = NULL;
	const gchar* _tmp0_ = NULL;
	GXmlGomText* _tmp1_ = NULL;
	self = (GXmlGomDocument*) base;
	g_return_val_if_fail (data != NULL, NULL);
	_tmp0_ = data;
	_tmp1_ = gxml_gom_text_new ((GXmlDomDocument*) self, _tmp0_);
	result = (GXmlDomText*) _tmp1_;
	return result;
}


static GXmlDomComment* gxml_gom_document_real_gxml_dom_document_create_comment (GXmlDomDocument* base, const gchar* data, GError** error) {
	GXmlGomDocument * self;
	GXmlDomComment* result = NULL;
	const gchar* _tmp0_ = NULL;
	GXmlGomComment* _tmp1_ = NULL;
	self = (GXmlGomDocument*) base;
	g_return_val_if_fail (data != NULL, NULL);
	_tmp0_ = data;
	_tmp1_ = gxml_gom_comment_new ((GXmlDomDocument*) self, _tmp0_);
	result = (GXmlDomComment*) _tmp1_;
	return result;
}


static GXmlDomProcessingInstruction* gxml_gom_document_real_create_processing_instruction (GXmlDomDocument* base, const gchar* target, const gchar* data, GError** error) {
	GXmlGomDocument * self;
	GXmlDomProcessingInstruction* result = NULL;
	const gchar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	GXmlGomProcessingInstruction* _tmp2_ = NULL;
	self = (GXmlGomDocument*) base;
	g_return_val_if_fail (target != NULL, NULL);
	g_return_val_if_fail (data != NULL, NULL);
	_tmp0_ = target;
	_tmp1_ = data;
	_tmp2_ = gxml_gom_processing_instruction_new ((GXmlDomDocument*) self, _tmp0_, _tmp1_);
	result = (GXmlDomProcessingInstruction*) _tmp2_;
	return result;
}


static gpointer _g_object_ref0 (gpointer self) {
	return self ? g_object_ref (self) : NULL;
}


static GXmlDomNode* gxml_gom_document_real_import_node (GXmlDomDocument* base, GXmlDomNode* node, gboolean deep, GError** error) {
	GXmlGomDocument * self;
	GXmlDomNode* result = NULL;
	GXmlDomNode* _tmp0_ = NULL;
	gboolean _tmp3_ = FALSE;
	GXmlDomNode* _tmp4_ = NULL;
	GXmlDomNode* dst = NULL;
	GXmlDomNode* _tmp10_ = NULL;
	GXmlDomNode* _tmp29_ = NULL;
	GXmlDomNode* _tmp38_ = NULL;
	GXmlDomNode* _tmp47_ = NULL;
	GXmlDomNode* _tmp60_ = NULL;
	GXmlDomNode* _tmp67_ = NULL;
	GXmlDomNode* _tmp68_ = NULL;
	GError * _inner_error_ = NULL;
	self = (GXmlGomDocument*) base;
	g_return_val_if_fail (node != NULL, NULL);
	_tmp0_ = node;
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, GXML_TYPE_DOM_DOCUMENT)) {
		const gchar* _tmp1_ = NULL;
		GError* _tmp2_ = NULL;
		_tmp1_ = _ ("Can't import a Document");
		_tmp2_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_NOT_SUPPORTED_ERROR, _tmp1_);
		_inner_error_ = _tmp2_;
		g_propagate_error (error, _inner_error_);
		return NULL;
	}
	_tmp4_ = node;
	if (!G_TYPE_CHECK_INSTANCE_TYPE (_tmp4_, GXML_TYPE_DOM_ELEMENT)) {
		GXmlDomElement* _tmp5_ = NULL;
		GXmlDomElement* _tmp6_ = NULL;
		GXmlDomElement* _tmp7_ = NULL;
		_tmp5_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) self);
		_tmp6_ = _tmp5_;
		_tmp7_ = _tmp6_;
		_tmp3_ = _tmp7_ == NULL;
		_g_object_unref0 (_tmp7_);
	} else {
		_tmp3_ = FALSE;
	}
	if (_tmp3_) {
		const gchar* _tmp8_ = NULL;
		GError* _tmp9_ = NULL;
		_tmp8_ = _ ("Can't import a non Element type node to a Document");
		_tmp9_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_HIERARCHY_REQUEST_ERROR, _tmp8_);
		_inner_error_ = _tmp9_;
		g_propagate_error (error, _inner_error_);
		return NULL;
	}
	dst = NULL;
	_tmp10_ = node;
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp10_, GXML_TYPE_DOM_ELEMENT)) {
		GXmlDomElement* _tmp11_ = NULL;
		GXmlDomNode* _tmp12_ = NULL;
		gchar* _tmp13_ = NULL;
		gchar* _tmp14_ = NULL;
		gchar* _tmp15_ = NULL;
		GXmlDomElement* _tmp16_ = NULL;
		GXmlDomElement* _tmp17_ = NULL;
		GXmlDomElement* _tmp18_ = NULL;
		GXmlDomNode* _tmp19_ = NULL;
		GXmlDomNode* _tmp20_ = NULL;
		gboolean _tmp21_ = FALSE;
		GXmlDomElement* _tmp22_ = NULL;
		GXmlDomElement* _tmp23_ = NULL;
		GXmlDomElement* _tmp24_ = NULL;
		gboolean _tmp25_ = FALSE;
		_tmp12_ = node;
		_tmp13_ = gxml_dom_node_get_node_name (_tmp12_);
		_tmp14_ = _tmp13_;
		_tmp15_ = _tmp14_;
		_tmp16_ = gxml_dom_document_create_element (G_TYPE_CHECK_INSTANCE_TYPE (self, GXML_TYPE_DOM_DOCUMENT) ? ((GXmlDomDocument*) self) : NULL, _tmp15_, &_inner_error_);
		_tmp17_ = _tmp16_;
		_g_free0 (_tmp15_);
		_tmp11_ = _tmp17_;
		if (G_UNLIKELY (_inner_error_ != NULL)) {
			g_propagate_error (error, _inner_error_);
			_g_object_unref0 (dst);
			return NULL;
		}
		_tmp18_ = _tmp11_;
		_tmp11_ = NULL;
		_g_object_unref0 (dst);
		dst = (GXmlDomNode*) _tmp18_;
		_tmp19_ = dst;
		_tmp20_ = node;
		_tmp21_ = deep;
		gxml_dom_node_copy ((GXmlDomDocument*) self, _tmp19_, _tmp20_, _tmp21_, &_inner_error_);
		if (G_UNLIKELY (_inner_error_ != NULL)) {
			g_propagate_error (error, _inner_error_);
			_g_object_unref0 (_tmp11_);
			_g_object_unref0 (dst);
			return NULL;
		}
		_tmp22_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) self);
		_tmp23_ = _tmp22_;
		_tmp24_ = _tmp23_;
		_tmp25_ = _tmp24_ == NULL;
		_g_object_unref0 (_tmp24_);
		if (_tmp25_) {
			GXmlDomNode* _tmp26_ = NULL;
			GXmlDomNode* _tmp27_ = NULL;
			GXmlDomNode* _tmp28_ = NULL;
			_tmp26_ = dst;
			_tmp27_ = gxml_dom_node_append_child ((GXmlDomNode*) self, _tmp26_, &_inner_error_);
			_tmp28_ = _tmp27_;
			_g_object_unref0 (_tmp28_);
			if (G_UNLIKELY (_inner_error_ != NULL)) {
				g_propagate_error (error, _inner_error_);
				_g_object_unref0 (_tmp11_);
				_g_object_unref0 (dst);
				return NULL;
			}
			result = dst;
			_g_object_unref0 (_tmp11_);
			return result;
		}
		_g_object_unref0 (_tmp11_);
	}
	_tmp29_ = node;
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp29_, GXML_TYPE_DOM_TEXT)) {
		GXmlDomText* _tmp30_ = NULL;
		GXmlDomNode* _tmp31_ = NULL;
		gchar* _tmp32_ = NULL;
		gchar* _tmp33_ = NULL;
		gchar* _tmp34_ = NULL;
		GXmlDomText* _tmp35_ = NULL;
		GXmlDomText* _tmp36_ = NULL;
		GXmlDomText* _tmp37_ = NULL;
		_tmp31_ = node;
		_tmp32_ = gxml_dom_character_data_get_data ((GXmlDomCharacterData*) (G_TYPE_CHECK_INSTANCE_TYPE (_tmp31_, GXML_TYPE_DOM_TEXT) ? ((GXmlDomText*) _tmp31_) : NULL));
		_tmp33_ = _tmp32_;
		_tmp34_ = _tmp33_;
		_tmp35_ = gxml_dom_document_create_text_node ((GXmlDomDocument*) self, _tmp34_, &_inner_error_);
		_tmp36_ = _tmp35_;
		_g_free0 (_tmp34_);
		_tmp30_ = _tmp36_;
		if (G_UNLIKELY (_inner_error_ != NULL)) {
			g_propagate_error (error, _inner_error_);
			_g_object_unref0 (dst);
			return NULL;
		}
		_tmp37_ = _tmp30_;
		_tmp30_ = NULL;
		_g_object_unref0 (dst);
		dst = (GXmlDomNode*) _tmp37_;
		_g_object_unref0 (_tmp30_);
	}
	_tmp38_ = node;
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp38_, GXML_TYPE_DOM_COMMENT)) {
		GXmlDomComment* _tmp39_ = NULL;
		GXmlDomNode* _tmp40_ = NULL;
		gchar* _tmp41_ = NULL;
		gchar* _tmp42_ = NULL;
		gchar* _tmp43_ = NULL;
		GXmlDomComment* _tmp44_ = NULL;
		GXmlDomComment* _tmp45_ = NULL;
		GXmlDomComment* _tmp46_ = NULL;
		_tmp40_ = node;
		_tmp41_ = gxml_dom_character_data_get_data ((GXmlDomCharacterData*) (G_TYPE_CHECK_INSTANCE_TYPE (_tmp40_, GXML_TYPE_DOM_COMMENT) ? ((GXmlDomComment*) _tmp40_) : NULL));
		_tmp42_ = _tmp41_;
		_tmp43_ = _tmp42_;
		_tmp44_ = gxml_dom_document_create_comment (G_TYPE_CHECK_INSTANCE_TYPE (self, GXML_TYPE_DOM_DOCUMENT) ? ((GXmlDomDocument*) self) : NULL, _tmp43_, &_inner_error_);
		_tmp45_ = _tmp44_;
		_g_free0 (_tmp43_);
		_tmp39_ = _tmp45_;
		if (G_UNLIKELY (_inner_error_ != NULL)) {
			g_propagate_error (error, _inner_error_);
			_g_object_unref0 (dst);
			return NULL;
		}
		_tmp46_ = _tmp39_;
		_tmp39_ = NULL;
		_g_object_unref0 (dst);
		dst = (GXmlDomNode*) _tmp46_;
		_g_object_unref0 (_tmp39_);
	}
	_tmp47_ = node;
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp47_, GXML_TYPE_DOM_PROCESSING_INSTRUCTION)) {
		GXmlDomProcessingInstruction* _tmp48_ = NULL;
		GXmlDomNode* _tmp49_ = NULL;
		gchar* _tmp50_ = NULL;
		gchar* _tmp51_ = NULL;
		gchar* _tmp52_ = NULL;
		GXmlDomNode* _tmp53_ = NULL;
		gchar* _tmp54_ = NULL;
		gchar* _tmp55_ = NULL;
		gchar* _tmp56_ = NULL;
		GXmlDomProcessingInstruction* _tmp57_ = NULL;
		GXmlDomProcessingInstruction* _tmp58_ = NULL;
		GXmlDomProcessingInstruction* _tmp59_ = NULL;
		_tmp49_ = node;
		_tmp50_ = gxml_dom_processing_instruction_get_target (G_TYPE_CHECK_INSTANCE_TYPE (_tmp49_, GXML_TYPE_DOM_PROCESSING_INSTRUCTION) ? ((GXmlDomProcessingInstruction*) _tmp49_) : NULL);
		_tmp51_ = _tmp50_;
		_tmp52_ = _tmp51_;
		_tmp53_ = node;
		_tmp54_ = gxml_dom_character_data_get_data ((GXmlDomCharacterData*) (G_TYPE_CHECK_INSTANCE_TYPE (_tmp53_, GXML_TYPE_DOM_PROCESSING_INSTRUCTION) ? ((GXmlDomProcessingInstruction*) _tmp53_) : NULL));
		_tmp55_ = _tmp54_;
		_tmp56_ = _tmp55_;
		_tmp57_ = gxml_dom_document_create_processing_instruction ((GXmlDomDocument*) self, _tmp52_, _tmp56_, &_inner_error_);
		_tmp58_ = _tmp57_;
		_g_free0 (_tmp56_);
		_g_free0 (_tmp52_);
		_tmp48_ = _tmp58_;
		if (G_UNLIKELY (_inner_error_ != NULL)) {
			g_propagate_error (error, _inner_error_);
			_g_object_unref0 (dst);
			return NULL;
		}
		_tmp59_ = _tmp48_;
		_tmp48_ = NULL;
		_g_object_unref0 (dst);
		dst = (GXmlDomNode*) _tmp59_;
		_g_object_unref0 (_tmp48_);
	}
	_tmp60_ = dst;
	if (_tmp60_ != NULL) {
		GXmlDomElement* _tmp61_ = NULL;
		GXmlDomElement* _tmp62_ = NULL;
		GXmlDomElement* _tmp63_ = NULL;
		GXmlDomNode* _tmp64_ = NULL;
		GXmlDomNode* _tmp65_ = NULL;
		GXmlDomNode* _tmp66_ = NULL;
		_tmp61_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) self);
		_tmp62_ = _tmp61_;
		_tmp63_ = _tmp62_;
		_tmp64_ = dst;
		_tmp65_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp63_, G_TYPE_CHECK_INSTANCE_TYPE (_tmp64_, GXML_TYPE_DOM_NODE) ? ((GXmlDomNode*) _tmp64_) : NULL, &_inner_error_);
		_tmp66_ = _tmp65_;
		_g_object_unref0 (_tmp66_);
		_g_object_unref0 (_tmp63_);
		if (G_UNLIKELY (_inner_error_ != NULL)) {
			g_propagate_error (error, _inner_error_);
			_g_object_unref0 (dst);
			return NULL;
		}
		result = dst;
		return result;
	}
	_tmp67_ = node;
	_tmp68_ = _g_object_ref0 (_tmp67_);
	result = _tmp68_;
	_g_object_unref0 (dst);
	return result;
}


static GXmlDomNode* gxml_gom_document_real_adopt_node (GXmlDomDocument* base, GXmlDomNode* node, GError** error) {
	GXmlGomDocument * self;
	GXmlDomNode* result = NULL;
	GXmlDomNode* _tmp0_ = NULL;
	GXmlDomNode* _tmp3_ = NULL;
	GXmlDomDocument* _tmp4_ = NULL;
	GXmlDomDocument* _tmp5_ = NULL;
	GXmlDomElement* dst = NULL;
	GXmlDomNode* _tmp8_ = NULL;
	gchar* _tmp9_ = NULL;
	gchar* _tmp10_ = NULL;
	gchar* _tmp11_ = NULL;
	GXmlDomElement* _tmp12_ = NULL;
	GXmlDomElement* _tmp13_ = NULL;
	GXmlDomElement* _tmp14_ = NULL;
	GXmlDomNode* _tmp15_ = NULL;
	GXmlDomNode* _tmp16_ = NULL;
	GXmlDomNode* _tmp17_ = NULL;
	GXmlDomNode* _tmp18_ = NULL;
	GXmlDomNode* _tmp19_ = NULL;
	gboolean _tmp20_ = FALSE;
	GXmlDomElement* _tmp39_ = NULL;
	GXmlDomElement* _tmp40_ = NULL;
	GXmlDomElement* _tmp41_ = NULL;
	gboolean _tmp42_ = FALSE;
	GXmlDomElement* _tmp52_ = NULL;
	GXmlDomNode* _tmp53_ = NULL;
	GError * _inner_error_ = NULL;
	self = (GXmlGomDocument*) base;
	g_return_val_if_fail (node != NULL, NULL);
	_tmp0_ = node;
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, GXML_TYPE_DOM_DOCUMENT)) {
		const gchar* _tmp1_ = NULL;
		GError* _tmp2_ = NULL;
		_tmp1_ = _ ("Can't adopt a Document");
		_tmp2_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_NOT_SUPPORTED_ERROR, _tmp1_);
		_inner_error_ = _tmp2_;
		g_propagate_error (error, _inner_error_);
		return NULL;
	}
	_tmp3_ = node;
	_tmp4_ = gxml_dom_node_get_owner_document (_tmp3_);
	_tmp5_ = _tmp4_;
	if (self == _tmp5_) {
		GXmlDomNode* _tmp6_ = NULL;
		GXmlDomNode* _tmp7_ = NULL;
		_tmp6_ = node;
		_tmp7_ = _g_object_ref0 (_tmp6_);
		result = _tmp7_;
		return result;
	}
	_tmp8_ = node;
	_tmp9_ = gxml_dom_node_get_node_name (_tmp8_);
	_tmp10_ = _tmp9_;
	_tmp11_ = _tmp10_;
	_tmp12_ = gxml_dom_document_create_element ((GXmlDomDocument*) self, _tmp11_, &_inner_error_);
	_tmp13_ = _tmp12_;
	_g_free0 (_tmp11_);
	dst = _tmp13_;
	if (G_UNLIKELY (_inner_error_ != NULL)) {
		g_propagate_error (error, _inner_error_);
		return NULL;
	}
	_tmp14_ = dst;
	_tmp15_ = node;
	gxml_dom_node_copy ((GXmlDomDocument*) self, (GXmlDomNode*) _tmp14_, _tmp15_, TRUE, &_inner_error_);
	if (G_UNLIKELY (_inner_error_ != NULL)) {
		g_propagate_error (error, _inner_error_);
		_g_object_unref0 (dst);
		return NULL;
	}
	_tmp16_ = node;
	_tmp17_ = gxml_dom_node_get_parent_node (_tmp16_);
	_tmp18_ = _tmp17_;
	_tmp19_ = _tmp18_;
	_tmp20_ = _tmp19_ != NULL;
	_g_object_unref0 (_tmp19_);
	if (_tmp20_) {
		GXmlDomNode* _tmp21_ = NULL;
		GXmlDomNode* _tmp22_ = NULL;
		GXmlDomNode* _tmp23_ = NULL;
		GXmlDomNode* _tmp24_ = NULL;
		GXmlDomNodeList* _tmp25_ = NULL;
		GXmlDomNodeList* _tmp26_ = NULL;
		GXmlDomNodeList* _tmp27_ = NULL;
		GXmlDomNode* _tmp28_ = NULL;
		GXmlDomNode* _tmp29_ = NULL;
		GXmlDomNode* _tmp30_ = NULL;
		GXmlDomNode* _tmp31_ = NULL;
		GXmlDomNodeList* _tmp32_ = NULL;
		GXmlDomNodeList* _tmp33_ = NULL;
		GXmlDomNodeList* _tmp34_ = NULL;
		GXmlDomNode* _tmp35_ = NULL;
		gint _tmp36_ = 0;
		gpointer _tmp37_ = NULL;
		GXmlDomNode* _tmp38_ = NULL;
		_tmp21_ = node;
		_tmp22_ = gxml_dom_node_get_parent_node (_tmp21_);
		_tmp23_ = _tmp22_;
		_tmp24_ = _tmp23_;
		_tmp25_ = gxml_dom_node_get_child_nodes (_tmp24_);
		_tmp26_ = _tmp25_;
		_tmp27_ = _tmp26_;
		_tmp28_ = node;
		_tmp29_ = gxml_dom_node_get_parent_node (_tmp28_);
		_tmp30_ = _tmp29_;
		_tmp31_ = _tmp30_;
		_tmp32_ = gxml_dom_node_get_child_nodes (_tmp31_);
		_tmp33_ = _tmp32_;
		_tmp34_ = _tmp33_;
		_tmp35_ = node;
		_tmp36_ = gee_list_index_of ((GeeList*) _tmp34_, _tmp35_);
		_tmp37_ = gee_list_remove_at ((GeeList*) _tmp27_, _tmp36_);
		_tmp38_ = (GXmlDomNode*) _tmp37_;
		_g_object_unref0 (_tmp38_);
		_g_object_unref0 (_tmp34_);
		_g_object_unref0 (_tmp31_);
		_g_object_unref0 (_tmp27_);
		_g_object_unref0 (_tmp24_);
	}
	_tmp39_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) self);
	_tmp40_ = _tmp39_;
	_tmp41_ = _tmp40_;
	_tmp42_ = _tmp41_ == NULL;
	_g_object_unref0 (_tmp41_);
	if (_tmp42_) {
		GXmlDomElement* _tmp43_ = NULL;
		GXmlDomNode* _tmp44_ = NULL;
		GXmlDomNode* _tmp45_ = NULL;
		_tmp43_ = dst;
		_tmp44_ = gxml_dom_node_append_child ((GXmlDomNode*) self, G_TYPE_CHECK_INSTANCE_TYPE (_tmp43_, GXML_TYPE_DOM_NODE) ? ((GXmlDomNode*) _tmp43_) : NULL, &_inner_error_);
		_tmp45_ = _tmp44_;
		_g_object_unref0 (_tmp45_);
		if (G_UNLIKELY (_inner_error_ != NULL)) {
			g_propagate_error (error, _inner_error_);
			_g_object_unref0 (dst);
			return NULL;
		}
	} else {
		GXmlDomElement* _tmp46_ = NULL;
		GXmlDomElement* _tmp47_ = NULL;
		GXmlDomElement* _tmp48_ = NULL;
		GXmlDomElement* _tmp49_ = NULL;
		GXmlDomNode* _tmp50_ = NULL;
		GXmlDomNode* _tmp51_ = NULL;
		_tmp46_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) self);
		_tmp47_ = _tmp46_;
		_tmp48_ = _tmp47_;
		_tmp49_ = dst;
		_tmp50_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp48_, G_TYPE_CHECK_INSTANCE_TYPE (_tmp49_, GXML_TYPE_DOM_NODE) ? ((GXmlDomNode*) _tmp49_) : NULL, &_inner_error_);
		_tmp51_ = _tmp50_;
		_g_object_unref0 (_tmp51_);
		_g_object_unref0 (_tmp48_);
		if (G_UNLIKELY (_inner_error_ != NULL)) {
			g_propagate_error (error, _inner_error_);
			_g_object_unref0 (dst);
			return NULL;
		}
	}
	_tmp52_ = dst;
	_tmp53_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp52_, GXML_TYPE_DOM_NODE, GXmlDomNode));
	result = _tmp53_;
	_g_object_unref0 (dst);
	return result;
}


static GXmlDomEvent* gxml_gom_document_real_create_event (GXmlDomDocument* base, const gchar* iface, GError** error) {
	GXmlGomDocument * self;
	GXmlDomEvent* result = NULL;
	gchar* s = NULL;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	const gchar* _tmp4_ = NULL;
	const gchar* _tmp6_ = NULL;
	const gchar* _tmp8_ = NULL;
	const gchar* _tmp10_ = NULL;
	const gchar* _tmp11_ = NULL;
	const gchar* _tmp12_ = NULL;
	const gchar* _tmp13_ = NULL;
	const gchar* _tmp14_ = NULL;
	const gchar* _tmp15_ = NULL;
	const gchar* _tmp16_ = NULL;
	const gchar* _tmp17_ = NULL;
	GXmlDomEvent* _tmp18_ = NULL;
	GXmlDomEvent* _tmp19_ = NULL;
	self = (GXmlGomDocument*) base;
	g_return_val_if_fail (iface != NULL, NULL);
	_tmp0_ = iface;
	_tmp1_ = g_utf8_strdown (_tmp0_, (gssize) -1);
	s = _tmp1_;
	_tmp2_ = s;
	if (g_strcmp0 (_tmp2_, "customevent") == 0) {
		GXmlGDomCustomEvent* _tmp3_ = NULL;
		_tmp3_ = gxml_gdom_custom_event_new ();
		_g_object_unref0 (self->_constructor);
		self->_constructor = (GXmlDomEvent*) _tmp3_;
	}
	_tmp4_ = s;
	if (g_strcmp0 (_tmp4_, "event") == 0) {
		GXmlGDomCustomEvent* _tmp5_ = NULL;
		_tmp5_ = gxml_gdom_custom_event_new ();
		_g_object_unref0 (self->_constructor);
		self->_constructor = (GXmlDomEvent*) _tmp5_;
	}
	_tmp6_ = s;
	if (g_strcmp0 (_tmp6_, "events") == 0) {
		GXmlGDomCustomEvent* _tmp7_ = NULL;
		_tmp7_ = gxml_gdom_custom_event_new ();
		_g_object_unref0 (self->_constructor);
		self->_constructor = (GXmlDomEvent*) _tmp7_;
	}
	_tmp8_ = s;
	if (g_strcmp0 (_tmp8_, "htmlevents") == 0) {
		GXmlGDomCustomEvent* _tmp9_ = NULL;
		_tmp9_ = gxml_gdom_custom_event_new ();
		_g_object_unref0 (self->_constructor);
		self->_constructor = (GXmlDomEvent*) _tmp9_;
	}
	_tmp10_ = s;
	if (g_strcmp0 (_tmp10_, "keyboardevent") == 0) {
		_g_object_unref0 (self->_constructor);
		self->_constructor = NULL;
	}
	_tmp11_ = s;
	if (g_strcmp0 (_tmp11_, "keyevents") == 0) {
		_g_object_unref0 (self->_constructor);
		self->_constructor = NULL;
	}
	_tmp12_ = s;
	if (g_strcmp0 (_tmp12_, "messageevent") == 0) {
		_g_object_unref0 (self->_constructor);
		self->_constructor = NULL;
	}
	_tmp13_ = s;
	if (g_strcmp0 (_tmp13_, "mouseevent") == 0) {
		_g_object_unref0 (self->_constructor);
		self->_constructor = NULL;
	}
	_tmp14_ = s;
	if (g_strcmp0 (_tmp14_, "mouseevents") == 0) {
		_g_object_unref0 (self->_constructor);
		self->_constructor = NULL;
	}
	_tmp15_ = s;
	if (g_strcmp0 (_tmp15_, "touchevent") == 0) {
		_g_object_unref0 (self->_constructor);
		self->_constructor = NULL;
	}
	_tmp16_ = s;
	if (g_strcmp0 (_tmp16_, "uievent") == 0) {
		_g_object_unref0 (self->_constructor);
		self->_constructor = NULL;
	}
	_tmp17_ = s;
	if (g_strcmp0 (_tmp17_, "uievents") == 0) {
		_g_object_unref0 (self->_constructor);
		self->_constructor = NULL;
	}
	_tmp18_ = self->_constructor;
	_tmp19_ = _g_object_ref0 (_tmp18_);
	result = _tmp19_;
	_g_free0 (s);
	return result;
}


static GXmlDomRange* gxml_gom_document_real_create_range (GXmlDomDocument* base) {
	GXmlGomDocument * self;
	GXmlDomRange* result = NULL;
	GXmlGDomRange* _tmp0_ = NULL;
	self = (GXmlGomDocument*) base;
	_tmp0_ = gxml_gdom_range_new ((GXmlDomDocument*) self);
	result = (GXmlDomRange*) _tmp0_;
	return result;
}


static GXmlDomNodeIterator* gxml_gom_document_real_create_node_iterator (GXmlDomDocument* base, GXmlDomNode* root, gint what_to_show, GXmlDomNodeFilter* filter) {
	GXmlGomDocument * self;
	GXmlDomNodeIterator* result = NULL;
	GXmlDomNode* _tmp0_ = NULL;
	gint _tmp1_ = 0;
	GXmlDomNodeFilter* _tmp2_ = NULL;
	GXmlGDomNodeIterator* _tmp3_ = NULL;
	self = (GXmlGomDocument*) base;
	g_return_val_if_fail (root != NULL, NULL);
	_tmp0_ = root;
	_tmp1_ = what_to_show;
	_tmp2_ = filter;
	_tmp3_ = gxml_gdom_node_iterator_new (_tmp0_, _tmp1_, _tmp2_);
	result = (GXmlDomNodeIterator*) _tmp3_;
	return result;
}


static GXmlDomTreeWalker* gxml_gom_document_real_create_tree_walker (GXmlDomDocument* base, GXmlDomNode* root, gint what_to_show, GXmlDomNodeFilter* filter) {
	GXmlGomDocument * self;
	GXmlDomTreeWalker* result = NULL;
	GXmlDomNode* _tmp0_ = NULL;
	gint _tmp1_ = 0;
	GXmlDomNodeFilter* _tmp2_ = NULL;
	GXmlGDomTreeWalker* _tmp3_ = NULL;
	self = (GXmlGomDocument*) base;
	g_return_val_if_fail (root != NULL, NULL);
	_tmp0_ = root;
	_tmp1_ = what_to_show;
	_tmp2_ = filter;
	_tmp3_ = gxml_gdom_tree_walker_new (_tmp0_, _tmp1_, _tmp2_);
	result = (GXmlDomTreeWalker*) _tmp3_;
	return result;
}


static GXmlDomElement* gxml_gom_document_real_query_selector (GXmlDomParentNode* base, const gchar* selectors, GError** error) {
	GXmlGomDocument * self;
	GXmlDomElement* result = NULL;
	self = (GXmlGomDocument*) base;
	g_return_val_if_fail (selectors != NULL, NULL);
	result = NULL;
	return result;
}


static GXmlDomNodeList* gxml_gom_document_real_query_selector_all (GXmlDomParentNode* base, const gchar* selectors, GError** error) {
	GXmlGomDocument * self;
	GXmlDomNodeList* result = NULL;
	GXmlDomNodeList* nulllist = NULL;
	self = (GXmlGomDocument*) base;
	g_return_val_if_fail (selectors != NULL, NULL);
	nulllist = NULL;
	result = nulllist;
	return result;
}


static GXmlDomElement* gxml_gom_document_real_get_element_by_id (GXmlDomNonElementParentNode* base, const gchar* element_id, GError** error) {
	GXmlGomDocument * self;
	GXmlDomElement* result = NULL;
	GXmlDomElementList* l = NULL;
	const gchar* _tmp0_ = NULL;
	GXmlDomElementList* _tmp1_ = NULL;
	GXmlDomElementList* _tmp2_ = NULL;
	gint _tmp3_ = 0;
	gint _tmp4_ = 0;
	self = (GXmlGomDocument*) base;
	g_return_val_if_fail (element_id != NULL, NULL);
	_tmp0_ = element_id;
	_tmp1_ = gxml_dom_parent_node_get_elements_by_property_value ((GXmlDomParentNode*) self, "id", _tmp0_);
	l = _tmp1_;
	_tmp2_ = l;
	_tmp3_ = gee_abstract_collection_get_size ((GeeAbstractCollection*) _tmp2_);
	_tmp4_ = _tmp3_;
	if (_tmp4_ > 0) {
		GXmlDomElementList* _tmp5_ = NULL;
		gpointer _tmp6_ = NULL;
		_tmp5_ = l;
		_tmp6_ = gee_abstract_list_get ((GeeAbstractList*) _tmp5_, 0);
		result = G_TYPE_CHECK_INSTANCE_CAST ((GXmlDomElement*) _tmp6_, GXML_TYPE_DOM_ELEMENT, GXmlDomElement);
		_g_object_unref0 (l);
		return result;
	}
	result = NULL;
	_g_object_unref0 (l);
	return result;
}


static GXmlDomImplementation* gxml_gom_document_real_get_implementation (GXmlDomDocument* base) {
	GXmlDomImplementation* result;
	GXmlGomDocument* self;
	GXmlDomImplementation* _tmp0_ = NULL;
	self = (GXmlGomDocument*) base;
	_tmp0_ = self->_implementation;
	result = _tmp0_;
	return result;
}


static const gchar* gxml_gom_document_real_get_url (GXmlDomDocument* base) {
	const gchar* result;
	GXmlGomDocument* self;
	const gchar* _tmp0_ = NULL;
	self = (GXmlGomDocument*) base;
	_tmp0_ = self->_url;
	result = _tmp0_;
	return result;
}


static const gchar* gxml_gom_document_real_get_document_uri (GXmlDomDocument* base) {
	const gchar* result;
	GXmlGomDocument* self;
	const gchar* _tmp0_ = NULL;
	self = (GXmlGomDocument*) base;
	_tmp0_ = self->_url;
	result = _tmp0_;
	return result;
}


static const gchar* gxml_gom_document_real_get_origin (GXmlDomDocument* base) {
	const gchar* result;
	GXmlGomDocument* self;
	const gchar* _tmp0_ = NULL;
	self = (GXmlGomDocument*) base;
	_tmp0_ = self->_origin;
	result = _tmp0_;
	return result;
}


static const gchar* gxml_gom_document_real_get_compat_mode (GXmlDomDocument* base) {
	const gchar* result;
	GXmlGomDocument* self;
	const gchar* _tmp0_ = NULL;
	self = (GXmlGomDocument*) base;
	_tmp0_ = self->_compat_mode;
	result = _tmp0_;
	return result;
}


static const gchar* gxml_gom_document_real_get_character_set (GXmlDomDocument* base) {
	const gchar* result;
	GXmlGomDocument* self;
	const gchar* _tmp0_ = NULL;
	self = (GXmlGomDocument*) base;
	_tmp0_ = self->_character_set;
	result = _tmp0_;
	return result;
}


static const gchar* gxml_gom_document_real_get_content_type (GXmlDomDocument* base) {
	const gchar* result;
	GXmlGomDocument* self;
	const gchar* _tmp0_ = NULL;
	self = (GXmlGomDocument*) base;
	_tmp0_ = self->_content_type;
	result = _tmp0_;
	return result;
}


static GXmlDomDocumentType* gxml_gom_document_real_get_doctype (GXmlDomDocument* base) {
	GXmlDomDocumentType* result;
	GXmlGomDocument* self;
	self = (GXmlGomDocument*) base;
	{
		GXmlDomNodeList* _n_list = NULL;
		GXmlDomNodeList* _tmp0_ = NULL;
		GXmlDomNodeList* _tmp1_ = NULL;
		gint _n_size = 0;
		GXmlDomNodeList* _tmp2_ = NULL;
		gint _tmp3_ = 0;
		gint _tmp4_ = 0;
		gint _n_index = 0;
		_tmp0_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) self);
		_tmp1_ = _tmp0_;
		_n_list = _tmp1_;
		_tmp2_ = _n_list;
		_tmp3_ = gee_collection_get_size ((GeeCollection*) _tmp2_);
		_tmp4_ = _tmp3_;
		_n_size = _tmp4_;
		_n_index = -1;
		while (TRUE) {
			gint _tmp5_ = 0;
			gint _tmp6_ = 0;
			gint _tmp7_ = 0;
			GXmlDomNode* n = NULL;
			GXmlDomNodeList* _tmp8_ = NULL;
			gint _tmp9_ = 0;
			gpointer _tmp10_ = NULL;
			GXmlDomNode* _tmp11_ = NULL;
			_tmp5_ = _n_index;
			_n_index = _tmp5_ + 1;
			_tmp6_ = _n_index;
			_tmp7_ = _n_size;
			if (!(_tmp6_ < _tmp7_)) {
				break;
			}
			_tmp8_ = _n_list;
			_tmp9_ = _n_index;
			_tmp10_ = gee_list_get ((GeeList*) _tmp8_, _tmp9_);
			n = (GXmlDomNode*) _tmp10_;
			_tmp11_ = n;
			if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp11_, GXML_TYPE_DOM_DOCUMENT_TYPE)) {
				GXmlDomNode* _tmp12_ = NULL;
				GXmlDomDocumentType* _tmp13_ = NULL;
				_tmp12_ = n;
				_tmp13_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp12_, GXML_TYPE_DOM_DOCUMENT_TYPE, GXmlDomDocumentType));
				result = _tmp13_;
				_g_object_unref0 (n);
				_g_object_unref0 (_n_list);
				return result;
			}
			_g_object_unref0 (n);
		}
		_g_object_unref0 (_n_list);
	}
	result = NULL;
	return result;
}


static GXmlDomElement* gxml_gom_document_real_get_document_element (GXmlDomDocument* base) {
	GXmlDomElement* result;
	GXmlGomDocument* self;
	GXmlDomNodeList* _tmp0_ = NULL;
	GXmlDomNodeList* _tmp1_ = NULL;
	GXmlDomNodeList* _tmp2_ = NULL;
	gint _tmp3_ = 0;
	gint _tmp4_ = 0;
	gboolean _tmp5_ = FALSE;
	GXmlDomNodeList* _tmp6_ = NULL;
	GXmlDomNodeList* _tmp7_ = NULL;
	GXmlDomNodeList* _tmp8_ = NULL;
	gpointer _tmp9_ = NULL;
	GXmlDomNode* _tmp10_ = NULL;
	GXmlDomElement* _tmp11_ = NULL;
	GXmlDomElement* _tmp12_ = NULL;
	self = (GXmlGomDocument*) base;
	_tmp0_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) self);
	_tmp1_ = _tmp0_;
	_tmp2_ = _tmp1_;
	_tmp3_ = gee_collection_get_size ((GeeCollection*) _tmp2_);
	_tmp4_ = _tmp3_;
	_tmp5_ = _tmp4_ == 0;
	_g_object_unref0 (_tmp2_);
	if (_tmp5_) {
		result = NULL;
		return result;
	}
	_tmp6_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) self);
	_tmp7_ = _tmp6_;
	_tmp8_ = _tmp7_;
	_tmp9_ = gee_list_get ((GeeList*) _tmp8_, 0);
	_tmp10_ = (GXmlDomNode*) _tmp9_;
	_tmp11_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp10_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp10_) : NULL;
	if (_tmp11_ == NULL) {
		_g_object_unref0 (_tmp10_);
	}
	_tmp12_ = _tmp11_;
	_g_object_unref0 (_tmp8_);
	result = _tmp12_;
	return result;
}


static GXmlDomHTMLCollection* gxml_gom_document_real_get_children (GXmlDomParentNode* base) {
	GXmlDomHTMLCollection* result;
	GXmlGomDocument* self;
	GXmlDomNodeList* _tmp0_ = NULL;
	GXmlDomNodeList* _tmp1_ = NULL;
	self = (GXmlGomDocument*) base;
	_tmp0_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) self);
	_tmp1_ = _tmp0_;
	result = G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, GXML_TYPE_DOM_HTML_COLLECTION, GXmlDomHTMLCollection);
	return result;
}


static GXmlDomElement* gxml_gom_document_real_get_first_element_child (GXmlDomParentNode* base) {
	GXmlDomElement* result;
	GXmlGomDocument* self;
	GXmlDomNodeList* _tmp0_ = NULL;
	GXmlDomNodeList* _tmp1_ = NULL;
	GXmlDomNodeList* _tmp2_ = NULL;
	gpointer _tmp3_ = NULL;
	GXmlDomElement* _tmp4_ = NULL;
	self = (GXmlGomDocument*) base;
	_tmp0_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) self);
	_tmp1_ = _tmp0_;
	_tmp2_ = _tmp1_;
	_tmp3_ = gee_list_first ((GeeList*) _tmp2_);
	_tmp4_ = G_TYPE_CHECK_INSTANCE_CAST ((GXmlDomNode*) _tmp3_, GXML_TYPE_DOM_ELEMENT, GXmlDomElement);
	_g_object_unref0 (_tmp2_);
	result = _tmp4_;
	return result;
}


static GXmlDomElement* gxml_gom_document_real_get_last_element_child (GXmlDomParentNode* base) {
	GXmlDomElement* result;
	GXmlGomDocument* self;
	GXmlDomNodeList* _tmp0_ = NULL;
	GXmlDomNodeList* _tmp1_ = NULL;
	GXmlDomNodeList* _tmp2_ = NULL;
	gpointer _tmp3_ = NULL;
	GXmlDomElement* _tmp4_ = NULL;
	self = (GXmlGomDocument*) base;
	_tmp0_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) self);
	_tmp1_ = _tmp0_;
	_tmp2_ = _tmp1_;
	_tmp3_ = gee_list_last ((GeeList*) _tmp2_);
	_tmp4_ = G_TYPE_CHECK_INSTANCE_CAST ((GXmlDomNode*) _tmp3_, GXML_TYPE_DOM_ELEMENT, GXmlDomElement);
	_g_object_unref0 (_tmp2_);
	result = _tmp4_;
	return result;
}


static gint gxml_gom_document_real_get_child_element_count (GXmlDomParentNode* base) {
	gint result;
	GXmlGomDocument* self;
	GXmlDomNodeList* _tmp0_ = NULL;
	GXmlDomNodeList* _tmp1_ = NULL;
	GXmlDomNodeList* _tmp2_ = NULL;
	gint _tmp3_ = 0;
	gint _tmp4_ = 0;
	gint _tmp5_ = 0;
	self = (GXmlGomDocument*) base;
	_tmp0_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) self);
	_tmp1_ = _tmp0_;
	_tmp2_ = _tmp1_;
	_tmp3_ = gee_collection_get_size ((GeeCollection*) _tmp2_);
	_tmp4_ = _tmp3_;
	_tmp5_ = _tmp4_;
	_g_object_unref0 (_tmp2_);
	result = _tmp5_;
	return result;
}


static GObject * gxml_gom_document_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	GXmlGomDocument * self;
	gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	parent_class = G_OBJECT_CLASS (gxml_gom_document_parent_class);
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GXML_TYPE_GOM_DOCUMENT, GXmlGomDocument);
	_tmp0_ = g_strdup ("#document");
	_g_free0 (((GXmlGomNode*) self)->_local_name);
	((GXmlGomNode*) self)->_local_name = _tmp0_;
	((GXmlGomNode*) self)->_node_type = GXML_DOM_NODE_NODE_TYPE_DOCUMENT_NODE;
	_tmp1_ = g_strdup ("about:blank");
	_g_free0 (self->_url);
	self->_url = _tmp1_;
	_tmp2_ = g_strdup ("");
	_g_free0 (self->_origin);
	self->_origin = _tmp2_;
	_tmp3_ = g_strdup ("");
	_g_free0 (self->_compat_mode);
	self->_compat_mode = _tmp3_;
	_tmp4_ = g_strdup ("utf-8");
	_g_free0 (self->_character_set);
	self->_character_set = _tmp4_;
	_tmp5_ = g_strdup ("application/xml");
	_g_free0 (self->_content_type);
	self->_content_type = _tmp5_;
	return obj;
}


static void gxml_gom_document_class_init (GXmlGomDocumentClass * klass) {
	gxml_gom_document_parent_class = g_type_class_peek_parent (klass);
	G_OBJECT_CLASS (klass)->get_property = _vala_gxml_gom_document_get_property;
	G_OBJECT_CLASS (klass)->constructor = gxml_gom_document_constructor;
	G_OBJECT_CLASS (klass)->finalize = gxml_gom_document_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_DOCUMENT_IMPLEMENTATION, g_param_spec_object ("implementation", "implementation", "implementation", GXML_TYPE_DOM_IMPLEMENTATION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_DOCUMENT_URL, g_param_spec_string ("url", "url", "url", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_DOCUMENT_DOCUMENT_URI, g_param_spec_string ("document-uri", "document-uri", "document-uri", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_DOCUMENT_ORIGIN, g_param_spec_string ("origin", "origin", "origin", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_DOCUMENT_COMPAT_MODE, g_param_spec_string ("compat-mode", "compat-mode", "compat-mode", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_DOCUMENT_CHARACTER_SET, g_param_spec_string ("character-set", "character-set", "character-set", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_DOCUMENT_CONTENT_TYPE, g_param_spec_string ("content-type", "content-type", "content-type", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_DOCUMENT_DOCTYPE, g_param_spec_object ("doctype", "doctype", "doctype", GXML_TYPE_DOM_DOCUMENT_TYPE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_DOCUMENT_DOCUMENT_ELEMENT, g_param_spec_object ("document-element", "document-element", "document-element", GXML_TYPE_DOM_ELEMENT, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_DOCUMENT_CHILDREN, g_param_spec_object ("children", "children", "children", GXML_TYPE_DOM_HTML_COLLECTION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_DOCUMENT_FIRST_ELEMENT_CHILD, g_param_spec_object ("first-element-child", "first-element-child", "first-element-child", GXML_TYPE_DOM_ELEMENT, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_DOCUMENT_LAST_ELEMENT_CHILD, g_param_spec_object ("last-element-child", "last-element-child", "last-element-child", GXML_TYPE_DOM_ELEMENT, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_DOCUMENT_CHILD_ELEMENT_COUNT, g_param_spec_int ("child-element-count", "child-element-count", "child-element-count", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
}


static void gxml_gom_document_gxml_dom_parent_node_interface_init (GXmlDomParentNodeIface * iface) {
	gxml_gom_document_gxml_dom_parent_node_parent_iface = g_type_interface_peek_parent (iface);
	iface->query_selector = (GXmlDomElement* (*)(GXmlDomParentNode*, const gchar*, GError**)) gxml_gom_document_real_query_selector;
	iface->query_selector_all = (GXmlDomNodeList* (*)(GXmlDomParentNode*, const gchar*, GError**)) gxml_gom_document_real_query_selector_all;
	iface->get_children = gxml_gom_document_real_get_children;
	iface->get_first_element_child = gxml_gom_document_real_get_first_element_child;
	iface->get_last_element_child = gxml_gom_document_real_get_last_element_child;
	iface->get_child_element_count = gxml_gom_document_real_get_child_element_count;
}


static void gxml_gom_document_gxml_dom_non_element_parent_node_interface_init (GXmlDomNonElementParentNodeIface * iface) {
	gxml_gom_document_gxml_dom_non_element_parent_node_parent_iface = g_type_interface_peek_parent (iface);
	iface->get_element_by_id = (GXmlDomElement* (*)(GXmlDomNonElementParentNode*, const gchar*, GError**)) gxml_gom_document_real_get_element_by_id;
}


static void gxml_gom_document_gxml_dom_document_interface_init (GXmlDomDocumentIface * iface) {
	gxml_gom_document_gxml_dom_document_parent_iface = g_type_interface_peek_parent (iface);
	iface->create_element = (GXmlDomElement* (*)(GXmlDomDocument*, const gchar*, GError**)) gxml_gom_document_real_create_element;
	iface->create_element_ns = (GXmlDomElement* (*)(GXmlDomDocument*, const gchar*, const gchar*, GError**)) gxml_gom_document_real_create_element_ns;
	iface->get_elements_by_tag_name = (GXmlDomHTMLCollection* (*)(GXmlDomDocument*, const gchar*)) gxml_gom_document_real_get_elements_by_tag_name;
	iface->get_elements_by_tag_name_ns = (GXmlDomHTMLCollection* (*)(GXmlDomDocument*, const gchar*, const gchar*)) gxml_gom_document_real_get_elements_by_tag_name_ns;
	iface->get_elements_by_class_name = (GXmlDomHTMLCollection* (*)(GXmlDomDocument*, const gchar*)) gxml_gom_document_real_get_elements_by_class_name;
	iface->create_document_fragment = (GXmlDomDocumentFragment* (*)(GXmlDomDocument*)) gxml_gom_document_real_create_document_fragment;
	iface->create_text_node = (GXmlDomText* (*)(GXmlDomDocument*, const gchar*, GError**)) gxml_gom_document_real_create_text_node;
	iface->create_comment = (GXmlDomComment* (*)(GXmlDomDocument*, const gchar*, GError**)) gxml_gom_document_real_gxml_dom_document_create_comment;
	iface->create_processing_instruction = (GXmlDomProcessingInstruction* (*)(GXmlDomDocument*, const gchar*, const gchar*, GError**)) gxml_gom_document_real_create_processing_instruction;
	iface->import_node = (GXmlDomNode* (*)(GXmlDomDocument*, GXmlDomNode*, gboolean, GError**)) gxml_gom_document_real_import_node;
	iface->adopt_node = (GXmlDomNode* (*)(GXmlDomDocument*, GXmlDomNode*, GError**)) gxml_gom_document_real_adopt_node;
	iface->create_event = (GXmlDomEvent* (*)(GXmlDomDocument*, const gchar*, GError**)) gxml_gom_document_real_create_event;
	iface->create_range = (GXmlDomRange* (*)(GXmlDomDocument*)) gxml_gom_document_real_create_range;
	iface->create_node_iterator = (GXmlDomNodeIterator* (*)(GXmlDomDocument*, GXmlDomNode*, gint, GXmlDomNodeFilter*)) gxml_gom_document_real_create_node_iterator;
	iface->create_tree_walker = (GXmlDomTreeWalker* (*)(GXmlDomDocument*, GXmlDomNode*, gint, GXmlDomNodeFilter*)) gxml_gom_document_real_create_tree_walker;
	iface->get_implementation = gxml_gom_document_real_get_implementation;
	iface->get_url = gxml_gom_document_real_get_url;
	iface->get_document_uri = gxml_gom_document_real_get_document_uri;
	iface->get_origin = gxml_gom_document_real_get_origin;
	iface->get_compat_mode = gxml_gom_document_real_get_compat_mode;
	iface->get_character_set = gxml_gom_document_real_get_character_set;
	iface->get_content_type = gxml_gom_document_real_get_content_type;
	iface->get_doctype = gxml_gom_document_real_get_doctype;
	iface->get_document_element = gxml_gom_document_real_get_document_element;
}


static void gxml_gom_document_gxml_dom_xml_document_interface_init (GXmlDomXMLDocumentIface * iface) {
	gxml_gom_document_gxml_dom_xml_document_parent_iface = g_type_interface_peek_parent (iface);
}


static void gxml_gom_document_instance_init (GXmlGomDocument * self) {
	GXmlGomImplementation* _tmp0_ = NULL;
	_tmp0_ = gxml_gom_implementation_new ();
	self->_implementation = (GXmlDomImplementation*) _tmp0_;
}


static void gxml_gom_document_finalize (GObject* obj) {
	GXmlGomDocument * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GXML_TYPE_GOM_DOCUMENT, GXmlGomDocument);
	_g_object_unref0 (self->_implementation);
	_g_free0 (self->_url);
	_g_free0 (self->_origin);
	_g_free0 (self->_compat_mode);
	_g_free0 (self->_character_set);
	_g_free0 (self->_content_type);
	_g_object_unref0 (self->_constructor);
	G_OBJECT_CLASS (gxml_gom_document_parent_class)->finalize (obj);
}


GType gxml_gom_document_get_type (void) {
	static volatile gsize gxml_gom_document_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_gom_document_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlGomDocumentClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gxml_gom_document_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GXmlGomDocument), 0, (GInstanceInitFunc) gxml_gom_document_instance_init, NULL };
		static const GInterfaceInfo gxml_dom_parent_node_info = { (GInterfaceInitFunc) gxml_gom_document_gxml_dom_parent_node_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		static const GInterfaceInfo gxml_dom_non_element_parent_node_info = { (GInterfaceInitFunc) gxml_gom_document_gxml_dom_non_element_parent_node_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		static const GInterfaceInfo gxml_dom_document_info = { (GInterfaceInitFunc) gxml_gom_document_gxml_dom_document_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		static const GInterfaceInfo gxml_dom_xml_document_info = { (GInterfaceInitFunc) gxml_gom_document_gxml_dom_xml_document_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType gxml_gom_document_type_id;
		gxml_gom_document_type_id = g_type_register_static (GXML_TYPE_GOM_NODE, "GXmlGomDocument", &g_define_type_info, 0);
		g_type_add_interface_static (gxml_gom_document_type_id, GXML_TYPE_DOM_PARENT_NODE, &gxml_dom_parent_node_info);
		g_type_add_interface_static (gxml_gom_document_type_id, GXML_TYPE_DOM_NON_ELEMENT_PARENT_NODE, &gxml_dom_non_element_parent_node_info);
		g_type_add_interface_static (gxml_gom_document_type_id, GXML_TYPE_DOM_DOCUMENT, &gxml_dom_document_info);
		g_type_add_interface_static (gxml_gom_document_type_id, GXML_TYPE_DOM_XML_DOCUMENT, &gxml_dom_xml_document_info);
		g_once_init_leave (&gxml_gom_document_type_id__volatile, gxml_gom_document_type_id);
	}
	return gxml_gom_document_type_id__volatile;
}


static void _vala_gxml_gom_document_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	GXmlGomDocument * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GXML_TYPE_GOM_DOCUMENT, GXmlGomDocument);
	switch (property_id) {
		case GXML_GOM_DOCUMENT_IMPLEMENTATION:
		g_value_set_object (value, gxml_dom_document_get_implementation ((GXmlDomDocument*) self));
		break;
		case GXML_GOM_DOCUMENT_URL:
		g_value_set_string (value, gxml_dom_document_get_url ((GXmlDomDocument*) self));
		break;
		case GXML_GOM_DOCUMENT_DOCUMENT_URI:
		g_value_set_string (value, gxml_dom_document_get_document_uri ((GXmlDomDocument*) self));
		break;
		case GXML_GOM_DOCUMENT_ORIGIN:
		g_value_set_string (value, gxml_dom_document_get_origin ((GXmlDomDocument*) self));
		break;
		case GXML_GOM_DOCUMENT_COMPAT_MODE:
		g_value_set_string (value, gxml_dom_document_get_compat_mode ((GXmlDomDocument*) self));
		break;
		case GXML_GOM_DOCUMENT_CHARACTER_SET:
		g_value_set_string (value, gxml_dom_document_get_character_set ((GXmlDomDocument*) self));
		break;
		case GXML_GOM_DOCUMENT_CONTENT_TYPE:
		g_value_set_string (value, gxml_dom_document_get_content_type ((GXmlDomDocument*) self));
		break;
		case GXML_GOM_DOCUMENT_DOCTYPE:
		g_value_take_object (value, gxml_dom_document_get_doctype ((GXmlDomDocument*) self));
		break;
		case GXML_GOM_DOCUMENT_DOCUMENT_ELEMENT:
		g_value_take_object (value, gxml_dom_document_get_document_element ((GXmlDomDocument*) self));
		break;
		case GXML_GOM_DOCUMENT_CHILDREN:
		g_value_take_object (value, gxml_dom_parent_node_get_children ((GXmlDomParentNode*) self));
		break;
		case GXML_GOM_DOCUMENT_FIRST_ELEMENT_CHILD:
		g_value_take_object (value, gxml_dom_parent_node_get_first_element_child ((GXmlDomParentNode*) self));
		break;
		case GXML_GOM_DOCUMENT_LAST_ELEMENT_CHILD:
		g_value_take_object (value, gxml_dom_parent_node_get_last_element_child ((GXmlDomParentNode*) self));
		break;
		case GXML_GOM_DOCUMENT_CHILD_ELEMENT_COUNT:
		g_value_set_int (value, gxml_dom_parent_node_get_child_element_count ((GXmlDomParentNode*) self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


static GXmlDomDocumentType* gxml_gom_implementation_real_create_document_type (GXmlDomImplementation* base, const gchar* qualified_name, const gchar* public_id, const gchar* system_id, GError** error) {
	GXmlGomImplementation * self;
	GXmlDomDocumentType* result = NULL;
	GXmlGomDocument* _tmp0_ = NULL;
	GXmlGomDocument* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	GXmlGomDocumentType* _tmp5_ = NULL;
	GXmlDomDocumentType* _tmp6_ = NULL;
	self = (GXmlGomImplementation*) base;
	g_return_val_if_fail (qualified_name != NULL, NULL);
	g_return_val_if_fail (public_id != NULL, NULL);
	g_return_val_if_fail (system_id != NULL, NULL);
	_tmp0_ = gxml_gom_document_new ();
	_tmp1_ = _tmp0_;
	_tmp2_ = qualified_name;
	_tmp3_ = public_id;
	_tmp4_ = system_id;
	_tmp5_ = gxml_gom_document_type_new_with_ids ((GXmlDomDocument*) _tmp1_, _tmp2_, _tmp3_, _tmp4_);
	_tmp6_ = (GXmlDomDocumentType*) _tmp5_;
	_g_object_unref0 (_tmp1_);
	result = _tmp6_;
	return result;
}


static GXmlDomXMLDocument* gxml_gom_implementation_real_create_document (GXmlDomImplementation* base, const gchar* namespace, const gchar* qualified_name, GXmlDomDocumentType* doctype, GError** error) {
	GXmlGomImplementation * self;
	GXmlDomXMLDocument* result = NULL;
	GXmlGomDocument* d = NULL;
	GXmlGomDocument* _tmp0_ = NULL;
	GXmlDomDocumentType* _tmp1_ = NULL;
	GXmlDomElement* _tmp17_ = NULL;
	GXmlGomDocument* _tmp18_ = NULL;
	const gchar* _tmp19_ = NULL;
	const gchar* _tmp20_ = NULL;
	GXmlDomElement* _tmp21_ = NULL;
	GXmlGomDocument* _tmp22_ = NULL;
	GXmlDomNode* _tmp23_ = NULL;
	GXmlDomNode* _tmp24_ = NULL;
	GXmlGomDocument* _tmp25_ = NULL;
	GXmlDomXMLDocument* _tmp26_ = NULL;
	GError * _inner_error_ = NULL;
	self = (GXmlGomImplementation*) base;
	_tmp0_ = gxml_gom_document_new ();
	d = _tmp0_;
	_tmp1_ = doctype;
	if (_tmp1_ != NULL) {
		GXmlGomDocument* _tmp2_ = NULL;
		GXmlGomDocument* _tmp3_ = NULL;
		GXmlDomDocumentType* _tmp4_ = NULL;
		const gchar* _tmp5_ = NULL;
		const gchar* _tmp6_ = NULL;
		GXmlDomDocumentType* _tmp7_ = NULL;
		const gchar* _tmp8_ = NULL;
		const gchar* _tmp9_ = NULL;
		GXmlDomDocumentType* _tmp10_ = NULL;
		const gchar* _tmp11_ = NULL;
		const gchar* _tmp12_ = NULL;
		GXmlGomDocumentType* _tmp13_ = NULL;
		GXmlGomDocumentType* _tmp14_ = NULL;
		GXmlDomNode* _tmp15_ = NULL;
		GXmlDomNode* _tmp16_ = NULL;
		_tmp2_ = d;
		_tmp3_ = d;
		_tmp4_ = doctype;
		_tmp5_ = gxml_dom_document_type_get_name (_tmp4_);
		_tmp6_ = _tmp5_;
		_tmp7_ = doctype;
		_tmp8_ = gxml_dom_document_type_get_public_id (_tmp7_);
		_tmp9_ = _tmp8_;
		_tmp10_ = doctype;
		_tmp11_ = gxml_dom_document_type_get_system_id (_tmp10_);
		_tmp12_ = _tmp11_;
		_tmp13_ = gxml_gom_document_type_new_with_ids ((GXmlDomDocument*) _tmp3_, _tmp6_, _tmp9_, _tmp12_);
		_tmp14_ = _tmp13_;
		_tmp15_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp2_, (GXmlDomNode*) _tmp14_, &_inner_error_);
		_tmp16_ = _tmp15_;
		_g_object_unref0 (_tmp16_);
		_g_object_unref0 (_tmp14_);
		if (G_UNLIKELY (_inner_error_ != NULL)) {
			g_propagate_error (error, _inner_error_);
			_g_object_unref0 (d);
			return NULL;
		}
	}
	_tmp18_ = d;
	_tmp19_ = namespace;
	_tmp20_ = qualified_name;
	_tmp21_ = gxml_dom_document_create_element_ns ((GXmlDomDocument*) _tmp18_, _tmp19_, _tmp20_, &_inner_error_);
	_tmp17_ = _tmp21_;
	if (G_UNLIKELY (_inner_error_ != NULL)) {
		g_propagate_error (error, _inner_error_);
		_g_object_unref0 (d);
		return NULL;
	}
	_tmp22_ = d;
	_tmp23_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp22_, (GXmlDomNode*) _tmp17_, &_inner_error_);
	_tmp24_ = _tmp23_;
	_g_object_unref0 (_tmp24_);
	if (G_UNLIKELY (_inner_error_ != NULL)) {
		g_propagate_error (error, _inner_error_);
		_g_object_unref0 (_tmp17_);
		_g_object_unref0 (d);
		return NULL;
	}
	_tmp25_ = d;
	_tmp26_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp25_, GXML_TYPE_DOM_XML_DOCUMENT) ? ((GXmlDomXMLDocument*) _tmp25_) : NULL);
	result = _tmp26_;
	_g_object_unref0 (_tmp17_);
	_g_object_unref0 (d);
	return result;
}


static GXmlDocument* gxml_gom_implementation_real_create_html_document (GXmlDomImplementation* base, const gchar* title) {
	GXmlGomImplementation * self;
	GXmlDocument* result = NULL;
	GXmlHtmlDocument* _tmp0_ = NULL;
	self = (GXmlGomImplementation*) base;
	g_return_val_if_fail (title != NULL, NULL);
	_tmp0_ = gxml_html_document_new ();
	result = (GXmlDocument*) _tmp0_;
	return result;
}


GXmlGomImplementation* gxml_gom_implementation_construct (GType object_type) {
	GXmlGomImplementation * self = NULL;
	self = (GXmlGomImplementation*) g_object_new (object_type, NULL);
	return self;
}


GXmlGomImplementation* gxml_gom_implementation_new (void) {
	return gxml_gom_implementation_construct (GXML_TYPE_GOM_IMPLEMENTATION);
}


static void gxml_gom_implementation_class_init (GXmlGomImplementationClass * klass) {
	gxml_gom_implementation_parent_class = g_type_class_peek_parent (klass);
}


static void gxml_gom_implementation_gxml_dom_implementation_interface_init (GXmlDomImplementationIface * iface) {
	gxml_gom_implementation_gxml_dom_implementation_parent_iface = g_type_interface_peek_parent (iface);
	iface->create_document_type = (GXmlDomDocumentType* (*)(GXmlDomImplementation*, const gchar*, const gchar*, const gchar*, GError**)) gxml_gom_implementation_real_create_document_type;
	iface->create_document = (GXmlDomXMLDocument* (*)(GXmlDomImplementation*, const gchar*, const gchar*, GXmlDomDocumentType*, GError**)) gxml_gom_implementation_real_create_document;
	iface->create_html_document = (GXmlDocument* (*)(GXmlDomImplementation*, const gchar*)) gxml_gom_implementation_real_create_html_document;
}


static void gxml_gom_implementation_instance_init (GXmlGomImplementation * self) {
}


GType gxml_gom_implementation_get_type (void) {
	static volatile gsize gxml_gom_implementation_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_gom_implementation_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlGomImplementationClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gxml_gom_implementation_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GXmlGomImplementation), 0, (GInstanceInitFunc) gxml_gom_implementation_instance_init, NULL };
		static const GInterfaceInfo gxml_dom_implementation_info = { (GInterfaceInitFunc) gxml_gom_implementation_gxml_dom_implementation_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType gxml_gom_implementation_type_id;
		gxml_gom_implementation_type_id = g_type_register_static (G_TYPE_OBJECT, "GXmlGomImplementation", &g_define_type_info, 0);
		g_type_add_interface_static (gxml_gom_implementation_type_id, GXML_TYPE_DOM_IMPLEMENTATION, &gxml_dom_implementation_info);
		g_once_init_leave (&gxml_gom_implementation_type_id__volatile, gxml_gom_implementation_type_id);
	}
	return gxml_gom_implementation_type_id__volatile;
}


GXmlGomDocumentType* gxml_gom_document_type_construct_with_name (GType object_type, GXmlDomDocument* doc, const gchar* name) {
	GXmlGomDocumentType * self = NULL;
	GXmlDomDocument* _tmp0_ = NULL;
	GXmlDomDocument* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	g_return_val_if_fail (doc != NULL, NULL);
	g_return_val_if_fail (name != NULL, NULL);
	self = (GXmlGomDocumentType*) gxml_gom_node_construct (object_type);
	_tmp0_ = doc;
	_tmp1_ = _g_object_ref0 (_tmp0_);
	_g_object_unref0 (((GXmlGomNode*) self)->_document);
	((GXmlGomNode*) self)->_document = _tmp1_;
	_tmp2_ = name;
	_tmp3_ = g_strdup (_tmp2_);
	_g_free0 (self->_name);
	self->_name = _tmp3_;
	_tmp4_ = g_strdup ("");
	_g_free0 (self->_public_id);
	self->_public_id = _tmp4_;
	_tmp5_ = g_strdup ("");
	_g_free0 (self->_system_id);
	self->_system_id = _tmp5_;
	return self;
}


GXmlGomDocumentType* gxml_gom_document_type_new_with_name (GXmlDomDocument* doc, const gchar* name) {
	return gxml_gom_document_type_construct_with_name (GXML_TYPE_GOM_DOCUMENT_TYPE, doc, name);
}


GXmlGomDocumentType* gxml_gom_document_type_construct_with_ids (GType object_type, GXmlDomDocument* doc, const gchar* name, const gchar* public_id, const gchar* system_id) {
	GXmlGomDocumentType * self = NULL;
	GXmlDomDocument* _tmp0_ = NULL;
	GXmlDomDocument* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	const gchar* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
	g_return_val_if_fail (doc != NULL, NULL);
	g_return_val_if_fail (name != NULL, NULL);
	g_return_val_if_fail (public_id != NULL, NULL);
	g_return_val_if_fail (system_id != NULL, NULL);
	self = (GXmlGomDocumentType*) gxml_gom_node_construct (object_type);
	_tmp0_ = doc;
	_tmp1_ = _g_object_ref0 (_tmp0_);
	_g_object_unref0 (((GXmlGomNode*) self)->_document);
	((GXmlGomNode*) self)->_document = _tmp1_;
	_tmp2_ = name;
	_tmp3_ = g_strdup (_tmp2_);
	_g_free0 (self->_name);
	self->_name = _tmp3_;
	_tmp4_ = public_id;
	_tmp5_ = g_strdup (_tmp4_);
	_g_free0 (self->_public_id);
	self->_public_id = _tmp5_;
	_tmp6_ = system_id;
	_tmp7_ = g_strdup (_tmp6_);
	_g_free0 (self->_system_id);
	self->_system_id = _tmp7_;
	return self;
}


GXmlGomDocumentType* gxml_gom_document_type_new_with_ids (GXmlDomDocument* doc, const gchar* name, const gchar* public_id, const gchar* system_id) {
	return gxml_gom_document_type_construct_with_ids (GXML_TYPE_GOM_DOCUMENT_TYPE, doc, name, public_id, system_id);
}


static void gxml_gom_document_type_real_remove (GXmlDomChildNode* base) {
	GXmlGomDocumentType * self;
	GXmlDomNode* _tmp0_ = NULL;
	GXmlDomNode* _tmp1_ = NULL;
	GXmlDomNode* _tmp2_ = NULL;
	gboolean _tmp3_ = FALSE;
	GXmlDomNode* _tmp4_ = NULL;
	GXmlDomNode* _tmp5_ = NULL;
	GXmlDomNode* _tmp6_ = NULL;
	GXmlDomNodeList* _tmp7_ = NULL;
	GXmlDomNodeList* _tmp8_ = NULL;
	GXmlDomNodeList* _tmp9_ = NULL;
	gboolean _tmp10_ = FALSE;
	gint i = 0;
	GXmlDomNode* _tmp11_ = NULL;
	GXmlDomNode* _tmp12_ = NULL;
	GXmlDomNode* _tmp13_ = NULL;
	GXmlDomNodeList* _tmp14_ = NULL;
	GXmlDomNodeList* _tmp15_ = NULL;
	GXmlDomNodeList* _tmp16_ = NULL;
	gint _tmp17_ = 0;
	gint _tmp18_ = 0;
	GXmlDomNode* _tmp19_ = NULL;
	GXmlDomNode* _tmp20_ = NULL;
	GXmlDomNode* _tmp21_ = NULL;
	GXmlDomNodeList* _tmp22_ = NULL;
	GXmlDomNodeList* _tmp23_ = NULL;
	GXmlDomNodeList* _tmp24_ = NULL;
	gint _tmp25_ = 0;
	gpointer _tmp26_ = NULL;
	GXmlDomNode* _tmp27_ = NULL;
	self = (GXmlGomDocumentType*) base;
	_tmp0_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) self);
	_tmp1_ = _tmp0_;
	_tmp2_ = _tmp1_;
	_tmp3_ = _tmp2_ == NULL;
	_g_object_unref0 (_tmp2_);
	if (_tmp3_) {
		return;
	}
	_tmp4_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) self);
	_tmp5_ = _tmp4_;
	_tmp6_ = _tmp5_;
	_tmp7_ = gxml_dom_node_get_child_nodes (_tmp6_);
	_tmp8_ = _tmp7_;
	_tmp9_ = _tmp8_;
	_tmp10_ = _tmp9_ == NULL;
	_g_object_unref0 (_tmp9_);
	_g_object_unref0 (_tmp6_);
	if (_tmp10_) {
		return;
	}
	_tmp11_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) self);
	_tmp12_ = _tmp11_;
	_tmp13_ = _tmp12_;
	_tmp14_ = gxml_dom_node_get_child_nodes (_tmp13_);
	_tmp15_ = _tmp14_;
	_tmp16_ = _tmp15_;
	_tmp17_ = gee_list_index_of ((GeeList*) _tmp16_, (GXmlDomNode*) self);
	_tmp18_ = _tmp17_;
	_g_object_unref0 (_tmp16_);
	_g_object_unref0 (_tmp13_);
	i = _tmp18_;
	_tmp19_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) self);
	_tmp20_ = _tmp19_;
	_tmp21_ = _tmp20_;
	_tmp22_ = gxml_dom_node_get_child_nodes (_tmp21_);
	_tmp23_ = _tmp22_;
	_tmp24_ = _tmp23_;
	_tmp25_ = i;
	_tmp26_ = gee_list_remove_at ((GeeList*) _tmp24_, _tmp25_);
	_tmp27_ = (GXmlDomNode*) _tmp26_;
	_g_object_unref0 (_tmp27_);
	_g_object_unref0 (_tmp24_);
	_g_object_unref0 (_tmp21_);
}


GXmlGomDocumentType* gxml_gom_document_type_construct (GType object_type) {
	GXmlGomDocumentType * self = NULL;
	self = (GXmlGomDocumentType*) gxml_gom_node_construct (object_type);
	return self;
}


GXmlGomDocumentType* gxml_gom_document_type_new (void) {
	return gxml_gom_document_type_construct (GXML_TYPE_GOM_DOCUMENT_TYPE);
}


static const gchar* gxml_gom_document_type_real_get_name (GXmlDomDocumentType* base) {
	const gchar* result;
	GXmlGomDocumentType* self;
	const gchar* _tmp0_ = NULL;
	self = (GXmlGomDocumentType*) base;
	_tmp0_ = self->_name;
	result = _tmp0_;
	return result;
}


static const gchar* gxml_gom_document_type_real_get_public_id (GXmlDomDocumentType* base) {
	const gchar* result;
	GXmlGomDocumentType* self;
	const gchar* _tmp0_ = NULL;
	self = (GXmlGomDocumentType*) base;
	_tmp0_ = self->_public_id;
	result = _tmp0_;
	return result;
}


static const gchar* gxml_gom_document_type_real_get_system_id (GXmlDomDocumentType* base) {
	const gchar* result;
	GXmlGomDocumentType* self;
	const gchar* _tmp0_ = NULL;
	self = (GXmlGomDocumentType*) base;
	_tmp0_ = self->_system_id;
	result = _tmp0_;
	return result;
}


static void gxml_gom_document_type_class_init (GXmlGomDocumentTypeClass * klass) {
	gxml_gom_document_type_parent_class = g_type_class_peek_parent (klass);
	G_OBJECT_CLASS (klass)->get_property = _vala_gxml_gom_document_type_get_property;
	G_OBJECT_CLASS (klass)->finalize = gxml_gom_document_type_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_DOCUMENT_TYPE_NAME, g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_DOCUMENT_TYPE_PUBLIC_ID, g_param_spec_string ("public-id", "public-id", "public-id", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_DOCUMENT_TYPE_SYSTEM_ID, g_param_spec_string ("system-id", "system-id", "system-id", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
}


static void gxml_gom_document_type_gxml_dom_node_interface_init (GXmlDomNodeIface * iface) {
	gxml_gom_document_type_gxml_dom_node_parent_iface = g_type_interface_peek_parent (iface);
	iface->has_child_nodes = (gboolean (*)(GXmlDomNode*)) gxml_dom_node_has_child_nodes;
	iface->normalize = (void (*)(GXmlDomNode*)) gxml_dom_node_normalize;
	iface->is_equal_node = (gboolean (*)(GXmlDomNode*, GXmlDomNode*)) gxml_dom_node_is_equal_node;
	iface->compare_document_position = (GXmlDomNodeDocumentPosition (*)(GXmlDomNode*, GXmlDomNode*)) gxml_dom_node_compare_document_position;
	iface->contains = (gboolean (*)(GXmlDomNode*, GXmlDomNode*)) gxml_dom_node_contains;
	iface->lookup_prefix = (gchar* (*)(GXmlDomNode*, const gchar*)) gxml_dom_node_lookup_prefix;
	iface->lookup_namespace_uri = (gchar* (*)(GXmlDomNode*, const gchar*)) gxml_dom_node_lookup_namespace_uri;
	iface->is_default_namespace = (gboolean (*)(GXmlDomNode*, const gchar*)) gxml_dom_node_is_default_namespace;
	iface->insert_before = (GXmlDomNode* (*)(GXmlDomNode*, GXmlDomNode*, GXmlDomNode*, GError**)) gxml_dom_node_insert_before;
	iface->append_child = (GXmlDomNode* (*)(GXmlDomNode*, GXmlDomNode*, GError**)) gxml_dom_node_append_child;
	iface->replace_child = (GXmlDomNode* (*)(GXmlDomNode*, GXmlDomNode*, GXmlDomNode*, GError**)) gxml_dom_node_replace_child;
	iface->remove_child = (GXmlDomNode* (*)(GXmlDomNode*, GXmlDomNode*, GError**)) gxml_dom_node_remove_child;
	iface->get_node_type = (GXmlDomNodeNodeType (*) (GXmlDomNode *)) gxml_dom_node_get_node_type;
	iface->get_node_name = (gchar* (*) (GXmlDomNode *)) gxml_dom_node_get_node_name;
	iface->get_base_uri = (const gchar* (*) (GXmlDomNode *)) gxml_dom_node_get_base_uri;
	iface->get_owner_document = (GXmlDomDocument* (*) (GXmlDomNode *)) gxml_dom_node_get_owner_document;
	iface->set_owner_document = (void (*) (GXmlDomNode *, GXmlDomDocument*)) gxml_dom_node_set_owner_document;
	iface->get_parent_node = (GXmlDomNode* (*) (GXmlDomNode *)) gxml_dom_node_get_parent_node;
	iface->get_parent_element = (GXmlDomElement* (*) (GXmlDomNode *)) gxml_dom_node_get_parent_element;
	iface->get_child_nodes = (GXmlDomNodeList* (*) (GXmlDomNode *)) gxml_dom_node_get_child_nodes;
	iface->get_first_child = (GXmlDomNode* (*) (GXmlDomNode *)) gxml_dom_node_get_first_child;
	iface->get_last_child = (GXmlDomNode* (*) (GXmlDomNode *)) gxml_dom_node_get_last_child;
	iface->get_previous_sibling = (GXmlDomNode* (*) (GXmlDomNode *)) gxml_dom_node_get_previous_sibling;
	iface->get_next_sibling = (GXmlDomNode* (*) (GXmlDomNode *)) gxml_dom_node_get_next_sibling;
	iface->get_node_value = (gchar* (*) (GXmlDomNode *)) gxml_dom_node_get_node_value;
	iface->set_node_value = (void (*) (GXmlDomNode *, const gchar*)) gxml_dom_node_set_node_value;
	iface->get_text_content = (gchar* (*) (GXmlDomNode *)) gxml_dom_node_get_text_content;
	iface->set_text_content = (void (*) (GXmlDomNode *, const gchar*)) gxml_dom_node_set_text_content;
}


static void gxml_gom_document_type_gxml_dom_child_node_interface_init (GXmlDomChildNodeIface * iface) {
	gxml_gom_document_type_gxml_dom_child_node_parent_iface = g_type_interface_peek_parent (iface);
	iface->remove = (void (*)(GXmlDomChildNode*)) gxml_gom_document_type_real_remove;
}


static void gxml_gom_document_type_gxml_dom_document_type_interface_init (GXmlDomDocumentTypeIface * iface) {
	gxml_gom_document_type_gxml_dom_document_type_parent_iface = g_type_interface_peek_parent (iface);
	iface->get_name = gxml_gom_document_type_real_get_name;
	iface->get_public_id = gxml_gom_document_type_real_get_public_id;
	iface->get_system_id = gxml_gom_document_type_real_get_system_id;
}


static void gxml_gom_document_type_instance_init (GXmlGomDocumentType * self) {
	gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	_tmp0_ = g_strdup ("");
	self->_name = _tmp0_;
	_tmp1_ = g_strdup ("");
	self->_public_id = _tmp1_;
	_tmp2_ = g_strdup ("");
	self->_system_id = _tmp2_;
}


static void gxml_gom_document_type_finalize (GObject* obj) {
	GXmlGomDocumentType * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GXML_TYPE_GOM_DOCUMENT_TYPE, GXmlGomDocumentType);
	_g_free0 (self->_name);
	_g_free0 (self->_public_id);
	_g_free0 (self->_system_id);
	G_OBJECT_CLASS (gxml_gom_document_type_parent_class)->finalize (obj);
}


GType gxml_gom_document_type_get_type (void) {
	static volatile gsize gxml_gom_document_type_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_gom_document_type_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlGomDocumentTypeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gxml_gom_document_type_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GXmlGomDocumentType), 0, (GInstanceInitFunc) gxml_gom_document_type_instance_init, NULL };
		static const GInterfaceInfo gxml_dom_node_info = { (GInterfaceInitFunc) gxml_gom_document_type_gxml_dom_node_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		static const GInterfaceInfo gxml_dom_child_node_info = { (GInterfaceInitFunc) gxml_gom_document_type_gxml_dom_child_node_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		static const GInterfaceInfo gxml_dom_document_type_info = { (GInterfaceInitFunc) gxml_gom_document_type_gxml_dom_document_type_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType gxml_gom_document_type_type_id;
		gxml_gom_document_type_type_id = g_type_register_static (GXML_TYPE_GOM_NODE, "GXmlGomDocumentType", &g_define_type_info, 0);
		g_type_add_interface_static (gxml_gom_document_type_type_id, GXML_TYPE_DOM_NODE, &gxml_dom_node_info);
		g_type_add_interface_static (gxml_gom_document_type_type_id, GXML_TYPE_DOM_CHILD_NODE, &gxml_dom_child_node_info);
		g_type_add_interface_static (gxml_gom_document_type_type_id, GXML_TYPE_DOM_DOCUMENT_TYPE, &gxml_dom_document_type_info);
		g_once_init_leave (&gxml_gom_document_type_type_id__volatile, gxml_gom_document_type_type_id);
	}
	return gxml_gom_document_type_type_id__volatile;
}


static void _vala_gxml_gom_document_type_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	GXmlGomDocumentType * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GXML_TYPE_GOM_DOCUMENT_TYPE, GXmlGomDocumentType);
	switch (property_id) {
		case GXML_GOM_DOCUMENT_TYPE_NAME:
		g_value_set_string (value, gxml_dom_document_type_get_name ((GXmlDomDocumentType*) self));
		break;
		case GXML_GOM_DOCUMENT_TYPE_PUBLIC_ID:
		g_value_set_string (value, gxml_dom_document_type_get_public_id ((GXmlDomDocumentType*) self));
		break;
		case GXML_GOM_DOCUMENT_TYPE_SYSTEM_ID:
		g_value_set_string (value, gxml_dom_document_type_get_system_id ((GXmlDomDocumentType*) self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


GXmlGomDocumentFragment* gxml_gom_document_fragment_construct (GType object_type, GXmlDomDocument* doc) {
	GXmlGomDocumentFragment * self = NULL;
	GXmlDomDocument* _tmp0_ = NULL;
	GXmlDomDocument* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	g_return_val_if_fail (doc != NULL, NULL);
	self = (GXmlGomDocumentFragment*) gxml_gom_node_construct (object_type);
	_tmp0_ = doc;
	_tmp1_ = _g_object_ref0 (_tmp0_);
	_g_object_unref0 (((GXmlGomNode*) self)->_document);
	((GXmlGomNode*) self)->_document = _tmp1_;
	((GXmlGomNode*) self)->_node_type = GXML_DOM_NODE_NODE_TYPE_DOCUMENT_FRAGMENT_NODE;
	_tmp2_ = g_strdup ("#document-fragment");
	_g_free0 (((GXmlGomNode*) self)->_local_name);
	((GXmlGomNode*) self)->_local_name = _tmp2_;
	return self;
}


GXmlGomDocumentFragment* gxml_gom_document_fragment_new (GXmlDomDocument* doc) {
	return gxml_gom_document_fragment_construct (GXML_TYPE_GOM_DOCUMENT_FRAGMENT, doc);
}


static GXmlDomElement* gxml_gom_document_fragment_real_query_selector (GXmlDomParentNode* base, const gchar* selectors, GError** error) {
	GXmlGomDocumentFragment * self;
	GXmlDomElement* result = NULL;
	const gchar* _tmp0_ = NULL;
	GError* _tmp1_ = NULL;
	GError * _inner_error_ = NULL;
	self = (GXmlGomDocumentFragment*) base;
	g_return_val_if_fail (selectors != NULL, NULL);
	_tmp0_ = _ ("DomElement query_selector is not implemented");
	_tmp1_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_SYNTAX_ERROR, _tmp0_);
	_inner_error_ = _tmp1_;
	g_propagate_error (error, _inner_error_);
	return NULL;
	return result;
}


static GXmlDomNodeList* gxml_gom_document_fragment_real_query_selector_all (GXmlDomParentNode* base, const gchar* selectors, GError** error) {
	GXmlGomDocumentFragment * self;
	GXmlDomNodeList* result = NULL;
	const gchar* _tmp0_ = NULL;
	GError* _tmp1_ = NULL;
	GError * _inner_error_ = NULL;
	self = (GXmlGomDocumentFragment*) base;
	g_return_val_if_fail (selectors != NULL, NULL);
	_tmp0_ = _ ("DomElement query_selector_all is not implemented");
	_tmp1_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_SYNTAX_ERROR, _tmp0_);
	_inner_error_ = _tmp1_;
	g_propagate_error (error, _inner_error_);
	return NULL;
	return result;
}


static GXmlDomElement* gxml_gom_document_fragment_real_get_element_by_id (GXmlDomNonElementParentNode* base, const gchar* element_id, GError** error) {
	GXmlGomDocumentFragment * self;
	GXmlDomElement* result = NULL;
	GXmlDomElementList* l = NULL;
	const gchar* _tmp0_ = NULL;
	GXmlDomElementList* _tmp1_ = NULL;
	GXmlDomElementList* _tmp2_ = NULL;
	gint _tmp3_ = 0;
	gint _tmp4_ = 0;
	self = (GXmlGomDocumentFragment*) base;
	g_return_val_if_fail (element_id != NULL, NULL);
	_tmp0_ = element_id;
	_tmp1_ = gxml_dom_parent_node_get_elements_by_property_value ((GXmlDomParentNode*) self, "id", _tmp0_);
	l = _tmp1_;
	_tmp2_ = l;
	_tmp3_ = gee_abstract_collection_get_size ((GeeAbstractCollection*) _tmp2_);
	_tmp4_ = _tmp3_;
	if (_tmp4_ > 0) {
		GXmlDomElementList* _tmp5_ = NULL;
		gpointer _tmp6_ = NULL;
		_tmp5_ = l;
		_tmp6_ = gee_abstract_list_get ((GeeAbstractList*) _tmp5_, 0);
		result = G_TYPE_CHECK_INSTANCE_CAST ((GXmlDomElement*) _tmp6_, GXML_TYPE_DOM_ELEMENT, GXmlDomElement);
		_g_object_unref0 (l);
		return result;
	}
	result = NULL;
	_g_object_unref0 (l);
	return result;
}


static GXmlDomHTMLCollection* gxml_gom_document_fragment_real_get_children (GXmlDomParentNode* base) {
	GXmlDomHTMLCollection* result;
	GXmlGomDocumentFragment* self;
	GXmlDomElementList* l = NULL;
	GXmlDomElementList* _tmp0_ = NULL;
	self = (GXmlGomDocumentFragment*) base;
	_tmp0_ = gxml_dom_element_list_new ();
	l = _tmp0_;
	{
		GXmlDomNodeList* _n_list = NULL;
		GXmlDomNodeList* _tmp1_ = NULL;
		GXmlDomNodeList* _tmp2_ = NULL;
		gint _n_size = 0;
		GXmlDomNodeList* _tmp3_ = NULL;
		gint _tmp4_ = 0;
		gint _tmp5_ = 0;
		gint _n_index = 0;
		_tmp1_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) self);
		_tmp2_ = _tmp1_;
		_n_list = _tmp2_;
		_tmp3_ = _n_list;
		_tmp4_ = gee_collection_get_size ((GeeCollection*) _tmp3_);
		_tmp5_ = _tmp4_;
		_n_size = _tmp5_;
		_n_index = -1;
		while (TRUE) {
			gint _tmp6_ = 0;
			gint _tmp7_ = 0;
			gint _tmp8_ = 0;
			GXmlDomNode* n = NULL;
			GXmlDomNodeList* _tmp9_ = NULL;
			gint _tmp10_ = 0;
			gpointer _tmp11_ = NULL;
			GXmlDomNode* _tmp12_ = NULL;
			_tmp6_ = _n_index;
			_n_index = _tmp6_ + 1;
			_tmp7_ = _n_index;
			_tmp8_ = _n_size;
			if (!(_tmp7_ < _tmp8_)) {
				break;
			}
			_tmp9_ = _n_list;
			_tmp10_ = _n_index;
			_tmp11_ = gee_list_get ((GeeList*) _tmp9_, _tmp10_);
			n = (GXmlDomNode*) _tmp11_;
			_tmp12_ = n;
			if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp12_, GXML_TYPE_DOM_ELEMENT)) {
				GXmlDomElementList* _tmp13_ = NULL;
				GXmlDomNode* _tmp14_ = NULL;
				_tmp13_ = l;
				_tmp14_ = n;
				gee_abstract_collection_add ((GeeAbstractCollection*) _tmp13_, G_TYPE_CHECK_INSTANCE_CAST (_tmp14_, GXML_TYPE_DOM_ELEMENT, GXmlDomElement));
			}
			_g_object_unref0 (n);
		}
		_g_object_unref0 (_n_list);
	}
	result = (GXmlDomHTMLCollection*) l;
	return result;
}


static GXmlDomElement* gxml_gom_document_fragment_real_get_first_element_child (GXmlDomParentNode* base) {
	GXmlDomElement* result;
	GXmlGomDocumentFragment* self;
	GXmlDomHTMLCollection* _tmp0_ = NULL;
	GXmlDomHTMLCollection* _tmp1_ = NULL;
	GXmlDomHTMLCollection* _tmp2_ = NULL;
	gpointer _tmp3_ = NULL;
	GXmlDomElement* _tmp4_ = NULL;
	self = (GXmlGomDocumentFragment*) base;
	_tmp0_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) self);
	_tmp1_ = _tmp0_;
	_tmp2_ = _tmp1_;
	_tmp3_ = gee_list_first ((GeeList*) _tmp2_);
	_tmp4_ = G_TYPE_CHECK_INSTANCE_CAST ((GXmlDomElement*) _tmp3_, GXML_TYPE_DOM_ELEMENT, GXmlDomElement);
	_g_object_unref0 (_tmp2_);
	result = _tmp4_;
	return result;
}


static GXmlDomElement* gxml_gom_document_fragment_real_get_last_element_child (GXmlDomParentNode* base) {
	GXmlDomElement* result;
	GXmlGomDocumentFragment* self;
	GXmlDomHTMLCollection* _tmp0_ = NULL;
	GXmlDomHTMLCollection* _tmp1_ = NULL;
	GXmlDomHTMLCollection* _tmp2_ = NULL;
	gpointer _tmp3_ = NULL;
	GXmlDomElement* _tmp4_ = NULL;
	self = (GXmlGomDocumentFragment*) base;
	_tmp0_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) self);
	_tmp1_ = _tmp0_;
	_tmp2_ = _tmp1_;
	_tmp3_ = gee_list_last ((GeeList*) _tmp2_);
	_tmp4_ = G_TYPE_CHECK_INSTANCE_CAST ((GXmlDomElement*) _tmp3_, GXML_TYPE_DOM_ELEMENT, GXmlDomElement);
	_g_object_unref0 (_tmp2_);
	result = _tmp4_;
	return result;
}


static gint gxml_gom_document_fragment_real_get_child_element_count (GXmlDomParentNode* base) {
	gint result;
	GXmlGomDocumentFragment* self;
	GXmlDomHTMLCollection* _tmp0_ = NULL;
	GXmlDomHTMLCollection* _tmp1_ = NULL;
	GXmlDomHTMLCollection* _tmp2_ = NULL;
	gint _tmp3_ = 0;
	gint _tmp4_ = 0;
	gint _tmp5_ = 0;
	self = (GXmlGomDocumentFragment*) base;
	_tmp0_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) self);
	_tmp1_ = _tmp0_;
	_tmp2_ = _tmp1_;
	_tmp3_ = gee_collection_get_size ((GeeCollection*) _tmp2_);
	_tmp4_ = _tmp3_;
	_tmp5_ = (gint) _tmp4_;
	_g_object_unref0 (_tmp2_);
	result = _tmp5_;
	return result;
}


static void gxml_gom_document_fragment_class_init (GXmlGomDocumentFragmentClass * klass) {
	gxml_gom_document_fragment_parent_class = g_type_class_peek_parent (klass);
	G_OBJECT_CLASS (klass)->get_property = _vala_gxml_gom_document_fragment_get_property;
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_DOCUMENT_FRAGMENT_CHILDREN, g_param_spec_object ("children", "children", "children", GXML_TYPE_DOM_HTML_COLLECTION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_DOCUMENT_FRAGMENT_FIRST_ELEMENT_CHILD, g_param_spec_object ("first-element-child", "first-element-child", "first-element-child", GXML_TYPE_DOM_ELEMENT, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_DOCUMENT_FRAGMENT_LAST_ELEMENT_CHILD, g_param_spec_object ("last-element-child", "last-element-child", "last-element-child", GXML_TYPE_DOM_ELEMENT, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_DOCUMENT_FRAGMENT_CHILD_ELEMENT_COUNT, g_param_spec_int ("child-element-count", "child-element-count", "child-element-count", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
}


static void gxml_gom_document_fragment_gxml_dom_parent_node_interface_init (GXmlDomParentNodeIface * iface) {
	gxml_gom_document_fragment_gxml_dom_parent_node_parent_iface = g_type_interface_peek_parent (iface);
	iface->query_selector = (GXmlDomElement* (*)(GXmlDomParentNode*, const gchar*, GError**)) gxml_gom_document_fragment_real_query_selector;
	iface->query_selector_all = (GXmlDomNodeList* (*)(GXmlDomParentNode*, const gchar*, GError**)) gxml_gom_document_fragment_real_query_selector_all;
	iface->get_children = gxml_gom_document_fragment_real_get_children;
	iface->get_first_element_child = gxml_gom_document_fragment_real_get_first_element_child;
	iface->get_last_element_child = gxml_gom_document_fragment_real_get_last_element_child;
	iface->get_child_element_count = gxml_gom_document_fragment_real_get_child_element_count;
}


static void gxml_gom_document_fragment_gxml_dom_non_element_parent_node_interface_init (GXmlDomNonElementParentNodeIface * iface) {
	gxml_gom_document_fragment_gxml_dom_non_element_parent_node_parent_iface = g_type_interface_peek_parent (iface);
	iface->get_element_by_id = (GXmlDomElement* (*)(GXmlDomNonElementParentNode*, const gchar*, GError**)) gxml_gom_document_fragment_real_get_element_by_id;
}


static void gxml_gom_document_fragment_gxml_dom_document_fragment_interface_init (GXmlDomDocumentFragmentIface * iface) {
	gxml_gom_document_fragment_gxml_dom_document_fragment_parent_iface = g_type_interface_peek_parent (iface);
}


static void gxml_gom_document_fragment_instance_init (GXmlGomDocumentFragment * self) {
}


GType gxml_gom_document_fragment_get_type (void) {
	static volatile gsize gxml_gom_document_fragment_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_gom_document_fragment_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlGomDocumentFragmentClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gxml_gom_document_fragment_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GXmlGomDocumentFragment), 0, (GInstanceInitFunc) gxml_gom_document_fragment_instance_init, NULL };
		static const GInterfaceInfo gxml_dom_parent_node_info = { (GInterfaceInitFunc) gxml_gom_document_fragment_gxml_dom_parent_node_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		static const GInterfaceInfo gxml_dom_non_element_parent_node_info = { (GInterfaceInitFunc) gxml_gom_document_fragment_gxml_dom_non_element_parent_node_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		static const GInterfaceInfo gxml_dom_document_fragment_info = { (GInterfaceInitFunc) gxml_gom_document_fragment_gxml_dom_document_fragment_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType gxml_gom_document_fragment_type_id;
		gxml_gom_document_fragment_type_id = g_type_register_static (GXML_TYPE_GOM_NODE, "GXmlGomDocumentFragment", &g_define_type_info, 0);
		g_type_add_interface_static (gxml_gom_document_fragment_type_id, GXML_TYPE_DOM_PARENT_NODE, &gxml_dom_parent_node_info);
		g_type_add_interface_static (gxml_gom_document_fragment_type_id, GXML_TYPE_DOM_NON_ELEMENT_PARENT_NODE, &gxml_dom_non_element_parent_node_info);
		g_type_add_interface_static (gxml_gom_document_fragment_type_id, GXML_TYPE_DOM_DOCUMENT_FRAGMENT, &gxml_dom_document_fragment_info);
		g_once_init_leave (&gxml_gom_document_fragment_type_id__volatile, gxml_gom_document_fragment_type_id);
	}
	return gxml_gom_document_fragment_type_id__volatile;
}


static void _vala_gxml_gom_document_fragment_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	GXmlGomDocumentFragment * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GXML_TYPE_GOM_DOCUMENT_FRAGMENT, GXmlGomDocumentFragment);
	switch (property_id) {
		case GXML_GOM_DOCUMENT_FRAGMENT_CHILDREN:
		g_value_take_object (value, gxml_dom_parent_node_get_children ((GXmlDomParentNode*) self));
		break;
		case GXML_GOM_DOCUMENT_FRAGMENT_FIRST_ELEMENT_CHILD:
		g_value_take_object (value, gxml_dom_parent_node_get_first_element_child ((GXmlDomParentNode*) self));
		break;
		case GXML_GOM_DOCUMENT_FRAGMENT_LAST_ELEMENT_CHILD:
		g_value_take_object (value, gxml_dom_parent_node_get_last_element_child ((GXmlDomParentNode*) self));
		break;
		case GXML_GOM_DOCUMENT_FRAGMENT_CHILD_ELEMENT_COUNT:
		g_value_set_int (value, gxml_dom_parent_node_get_child_element_count ((GXmlDomParentNode*) self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}


static gint _vala_array_length (gpointer array) {
	int length;
	length = 0;
	if (array) {
		while (((gpointer*) array)[length]) {
			length++;
		}
	}
	return length;
}



